@@ -7,7 +7,7 @@ const wxString s_translations[][2] = {
 	{ wxT("Armenian"), wxT("Hrant Ohanyan <hrantohanyan at mail.am>") },
 	{ wxT("Catalan"), wxT("Rafael Ferran i Peralta <rferranp at gmail.com>") },
 	{ wxT("Chinese (Simplified)"), wxString(wxT("程序民工 <lyj8063 at sohu.com>, 郁晓旭 <yuxiaoxu at msn.com>"), wxConvUTF8) },
-	{ wxT("Chinese (Traditional)"), wxString(wxT("紀明村 <tw.chi.ming at gmail.com>, Sophina Liu <Sophina-liu at hotmail.com>"), wxConvUTF8) },
+	{ wxT("Chinese (Traditional)"), wxString(wxT("風逸蘭 <stchen0214 at gmail.com>, Sophina Liu <Sophina-liu at hotmail.com>"), wxConvUTF8) },
 	{ wxT("Basque"), wxT("Piarres Beobide <pi at beobide.net>") },
 	{ wxT("Czech"), wxString(wxT("Vlastimil Skácel <vlastiks at gmail.com>"), wxConvUTF8) },
 	{ wxT("Danish"), wxT("Jørgen Rasmussen <l10n at joergenr.dk>") },
@@ -17,14 +17,14 @@ const wxString s_translations[][2] = {
 	{ wxT("German"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
 	{ wxT("Greek"), wxT("Aristotelis Pitaridis <pitaridis at gmail.com>") },
 	{ wxT("Hungarian"), wxString(wxT("Demecs Gábor <gabohw at freemail.hu>, Fáczán László <faczan at freemail.hu>"), wxConvUTF8) },
-	{ wxT("Italian"), wxT("Marco Ciampa <ciampix at libero.it>, Alessio Leonarduzzi <alessio.leonarduzzi at gmail.com>") },
+	{ wxT("Italian"), wxT("Marco Ciampa <ciampix at libero.it>, Christian Bevini <serse.tharkas at gmail.com>") },
 	{ wxT("Japanese"), wxT("OKANO Takayoshi <kano at na.rim.or.jp>") },
 	{ wxT("Korean"), wxString(wxT("김프사랑 <yongdoria at gmail.com>"), wxConvUTF8) },
 	{ wxT("Macedonian"), wxT("Damjan Dimitrioski <damjandimitrioski at gmail.com>") },
 	{ wxT("Norwegian"), wxString(wxT("Olav Inge Frøynes <olavinge at gmail.com>"), wxConvUTF8) },
 	{ wxT("Polish"), wxString(wxT("Michał Trzebiatowski <hippie_1968 at hotmail.com>"), wxConvUTF8) },
 	{ wxT("Portuguese"), wxString(wxT("João Frade / / 100 NOME PT <100nome.portugal at gmail.com>"), wxConvUTF8) },
-	{ wxT("Portuguese (Brazilian)"), wxT("SKYFORGE <skyforge at hotmail.com.br>, Paulo Henrique Araújo <paulohenriqueyer at hotmail.com>") },
+	{ wxT("Portuguese (Brazilian)"), wxT("SKYFORGE <skyforge at hotmail.com.br>, Henrique Barone <henrique.blender at gmail.com>, Paulo Henrique Araújo <paulohenriqueyer at hotmail.com>") },
 	{ wxT("Romanian"), wxT("Dan Ibanescu <ibanescu.dan at gmail.com>") },
 	{ wxT("Russian"), wxT("Alex Th&uuml;ring <alex at thuering.biz>") },
 	{ wxT("Slovenian"), wxT("Martin Srebotnjak <miles at filmsi.net>") },
