@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Structure (Titles/Menus)
 // Author:      Alex Thuering
 // Created:     29.01.2003
-// RCS-ID:      $Id: DVD.cpp,v 1.122 2013/06/16 19:27:48 ntalex Exp $
+// RCS-ID:      $Id: DVD.cpp,v 1.132 2014/02/18 17:01:46 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -37,11 +37,14 @@ DVD::DVD() {
 	m_audioFormat = afMP2;
 	m_aspectRatio = ar4_3;
 	m_defPostCommand = cmdCALL_LAST_MENU;
+	titleMenuTemplate = NULL;
 }
 
 DVD::~DVD() {
 	WX_CLEAR_ARRAY(m_vmgm);
 	WX_CLEAR_ARRAY(m_titlesets);
+	if (titleMenuTemplate)
+		delete titleMenuTemplate;
 }
 
 /** Returns disc capacity in KB */
@@ -87,7 +90,7 @@ wxArrayInt DVD::CalculateVideoBitrate() {
 				Vob* vob = pgc->GetVobs()[vobi];
 				VideoFormat videoFormat = vfCOPY;
 				if (!vob->GetSlideshow() && !vob->GetDoNotTranscode()) {
-					for (int stIdx = 0; stIdx < (int) vob->GetStreams().GetCount(); stIdx++) {
+					for (int stIdx = 0; stIdx < (int) vob->GetStreams().size(); stIdx++) {
 						Stream* stream = vob->GetStreams()[stIdx];
 						if (stream->GetType() == stVIDEO) {
 							videoFormat = stream->GetVideoFormat();
@@ -188,7 +191,7 @@ int DVD::AddPgc(int tsi, bool menu, Pgc* pgc) {
 
 /** Returns PGCs array */
 PgcArray& DVD::GetPgcArray(int tsi, bool menus) {
-	if (tsi >= 0 && tsi < (int) GetTitlesets().Count()) {
+	if (tsi >= 0 && tsi < (int) GetTitlesets().size()) {
 		Titleset* ts = GetTitlesets()[tsi];
 		if (menus)
 			return ts->GetMenus();
@@ -199,6 +202,8 @@ PgcArray& DVD::GetPgcArray(int tsi, bool menus) {
 }
 /** Returns PGC from given titleset */
 Pgc* DVD::GetPgc(int tsi, bool isMenu, int pgci) {
+	if (tsi >= (int) GetTitlesets().size())
+		return NULL;
 	PgcArray& pgcs = GetPgcArray(tsi, isMenu);
 	return pgci >= 0 && pgci < (int) pgcs.Count() ? pgcs[pgci] : NULL;
 }
@@ -244,8 +249,10 @@ bool DVD::CheckMenus() {
 	for (int tsi = -1; tsi < (int) GetTitlesets().Count(); tsi++) {
 		PgcArray& pgcs = GetPgcArray(tsi, true);
 		bool hasRootMenu = false;
+		bool hasTitleMenu = false;
 		for (unsigned int pgci = 0; pgci < pgcs.GetCount(); pgci++) {
 			hasRootMenu = hasRootMenu || pgcs[pgci]->GetEntries().find(wxT("root")) != pgcs[pgci]->GetEntries().end();
+			hasTitleMenu = hasTitleMenu || pgcs[pgci]->GetEntries().find(wxT("title")) != pgcs[pgci]->GetEntries().end();
 			Menu* menu = pgcs[pgci]->GetMenu();
 			if (menu) {
 				wxString src = DVDAction::GetSourceStr(this, tsi, pgci, true, wxT("")) + wxString(wxT(": "));
@@ -272,6 +279,9 @@ bool DVD::CheckMenus() {
 		if (!hasRootMenu && tsi >= 0 && pgcs.GetCount() > 0) {
 			pgcs[0]->GetEntries().insert(wxT("root"));
 		}
+		if (!hasTitleMenu && tsi == -1 && pgcs.GetCount() > 0) {
+			pgcs[0]->GetEntries().insert(wxT("title"));
+		}
 	}
 	return true;
 }
@@ -342,6 +352,18 @@ bool DVD::CheckActions(bool skipInvalidTarget) {
 	return valid;
 }
 
+/** Updates menus locations. Call it after moving of menus. */
+void DVD::UpdateMenusLocations() {
+	for (int tsi = -1; tsi < (int) GetTitlesets().GetCount(); tsi++) {
+		PgcArray& pgcs = GetPgcArray(tsi, true);
+		for (unsigned int pgci = 0; pgci < pgcs.GetCount(); pgci++) {
+			Menu* menu = pgcs[pgci]->GetMenu();
+			if (menu)
+				menu->UpdateMenuLocation(tsi, pgci);
+		}
+	}
+}
+
 /** Updates image in buttons with given jump action */
 bool DVD::UpdateButtonImageFor(int actionTsi, int actionPgci) {
 	bool result = false;
@@ -413,8 +435,33 @@ void DVD::SetDefPostCommand(DefaultPostCommand defPostCommand, bool updateTitles
 	}
 }
 
+wxSvgXmlNode* findTitleSelectionMenu(DVD* dvd) {
+	// find title selection menu
+	int tsi = dvd->GetVmgm().size() > 0 ? -1 : 0;
+	int pgci = -1;
+	PgcArray& menus = dvd->GetPgcArray(tsi, true);
+	for (unsigned int menuIdx = 0; menuIdx < menus.GetCount(); menuIdx++) {
+		Menu* menu = menus[menuIdx]->GetMenu();
+		if (!menu)
+			continue;
+		if ((menu->GetButtonByJumpAction(-2, 0) && menu->GetButtonByJumpAction(-2, 1) && menu->GetButtonByJumpAction(-2, 2))
+				|| (menu->GetButtonByJumpAction(0, 0) && menu->GetButtonByJumpAction(0, 1) && menu->GetButtonByJumpAction(0, 2))
+				|| (menu->GetButtonByJumpAction(0, 0) && menu->GetButtonByJumpAction(1, 0) && menu->GetButtonByJumpAction(2, 0))) {
+			pgci = menuIdx;
+			break;
+		}
+	}
+	if (pgci >= 0) {
+		Vob* vob = dvd->GetVob(tsi, true, pgci, 0);
+		if (vob && vob->GetMenu()) {
+			return vob->GetMenu()->GetXML(DVDSTYLER_XML);
+		}
+	}
+	return NULL;
+}
+
 /** Loads a project file */
-bool DVD::Open(wxString fname) {
+bool DVD::Open(wxString fname, wxProgressDialog* progressDlg) {
 	wxSvgXmlDocument xml;
 	if (!xml.Load(fname)) {
 		wxLogError(_("Cannot open file '%s'."), fname.c_str());
@@ -431,11 +478,25 @@ bool DVD::Open(wxString fname) {
 		m_templateFile = fname;
 	else
 		m_filename = fname;
-	return PutXML(xml);
+	if (!PutXML(xml, progressDlg))
+		return false;
+
+
+	if (m_templateFile == fname) {
+		titleMenuTemplate = findTitleSelectionMenu(this);
+	} else if (m_templateFile.length()) {
+		wxLogNull log;
+		DVD* dvd = new DVD();
+		if (dvd->Open(m_templateFile))
+			titleMenuTemplate = findTitleSelectionMenu(this);
+		delete dvd;
+	}
+
+	return true;
 }
 
 /** Initializes object with XML data */
-bool DVD::PutXML(const wxSvgXmlDocument& xml) {
+bool DVD::PutXML(const wxSvgXmlDocument& xml, wxProgressDialog* progressDlg) {
 	WX_CLEAR_ARRAY(GetTitlesets());
 
 	wxSvgXmlNode* root = xml.GetRoot();
@@ -453,8 +514,8 @@ bool DVD::PutXML(const wxSvgXmlDocument& xml) {
 		format = int(lval);
 	if (root->GetPropVal(wxT("template"), &val)) {
 		if (!wxFileName(val).IsAbsolute()) {
-			wxStandardPaths paths;
-			wxString templateDir = paths.GetUserDataDir() + wxFILE_SEP_PATH + wxT("templates") + wxFILE_SEP_PATH;
+			wxString templateDir = wxStandardPaths::Get().GetUserDataDir() + wxFILE_SEP_PATH + wxT("templates")
+					+ wxFILE_SEP_PATH;
 			if (wxFileExists(TEMPLATES_DIR + val))
 				m_templateFile = TEMPLATES_DIR + val;
 			else if (wxFileExists(templateDir + val))
@@ -466,6 +527,8 @@ bool DVD::PutXML(const wxSvgXmlDocument& xml) {
 		} else
 			m_templateFile = val;
 	}
+	if (root->GetPropVal(wxT("outputDir"), &val))
+		m_outputDir = val;
 	if (root->GetPropVal(wxT("isoFile"), &val))
 		m_isoFile = val;
 	if (root->GetPropVal(wxT("capacity"), &val) && val.ToLong(&lval))
@@ -502,13 +565,13 @@ bool DVD::PutXML(const wxSvgXmlDocument& xml) {
 					wxPropDlg::GetColourData().SetCustomColour(i, wxColour(r, g, b));
 			}
 		} else if (child->GetName() == wxT("vmgm")) {
-			if (!GetVmgm().PutXML(child, this)) {
+			if (!GetVmgm().PutXML(child, this, progressDlg)) {
 				wxLogError(_("Can't load vmgm menus"));
 				return false;
 			}
 		} else if (child->GetName() == wxT("titleset")) {
 			Titleset* titleset = new Titleset;
-			if (titleset->PutXML(child, this, GetTitlesets().GetCount()))
+			if (titleset->PutXML(child, this, GetTitlesets().GetCount(), progressDlg))
 				GetTitlesets().Add(titleset);
 			else {
 				delete titleset;
@@ -533,14 +596,15 @@ wxSvgXmlDocument* DVD::GetXml() {
 	if (m_templateFile.length() > 0) {
 		wxString tplName = m_templateFile;
 		wxString dir = TEMPLATES_DIR;
-		wxStandardPaths paths;
-		wxString dir2 = paths.GetUserDataDir() + wxFILE_SEP_PATH + wxT("templates") + wxFILE_SEP_PATH;
+		wxString dir2 = wxStandardPaths::Get().GetUserDataDir() + wxFILE_SEP_PATH + wxT("templates") + wxFILE_SEP_PATH;
 		if (tplName.StartsWith(dir))
 			tplName = tplName.substr(dir.length());
 		else if (tplName.StartsWith(dir2))
 			tplName = tplName.substr(dir2.length());
 		root->AddProperty(wxT("template"), tplName);
 	}
+	if (m_outputDir.length() > 0)
+		root->AddProperty(wxT("outputDir"), m_outputDir);
 	if (m_isoFile.length() > 0)
 		root->AddProperty(wxT("isoFile"), m_isoFile);
 	root->AddProperty(wxT("name"), m_label);
@@ -607,7 +671,7 @@ void DVD::Deserialize(const wxString& data) {
 	wxStringInputStream stream(data);
 	wxSvgXmlDocument xml;
 	xml.Load(stream);
-	PutXML(xml);
+	PutXML(xml, NULL);
 }
 
 bool DVD::SaveDVDAuthor(wxString fname) {
@@ -639,10 +703,11 @@ bool DVD::SaveDVDAuthor(wxString fname) {
 }
 
 void DVD::RenderThumbnail(wxString fname) {
-	Vob* vob = GetVob(0, true, 0, 0);
+	int tsi = GetVmgm().size() > 0 ? -1 : 0;
+	Vob* vob = GetVob(tsi, true, 0, 0);
 	if (vob == NULL || vob->GetMenu() == NULL)
 		return;
-	Vob* vob2 = GetVob(0, true, 1, 0);
+	Vob* vob2 = GetVob(tsi, true, 1, 0);
 	if (vob2) {
 		wxImage img1 = vob->GetMenu()->GetImage(102, 54);
 		wxImage img2 = vob2->GetMenu()->GetImage(102, 54);
@@ -668,7 +733,7 @@ long DVD::GetSize(bool afterTranscoding) {
 	for (int tsi = -1; tsi<(int)GetTitlesets().Count(); tsi++) {
 		for (int m=0; m<=1; m++) {
 			bool menu = m == 0;
-			if (tsi == -1 && !menu) // "titleset -1" contains only vmMenus
+			if (tsi == -1 && !menu) // "titleset -1" contains only vmgm menus
 				break;
 			PgcArray& pgcs = GetPgcArray(tsi, menu);
 			for (int pgci = 0; pgci<(int)pgcs.Count(); pgci++) {
@@ -688,7 +753,7 @@ long DVD::GetRequiredSize(Cache* cache) {
 	for (int tsi = -1; tsi<(int)GetTitlesets().Count(); tsi++) {
 		for (int m=0; m<=1; m++) {
 			bool menu = m == 0;
-			if (tsi == -1 && !menu) // "titleset -1" contains only vmMenus
+			if (tsi == -1 && !menu) // "titleset -1" contains only vmgm menus
 				break;
 			PgcArray& pgcs = GetPgcArray(tsi, menu);
 			for (int pgci = 0; pgci<(int)pgcs.Count(); pgci++) {
@@ -764,7 +829,7 @@ bool DVD::IsRegisterUsed(int g) {
 	for (int tsi = -1; tsi<(int)GetTitlesets().Count(); tsi++) {
 		for (int m=0; m<=1; m++) {
 			bool menu = m == 0;
-			if (tsi == -1 && !menu) // titleset -1 is Video-Manager and contains only vmMenus
+			if (tsi == -1 && !menu) // titleset -1 is contains only vmgm menus
 				continue;
 			PgcArray& pgcs = GetPgcArray(tsi, menu);
 			for (int pgci = 0; pgci<(int)pgcs.Count(); pgci++) {
