@@ -3,7 +3,7 @@
 // Purpose:     Stores a DVD Action
 // Author:      Alex Thuering
 // Created:     03.09.2009
-// RCS-ID:      $Id: DVDAction.cpp,v 1.28 2012/12/23 17:26:15 ntalex Exp $
+// RCS-ID:      $Id: DVDAction.cpp,v 1.31 2014/02/17 16:47:48 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -64,7 +64,7 @@ wxString DVDAction::AsString(DVD* dvd, bool translate) {
 		if (translate) {
 			if (s_entries.Index(entry) >= 0) {
 				const wxString jumpToEntry[6] = {
-						_("jump to title vmMenu"), _("jump to root menu"), _("jump to subtitle menu"),
+						_("jump to title menu"), _("jump to root menu"), _("jump to subtitle menu"),
 						_("jump to audio menu"), _("jump to angle menu"), _("jump to chapter menu")};
 				action += jumpToEntry[s_entries.Index(entry)];
 				Menus& menus = (Menus&) dvd->GetPgcArray(tsi, true);
@@ -74,17 +74,20 @@ wxString DVDAction::AsString(DVD* dvd, bool translate) {
 			} else {
 				action += _("jump to menu") + wxString(wxT(" entry ")) + entry;
 			}
-		} else
-			action += wxT(" menu entry ") + entry;
+		} else if (tsi == -1) {
+			action += wxT("vmgm menu entry ") + entry;
+		} else {
+			action += wxT("menu entry ") + entry;
+		}
 	} else {
 		int n = pgci + 1;
 		if (m_vmg && !menu && !translate) // use sequence number of title for jumping to title from vmg
 			for (int i = 0; i < tsi; i++)
-				n += dvd->GetTitlesets()[i]->GetTitles().Count();
+				n += i < (int) dvd->GetTitlesets().size() ? dvd->GetTitlesets()[i]->GetTitles().size() : 1;
 		
 		if (menu) {
 			if (tsi == -1)
-				action += translate ? _("jump to vmMenu") : wxT("vmgm menu");
+				action += translate ? _("jump to VMGM menu") : wxT("vmgm menu");
 			else
 				action += translate ? _("jump to menu") : wxT("menu");
 			if (tsi < 0 || n > 1 || translate)
@@ -178,7 +181,7 @@ wxString DVDAction::GetSourceStr(DVD* dvd, int tsi, int pgci, bool menu, wxStrin
 			source = _("titleset") + wxString::Format(wxT(" %d "), tsi + 1);
 		source += (menu ? _("menu") : _("title")) + wxString::Format(wxT(" %d"), pgci + 1);
 	} else
-		source = _("vmMenu") + wxString::Format(wxT(" %d"), pgci + 1);
+		source = _("VMGM menu") + wxString::Format(wxT(" %d"), pgci + 1);
 	if (buttonId.Length())
 		source += wxT(" ") + buttonId;
 	return source;
@@ -196,7 +199,7 @@ bool validateJumpTarget(wxString msgPrefix, DVD* dvd, int tsi, int pgci, bool me
 		int menuCount = menus.Count() > 0 ? menus.Count() : (dvd->IsEmptyMenuEnabled() && dvd->HasMenus() ? 1 : 0);
 		if (menuCount == 0) {
 			if (tsi == -1)
-				wxLogError(msgPrefix + _("cannot jump to vmMenu; none exist"));
+				wxLogError(msgPrefix + _("cannot jump to VMGM menu; none exist"));
 			else
 				wxLogError(msgPrefix + _("cannot jump to menu; none exist"));
 			return false;
@@ -212,7 +215,7 @@ bool validateJumpTarget(wxString msgPrefix, DVD* dvd, int tsi, int pgci, bool me
 			}
 		} else if (pgci >= menuCount) {
 			if (tsi == -1)
-				wxLogError(msgPrefix + _("cannot jump to vmMenu %d, only %d exist"), pgci + 1, menuCount);
+				wxLogError(msgPrefix + _("cannot jump to VMGM menu %d, only %d exist"), pgci + 1, menuCount);
 			else
 				wxLogError(msgPrefix + _("cannot jump to menu %d, only %d exist"), pgci + 1, menuCount);
 			return false;
@@ -248,7 +251,7 @@ wxString GetJumpFormError(bool toMenu, bool fromMenu) {
 		msg = _("cannot jump to a specific menu in another titleset, only to root/chapter/audio/subtitle/angle menu");
 	} else { // jump to title from another titleset
 		if (fromMenu)
-			msg = _("cannot jump from regular menu to a title in another titleset, use vmMenu instead");
+			msg = _("cannot jump from regular menu to a title in another titleset, use VMGM menu instead");
 		else
 			msg = _("cannot jump to a title in another titleset");
 	}
@@ -280,7 +283,7 @@ bool DVDAction::IsValid(DVD* dvd, int tsi, int pgci, bool menu, wxString buttonI
 			res = false;
 		} else if (tsi == -1 && m_chapter > 0 && !dvd->IsJumppadsEnabled()) {
 			wxString target = m_chapter < 65536 ? _("chapter") : (m_chapter < 131072 ? _("program") : _("cell"));
-			wxLogError(msgPrefix + _("jumping from vmMenu to %s is not allowed"), target.c_str());
+			wxLogError(msgPrefix + _("jumping from VMGM menu to %s is not allowed"), target.c_str());
 			return false;
 		} else {
 			if (!skipInvalidTarget)
@@ -396,7 +399,7 @@ bool validateJump(wxString msgPrefix, DVD* dvd, const struct vm_statement *cs, i
 	} else if (ismenu == VTYPE_VMGM && i2 >= 128 && i3) { // jump from vmgm to title chapter/program/cell
 		if (!dvd->IsJumppadsEnabled()) {
 			wxString target = i3 < 65536 ? _("chapter") : (i3 < 131072 ? _("program") : _("cell"));
-			wxLogError(msgPrefix + _("jumping from vmMenu to %s is not allowed"), target.c_str());
+			wxLogError(msgPrefix + _("jumping from VMGM menu to %s is not allowed"), target.c_str());
 			return false;
 		}
 	} else if (!i1 && !i2 && i3) {
