@@ -3,7 +3,7 @@
 // Purpose:     Stores a DVD Action
 // Author:      Alex Thuering
 // Created:     03.09.2009
-// RCS-ID:      $Id: DVDAction.h,v 1.14 2012/03/29 21:19:22 ntalex Exp $
+// RCS-ID:      $Id: DVDAction.h,v 1.16 2014/01/20 15:35:53 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -19,7 +19,10 @@ class wxSvgXmlNode;
 
 class DVDAction {
 public:
+	/** Constructor */
 	DVDAction(bool vmg = false, wxString id = wxT(""));
+	/** Sets if it's a vmgm menu */
+	inline void SetVmg(bool vmg) { m_vmg = vmg; }
 	
 	wxString GetId() { return m_id; }
 	void SetId(const wxString& id) { m_id = id; }
