@@ -3,7 +3,7 @@
 // Purpose:     DVD properties dialog
 // Author:      Alex Thuering
 // Created:     7.03.2005
-// RCS-ID:      $Id: DVDPropDlg.cpp,v 1.35 2013/01/10 15:29:57 ntalex Exp $
+// RCS-ID:      $Id: DVDPropDlg.cpp,v 1.38 2014/01/28 18:03:15 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -17,6 +17,7 @@ DVDPropDlg::DVDPropDlg(wxWindow *parent, DVD* dvd): NewProjectDlg(parent, false)
 }
 
 void DVDPropDlg::CreatePropPanel(wxSizer* sizer) {
+	// DVD properties
 	CreateDVDPropPanel(sizer, m_dvd);
 	
 	wxFlexGridSizer* grid = sizer ? new wxFlexGridSizer(2, 1, 16) : NULL;
@@ -24,10 +25,11 @@ void DVDPropDlg::CreatePropPanel(wxSizer* sizer) {
 		grid->AddGrowableCol(1);
 		sizer->Add(grid, 0, wxEXPAND|wxALL, 6);
 	}
-	AddComboProp(grid, _("First Play Commands:"), sizer ? m_dvd->GetVmgm().GetFpc() : wxT(""), GetFPCommands());
+	wxString fpc = sizer ? m_dvd->GetVmgm().GetFpc() : wxT("");
+	AddComboProp(grid, _("First Play Commands:"), fpc, GetFPCommands());
 
 	AddCheckProp(sizer, _("Create jumppads"), sizer ? m_dvd->IsJumppadsEnabled() : false);
-	AddCheckProp(sizer, _("Create empty menu/vmMenu if it doesn't exist"), sizer ? m_dvd->IsEmptyMenuEnabled() : true);
+	AddCheckProp(sizer, _("Create empty VMGM/titleset menus if it doesn't exist"), sizer ? m_dvd->IsEmptyMenuEnabled() : true);
 }
 
 /**
