@@ -3,7 +3,7 @@
 // Purpose:     Main window
 // Author:      Alex Thuering
 // Created:     10.10.2003
-// RCS-ID:      $Id: MainWin.cpp,v 1.171 2013/04/06 17:46:48 ntalex Exp $
+// RCS-ID:      $Id: MainWin.cpp,v 1.185 2014/03/10 12:20:44 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -19,6 +19,7 @@
 #include "Config.h"
 #include "MPEG.h"
 #include <wxVillaLib/VerticalToolbar.h>
+#include <wxVillaLib/SingleThumbnailDlg.h>
 #include <wxVillaLib/utils.h>
 #include <wx/imaglist.h>
 #include <wx/filename.h>
@@ -91,6 +92,7 @@ BEGIN_EVENT_TABLE(MainWin, wxFrame)
     EVT_MENU(MENU_DVD_ADD_FILE_AS_CHAPTER_ID, MainWin::OnAddFileAsChapter)
     EVT_MENU(MENU_DVD_ADD_TITLES_FROM_DVD_ID, MainWin::OnAddTitlesFromDVD)
     EVT_MENU(MENU_DVD_ADD_MENU_ID, MainWin::OnAddMenu)
+    EVT_MENU(MENU_DVD_ADD_CHAPTER_MENU_ID, MainWin::OnAddChapterMenu)
     EVT_MENU(MENU_DVD_ADD_VMMENU_ID, MainWin::OnAddVmMenu)
     EVT_MENU(MENU_DVD_ADD_TITLESET_ID, MainWin::OnAddTitleset)
     EVT_MENU(MENU_DVD_OPTIONS_ID, MainWin::OnDVDOptions)
@@ -98,6 +100,7 @@ BEGIN_EVENT_TABLE(MainWin, wxFrame)
     EVT_MENU(wxID_HELP_CONTENTS, MainWin::OnHelpContents)
     EVT_MENU(wxID_ABOUT, MainWin::OnAbout)
     // end wxGlade
+    EVT_UPDATE_UI(MENU_DVD_ADD_CHAPTER_MENU_ID, MainWin::OnAddChapterMenuUpdateUI)
     EVT_UPDATE_UI(MENU_DVD_ADD_TITLESET_ID, MainWin::OnAddTitlesetUpdateUI)
     EVT_UPDATE_UI(wxID_UNDO, MainWin::OnUpdateUIUndo)
 	EVT_UPDATE_UI(wxID_REDO, MainWin::OnUpdateUIRedo)
@@ -174,7 +177,8 @@ MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
     wxglade_tmp_menu_3_sub->Append(MENU_DVD_ADD_FILE_AS_CHAPTER_ID, _("File as &chapter..."), wxEmptyString, wxITEM_NORMAL);
     wxglade_tmp_menu_3_sub->Append(MENU_DVD_ADD_TITLES_FROM_DVD_ID, _("Titles from &DVD..."), wxEmptyString, wxITEM_NORMAL);
     wxglade_tmp_menu_3_sub->Append(MENU_DVD_ADD_MENU_ID, _("&Menu"), wxEmptyString, wxITEM_NORMAL);
-    wxglade_tmp_menu_3_sub->Append(MENU_DVD_ADD_VMMENU_ID, _("&vmMenu"), wxEmptyString, wxITEM_NORMAL);
+    wxglade_tmp_menu_3_sub->Append(MENU_DVD_ADD_CHAPTER_MENU_ID, _("&Chapter menu"), wxEmptyString, wxITEM_NORMAL);
+    wxglade_tmp_menu_3_sub->Append(MENU_DVD_ADD_VMMENU_ID, _("&VMGM menu"), wxEmptyString, wxITEM_NORMAL);
     wxglade_tmp_menu_3_sub->Append(MENU_DVD_ADD_TITLESET_ID, _("&Titleset"), wxEmptyString, wxITEM_NORMAL);
     wxglade_tmp_menu_3->Append(wxID_ANY, _("&Add"), wxglade_tmp_menu_3_sub, wxEmptyString);
     wxglade_tmp_menu_3->AppendSeparator();
@@ -237,7 +241,7 @@ MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
 	AspectRatio ar = (AspectRatio) s_config.GetDefAspectRatio();
 	DiscCapacity dc = (DiscCapacity) s_config.GetDefDiscCapacity();
 	NewDVD(wxT(""), wxT(""), s_config.GetDefDiscLabel(), dc, s_config.GetVideoBitrate(), s_config.GetAudioBitrate(),
-			vf <= vfCOPY ? vfPAL : vf, af <= afCOPY ? afMP2 : af, ar <= arAUTO ? ar4_3 : ar, cmdCALL_LAST_MENU);
+			vf <= vfCOPY ? vfPAL : vf, af <= afCOPY ? afMP2 : af, ar <= arAUTO ? ar4_3 : ar);
 
 	// Restore frame size/position
 	if (s_config.IsMainWinMaximized()) {
@@ -324,11 +328,10 @@ void MainWin::set_properties() {
 	
     // dir bar
 #ifdef __WXMAC__
-	const wxSize imageSize(16, 16);
-	m_dirBookImages = new wxImageList(imageSize.x, imageSize.y);
-	m_dirBookImages->Add(wxArtProvider::GetBitmap(wxART_FOLDER, wxART_TOOLBAR, imageSize)
-						 .ConvertToImage().Rotate90().Rotate90());
-	m_dirBook->SetImageList(m_dirBookImages);
+//	const wxSize imageSize(16, 16);
+//	m_dirBookImages = new wxImageList(imageSize.x, imageSize.y);
+//	m_dirBookImages->Add(wxArtProvider::GetBitmap(wxART_FOLDER, wxART_TOOLBAR, imageSize).ConvertToImage().Rotate90().Rotate90());
+//	m_dirBook->SetImageList(m_dirBookImages);
 	m_dirBook->AddPage(new wxPanel(m_dirBook), _("File browser"), false, 0);
 	m_dirBook->AddPage(new wxPanel(m_dirBook), _("Backgrounds"));
 	m_dirBook->AddPage(new wxPanel(m_dirBook), _("Buttons"));
@@ -393,7 +396,7 @@ void MainWin::ShowDirTree(bool show) {
 		m_dirTree->Show(true);
 	} else if (!show && m_splitterDir->IsSplit()) {
 		m_splitterDirSash = m_splitterDir->GetSashPosition();
-
+#ifndef __WXMAC__
 		// animate unsplitting
 		m_dirTree->Freeze();
 		wxStopWatch sw;
@@ -407,6 +410,7 @@ void MainWin::ShowDirTree(bool show) {
 				step = sw.Time();
 			pos -= int(step);
 		}
+#endif
 		m_splitterDir->Unsplit(m_dirTree);
 		m_dirTree->SetSize(0, 0);
 		m_dirTree->Thaw();
@@ -432,8 +436,7 @@ void MainWin::OnBackgroundsBt(wxCommandEvent& event) {
 			m_thumbnails->InsertItem(new wxThumb(fname));
 		fname = wxFindNextFile();
 	}
-	wxStandardPaths paths;
-	wxString bgDir = paths.GetUserDataDir() + wxFILE_SEP_PATH + wxT("backgrounds") + wxFILE_SEP_PATH;
+	wxString bgDir = wxStandardPaths::Get().GetUserDataDir() + wxFILE_SEP_PATH + wxT("backgrounds") + wxFILE_SEP_PATH;
 	if (wxDirExists(bgDir)) {
 		fname = wxFindFirstFile(bgDir + wxT("*"));
 		while (!fname.IsEmpty()) {
@@ -555,13 +558,22 @@ void MainWin::OnTitleInfo(wxCommandEvent& event) {
 				DVD::GetPgci(id), DVD::GetVobi(id));
 		if (vob) {
 			text = vob->GetFilenameDisplay();
+			double duration = vob->GetDuration();
+			if (vob->GetSlideshow()) {
+				text = wxString::Format(_("%d slides"), vob->GetSlideshow()->GetCount());
+				duration = vob->GetSlideshow()->GetResultDuration();
+			}
 			for (unsigned int i=0; i<vob->GetAudioFilenames().Count(); i++)
 				text += (text.length() ? wxT(" + ") : wxT("Video + ")) + vob->GetAudioFilenames()[i];
 			for (unsigned int i=0; i<vob->GetSubtitles().Count(); i++)
 				text += wxT(" + ") + vob->GetSubtitles()[i]->GetFilename();
-			if (text.length()) {
-				wxString unit = _("min");
-				int dur = vob->GetDuration() >= 60 ? (int)(vob->GetDuration()/60) : 1;
+			if (text.length() && duration > 0) {
+				wxString unit = _("sec");
+				int dur = (int) duration;
+				if (dur >= 60) {
+					dur = lround(duration/60);
+					unit = _("min");
+				}
 				text += wxString::Format(wxT(" (%d %s)"), dur, unit.c_str());
 			}
 		}
@@ -659,7 +671,7 @@ void MainWin::OnClose(wxCloseEvent &event) {
 
 void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLabel, DiscCapacity capacity,
 		int videoBitrate, int audioBitrate, VideoFormat videoFormat, AudioFormat audioFormat, AspectRatio aspectRatio,
-		DefaultPostCommand defPostCommand) {
+		DefaultPostCommand defPostCommand, bool chapterMenu) {
 	if (aspectRatio == ar16_9 && templateFile.Length()
 			&& wxFile::Exists(templateFile.substr(0, templateFile.length()-5) + wxT("WS.dvdt")))
 		templateFile = templateFile.substr(0, templateFile.length()-5) + wxT("WS.dvdt");
@@ -673,6 +685,57 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 		m_dvd->SetAudioFormat(audioFormat);
 		m_dvd->SetAspectRatio(aspectRatio);
 		m_dvd->SetDefPostCommand(defPostCommand);
+		if (m_dvd->GetTitlesets().size() && m_dvd->GetTitlesets()[0]->GetMenus().size()) {
+			// move menus to VMG
+			Menus& menus = m_dvd->GetTitlesets()[0]->GetMenus();
+			Menus& vmMenus = m_dvd->GetVmgm();
+			while (menus.size()) {
+				vmMenus.push_back(menus.front());
+				menus.erase(menus.begin());
+			}
+			m_dvd->UpdateMenusLocations();
+			// fix button actions
+			for (unsigned int mIdx = 0; mIdx < vmMenus.size(); mIdx++) {
+				Menu* menu = vmMenus[mIdx]->GetMenu();
+				if (!menu)
+					continue;
+				vmMenus[mIdx]->GetEntries().clear();
+				if (mIdx == 0) {
+					vmMenus[mIdx]->GetEntries().insert(wxT("title"));
+				}
+				for (unsigned int objIdx = 0; objIdx < menu->GetObjectsCount(); objIdx++) {
+					MenuObject* obj = menu->GetObject(objIdx);
+					DVDAction& action = obj->GetAction();
+					if (!obj->IsButton() || action.IsCustom() || action.GetPgci() == -1 || action.GetTsi() >= 0
+							|| action.IsMenu())
+						continue;
+					action.SetTsi(0);
+				}
+			}
+		}
+		if (chapterMenu && m_dvd->GetVmgm().size() == 2) {
+			// remove title selection menu
+			m_dvd->GetVmgm().erase(m_dvd->GetVmgm().begin() + 1);
+			// add chapters menu
+			m_titlesetManager->CreateChapterMenu(0, 1);
+			// fix button action
+			Menu* menu = m_dvd->GetMenu(-1, 0);
+			if (menu) {
+				MenuObject* menuButton = menu->GetButtonByJumpAction(-2, 1, true);
+				if (menuButton) {
+					menuButton->GetAction().SetTsi(0);
+					menuButton->GetAction().SetPgci(0);
+					MenuObjectParam* initParam = menuButton->GetInitParam();
+					if (initParam && (initParam->type == wxT("text") || initParam->type == wxT("string"))) {
+						wxString value = menuButton->GetParam(initParam->name);
+						if (value == wxT("Select Title") || value == wxT("Select title"))
+							value = _("Select chapter");
+						menuButton->SetParam(initParam->name, value);
+						menuButton->UpdateSize();
+					}
+				}
+			}
+		}
 		for (int tsi = -1; tsi < (int) m_dvd->GetTitlesets().GetCount(); tsi++) {
 			if (tsi >= 0) {
 				PgcArray& titles = m_dvd->GetPgcArray(tsi, false);
@@ -682,13 +745,13 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 			PgcArray& menus = m_dvd->GetPgcArray(tsi, true);
 			menus.GetVideo().SetFormat(videoFormat);
 			menus.GetVideo().SetAspect(aspectRatio);
-			for (unsigned int mi = 0; mi < menus.GetCount(); mi++) {
-				Menu* menu = menus[mi]->GetMenu();
+			for (unsigned int mIdx = 0; mIdx < menus.GetCount(); mIdx++) {
+				Menu* menu = menus[mIdx]->GetMenu();
 				if (menu) {
 					menu->SetVideoFormat(videoFormat);
 					menu->SetAspectRatio(aspectRatio);
-					for (unsigned int obji = 0; obji < menu->GetObjectsCount(); obji++) {
-						MenuObject* obj = menu->GetObject(obji);
+					for (unsigned int objIdx = 0; objIdx < menu->GetObjectsCount(); objIdx++) {
+						MenuObject* obj = menu->GetObject(objIdx);
 						MenuObjectParam* initParam = obj->GetInitParam();
 						if (initParam && (initParam->type == wxT("text") || initParam->type == wxT("string"))) {
 							wxString value = obj->GetParam(initParam->name);
@@ -723,7 +786,7 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 		m_dvd->SetAspectRatio(aspectRatio);
 		m_dvd->SetDefPostCommand(defPostCommand);
 		m_dvd->AddTitleset();
-		m_dvd->AddMenu(0);
+		m_dvd->AddMenu(-1);
 	}
 	UpdateDVD();
 	SetChanged(false);
@@ -732,19 +795,19 @@ void MainWin::NewDVD(wxString templateFile, wxString discTitle, wxString discLab
 
 bool MainWin::Open(wxString filename) {
 	bool showProgressDlg = !filename.EndsWith(wxT(".dvdt"));
-	wxProgressDialog* pdlg = NULL;
+	wxProgressDialog* pDlg = NULL;
 	if (showProgressDlg) {
-		pdlg = new wxProgressDialog(wxT("DVDStyler"), _("Please wait..."), 99, this,
+		pDlg = new wxProgressDialog(wxT("DVDStyler"), _("Please wait..."), 99, this,
 				wxPD_APP_MODAL | wxPD_AUTO_HIDE | wxPD_SMOOTH);
-		pdlg->Show();
-		pdlg->SetFocus();
-		pdlg->Pulse();
+		pDlg->Show();
+		pDlg->SetFocus();
+		pDlg->Pulse();
 	}
 	
 	DVD* dvd = new DVD;
-	if (!dvd->Open(filename)) {
+	if (!dvd->Open(filename, pDlg)) {
 		delete dvd;
-		delete pdlg;
+		delete pDlg;
 		wxLogError(_("Error opening '%s'"), filename.c_str());
 		return false;
 	}
@@ -758,7 +821,7 @@ bool MainWin::Open(wxString filename) {
 	m_fileHistory.AddFileToHistory(m_dvd->GetFilename());
 	m_fileHistory.Save(*s_config.GetConfigBase());
 
-	delete pdlg;
+	delete pDlg;
 	return true;
 }
 
@@ -770,7 +833,18 @@ void MainWin::ShowOpenDlg() {
 		Open(dlg.GetPath());
 }
 
+/** Saves a project file */
+bool MainWin::Save(wxString fname) {
+	if (!m_dvd->Save(fname))
+		return false;
+	SetChanged(false);
+	m_fileHistory.AddFileToHistory(m_dvd->GetFilename());
+	m_fileHistory.Save(*s_config.GetConfigBase());
+	return true;
+}
+
 void MainWin::UpdateDVD() {
+	m_menuEditor->Clear();
 	m_titlesetManager->SetDVD(m_dvd);
 	m_titlesetManager->UpdateItems();
 	m_titlesetManager->SelectFirstMenu();
@@ -829,9 +903,6 @@ void MainWin::DoChangedDVD(bool doUndo) {
 	long size = m_dvd->GetSize();
 	long total = m_dvd->GetCapacityValue();
 	m_statusbar->SetFillStatus(size, total, b[1], b[2]/60, b[0], m_dvd->IsVideoBitrateAuto(), m_dvd->GetAudioBitrate());
-	// update selection
-	if (m_menuEditor->GetSelected().length())
-		m_menuEditor->Select(m_menuEditor->GetSelected());
 	m_menuEditor->ShowSafeTV();
 	m_menuEditor->Refresh();
 }
@@ -865,7 +936,7 @@ void MainWin::OnNew(wxCommandEvent& event) {
 		wxString templateFile = templateDlg.ShowModal() == wxID_OK ? templateDlg.GetTemplate() : wxT("");
 		NewDVD(templateFile, templateDlg.GetTitle(), dlg.GetLabel(), dlg.GetCapacity(), dlg.GetVideoBitrate(),
 				dlg.GetAudioBitrate(), dlg.GetVideoFormat(), dlg.GetAudioFormat(), dlg.GetAspectRatio(),
-				dlg.GetDefPostCommand());
+				dlg.GetDefPostCommand(), templateDlg.IsChapterMenu());
 	}
 }
 
@@ -877,8 +948,7 @@ void MainWin::OnOpen(wxCommandEvent& event) {
 
 void MainWin::OnSave(wxCommandEvent& event) {
 	if (m_dvd->GetFilename().length()) {
-		if (m_dvd->Save())
-			SetChanged(false);
+		Save();
 	} else
 		OnSaveAs(event);
 }
@@ -888,8 +958,7 @@ void MainWin::OnSaveAs(wxCommandEvent& event) {
 			_("Project files") + wxString(wxT(" (*.dvds;*.xml)|*.dvds;*.xml|"))
 			+ _("All Files") + wxString(wxT(" (*.*)|*.*")), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
 	dlg.Centre();
-	if (dlg.ShowModal() == wxID_OK && m_dvd->Save(dlg.GetPath())) {
-		SetChanged(false);
+	if (dlg.ShowModal() == wxID_OK && Save(dlg.GetPath())) {
 		m_lastDir = m_dvd->GetPath(false);
 		s_config.SetLastProjectDir(m_lastDir);
 	}
@@ -946,8 +1015,12 @@ please drag a video file into the bottom section of the window."), emptyTsi+1),
 	m_dvd->FixButtonCoordinates();
 	// show burn dialog
 	BurnDlg burnDlg(this, m_dvd, &m_cache);
-	if (!autoStart && burnDlg.ShowModal() != wxID_OK)
+	if (autoStart) {
+		if (!m_cache.SetTempDir(s_config.GetTempDir()))
+			return;
+	} else if (burnDlg.ShowModal() != wxID_OK) {
 		return;
+	}
 	// Progress dialog
 	ProgressDlg progressDlg(this, &m_cache, autoStart);
 	progressDlg.Start(&burnDlg, m_dvd);
@@ -984,6 +1057,10 @@ void MainWin::AddUndo() {
 }
 
 void MainWin::DoUndo(bool redo) {
+	if ((m_undoPos == 0 && !redo) || (m_undoPos >= m_undoHistory.size() - 1 && redo))
+		return;
+	m_menuEditor->Clear();
+
 	// restore
 	m_undoPos += redo ? 1 : -1;
 	m_dvd->Deserialize(m_undoHistory[m_undoPos].data);
@@ -1059,7 +1136,7 @@ void MainWin::AddFileDialog(bool asChapter) {
 			} else if (wxThumbnails::IsSubtitle(filename)) {
 				m_titlesetManager->AddSubtitles(filename);
 			} else if (wxImage::FindHandler(filename.AfterLast('.').Lower(), BITMAP_TYPE_ANY)) {
-				m_titlesetManager->AddImage(filename, !asChapter && i == 0);
+				m_titlesetManager->AddImage(filename, !asChapter && i == 0, i == paths.GetCount() - 1);
 			} else {
 				// try to load it as video
 				m_titlesetManager->AddVideo(filename, !asChapter);
@@ -1076,23 +1153,57 @@ void MainWin::OnAddTitlesFromDVD(wxCommandEvent& event) {
 	wxString dir = dialog.GetPath();
 	if (wxDirExists(dir + wxFILE_SEP_PATH + wxString(wxT("VIDEO_TS"))))
 		dir += wxFILE_SEP_PATH + wxString(wxT("VIDEO_TS"));
-	wxString vobs;
-	for (int i = 0; i < 100; i++) {
-		wxString fileName = dir + wxFILE_SEP_PATH + wxString::Format(wxT("VTS_01_%d.VOB"), i);
+
+	// search for VOB files
+	wxArrayString titlesets;
+	wxArrayString tsLabels;
+	while (true) {
+		wxString fileName = dir + wxFILE_SEP_PATH + wxString::Format(wxT("VTS_%02d_1.VOB"), titlesets.size() + 1);
 		if (!wxFileExists(fileName)) {
-			if (i == 0)
-				continue;
-			if (i == 1) {
+			if (titlesets.empty()) {
 				wxLogError(wxT("%s: no such file or directory"), fileName.c_str());
 				return;
 			}
 			break;
 		}
-		if (vobs.length() > 0)
-			vobs += wxT('|');
-		vobs = vobs + fileName;
+
+		wxString vobs;
+		for (int i = 1; i < 100; i++) {
+			wxString fileName = dir + wxFILE_SEP_PATH + wxString::Format(wxT("VTS_%02d_%d.VOB"), titlesets.size() + 1, i);
+			if (!wxFileExists(fileName)) {
+				if (i == 1) {
+					wxLogError(wxT("%s: no such file or directory"), fileName.c_str());
+					return;
+				}
+				break;
+			}
+			if (vobs.length() > 0)
+				vobs += wxT('|');
+			vobs = vobs + fileName;
+		}
+		titlesets.push_back(wxT("concat:") + vobs);
+
+		// determine titleset duration and load frame image
+		long duration = -1;
+		wxFfmpegMediaDecoder decoder;
+		if (decoder.Load(titlesets[titlesets.size() - 1])) {
+			duration = lround(decoder.GetDuration());
+		}
+		wxString label = wxString::Format(_T("Titleset %d"), titlesets.size());
+		if (duration > 0)
+			label += wxString::Format(wxT(" (%d:%02d:%02d)"), duration/3600, (duration/60) % 60, duration % 60);
+		tsLabels.push_back(label);
+	}
+
+	if (titlesets.size() == 1) {
+		m_titlesetManager->AddVideo(titlesets[0], true);
+	} else {
+		// select titleset
+		SingleThumbnailDlg dlg(this, _("Choose a titleset to add:"), wxT("DVDStyler"), titlesets, tsLabels);
+		dlg.SetSelection(0);
+		if (dlg.ShowModal() == wxID_OK)
+			m_titlesetManager->AddVideo(titlesets[dlg.GetSelection()], true);
 	}
-	m_titlesetManager->AddVideo(wxT("concat:") + vobs, true);
 }
 
 void MainWin::OnAddMenu(wxCommandEvent& event) {
@@ -1100,6 +1211,21 @@ void MainWin::OnAddMenu(wxCommandEvent& event) {
 	m_titlesetManager->AddMenu();
 }
 
+void MainWin::OnAddChapterMenu(wxCommandEvent& event) {
+	int tsi = m_titlesetManager->GetSelected() >= 0 ? DVD::GetTsi(m_titlesetManager->GetSelectedId())
+			: m_dvd->GetTitlesets().size() - 1;
+	if (tsi < 0)
+		tsi = 0;
+	m_titlesetManager->CreateChapterMenu(tsi, tsi >= 0 && m_dvd->GetTitlesets()[tsi]->GetTitles().size() > 0
+			? m_dvd->GetTitlesets()[tsi]->GetTitles()[0]->GetChapterCount() : 1);
+	m_titlesetManager->UpdateItems();
+	DoChangedDVD();
+}
+
+void MainWin::OnAddChapterMenuUpdateUI(wxUpdateUIEvent& event) {
+	event.Enable(m_dvd->GetTitleMenuTemplate() != NULL);
+}
+
 void MainWin::OnAddVmMenu(wxCommandEvent& event) {
 	m_titlesetManager->AddVmMenu();
 }
