@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu
 // Author:      Alex Thuering
 // Created:	04.11.2003
-// RCS-ID:      $Id: Menu.cpp,v 1.114 2013/08/15 07:06:45 ntalex Exp $
+// RCS-ID:      $Id: Menu.cpp,v 1.120 2014/02/03 14:27:47 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -65,6 +65,18 @@ wxSVGDocument* Menu::CreateSVG(int width, int height) {
 	return svg;
 }
 
+/** Updates menu location. Call it after moving of menus. */
+void Menu::UpdateMenuLocation(int tsi, int pgci) {
+	m_tsi = tsi;
+	m_pgci = pgci;
+	for (unsigned int obji = 0; obji < m_objects.size(); obji++) {
+		m_objects[obji]->GetAction().SetVmg(tsi == -1);
+	}
+	for (unsigned int actIdx = 0; actIdx < m_actions.size(); actIdx++) {
+		m_actions[actIdx]->SetVmg(tsi == -1);
+	}
+}
+
 void Menu::SetVideoFormat(VideoFormat videoFormat) {
 	m_videoFormat = videoFormat;
 }
@@ -438,14 +450,14 @@ wxSVGSVGElement* Menu::GetSVGCopy(MenuDrawType drawType) {
 ////////////////////////////// Render ////////////////////////////////////////
 
 wxImage Menu::RenderImage(MenuDrawType drawType, int width, int height, const wxSVGRect* rect,
-		bool preserveAspectRatio, bool alpha) {
+		bool preserveAspectRatio, bool alpha, wxProgressDialog* progressDlg) {
 	wxSVGDocument svg;
 	svg.AppendChild(GetSVGCopy(drawType));
-	return svg.Render(width, height, rect, preserveAspectRatio, alpha);
+	return svg.Render(width, height, rect, preserveAspectRatio, alpha, progressDlg);
 }
 
-wxImage Menu::GetImage(int width, int height) {
-	return RenderImage(mdALL, width, height, NULL, true);
+wxImage Menu::GetImage(int width, int height, wxProgressDialog* progressDlg) {
+	return RenderImage(mdALL, width, height, NULL, true, false, progressDlg);
 }
 
 wxImage Menu::GetBackgroundImage() {
@@ -690,11 +702,11 @@ wxString Menu::AddObject(wxString fileName, wxString param, int x, int y) {
 }
 
 /** Returns button with given jump action */
-MenuObject* Menu::GetButtonByJumpAction(int actionTsi, int actionPgci) {
+MenuObject* Menu::GetButtonByJumpAction(int actionTsi, int actionPgci, bool actionIsMenu) {
 	for (unsigned int obji = 0; obji < m_objects.GetCount(); obji++) {
 		MenuObject* obj = m_objects[obji];
 		if (obj->IsButton() && !obj->GetAction().IsCustom() && obj->GetAction().GetTsi() == actionTsi
-				&& obj->GetAction().GetPgci() == actionPgci && !obj->GetAction().IsMenu()) {
+				&& obj->GetAction().GetPgci() == actionPgci && obj->GetAction().IsMenu() == actionIsMenu) {
 			return obj;
 		}
 	}
@@ -706,9 +718,9 @@ bool Menu::UpdateButtonImageFor(int actionTsi, int actionPgci, DVD* dvd) {
 	bool result = false;
 	for (unsigned int obji = 0; obji < m_objects.GetCount(); obji++) {
 		MenuObject* obj = m_objects[obji];
-		if (obj->IsButton() && !obj->GetAction().IsCustom() && obj->IsDisplayVideoFrame()
-				&& obj->GetAction().GetTsi() == actionTsi && obj->GetAction().GetPgci() == actionPgci
-				&& !obj->GetAction().IsMenu()) {
+		DVDAction& action = obj->GetAction();
+		if (obj->IsButton() && !action.IsCustom() && obj->IsDisplayVideoFrame()	&& action.GetTsi() == actionTsi
+				&& action.GetPgci() == actionPgci && !action.IsMenu()) {
 			result = true; // action is found
 			for (int i = 0; i < obj->GetObjectParamsCount(); i++) {
 				MenuObjectParam* param = obj->GetObjectParam(i);
@@ -717,7 +729,7 @@ bool Menu::UpdateButtonImageFor(int actionTsi, int actionPgci, DVD* dvd) {
 					wxString uri;
 					long int pos = 0;
 					if (actionPgci < (int)pgcs.size()) {
-						uri = pgcs[actionPgci]->GetVideoFrameUri(obj->GetAction().GetChapter());
+						uri = pgcs[actionPgci]->GetVideoFrameUri(action.GetChapter());
 						uri.AfterLast(wxT('#')).ToLong(&pos);
 						uri = uri.Find(wxT('#')) >= 0 ? uri.BeforeLast(wxT('#')) : uri;
 					}
@@ -821,8 +833,8 @@ wxSvgXmlNode* Menu::GetXML(DVDFileType type, wxSvgXmlNode* node) {
 			wxString bgFile = GetBackground(svg);
 			if (bgFile.length() > 0) {
 				wxString dir = BACKGROUNDS_DIR;
-				wxStandardPaths paths;
-				wxString bgDir = paths.GetUserDataDir() + wxFILE_SEP_PATH + wxT("backgrounds") + wxFILE_SEP_PATH;
+				wxString bgDir = wxStandardPaths::Get().GetUserDataDir() + wxFILE_SEP_PATH + wxT("backgrounds")
+						+ wxFILE_SEP_PATH;
 				if (bgFile.StartsWith(dir))
 	 				SetBackground(svg, bgFile.substr(dir.length()));
 				else if (bgFile.StartsWith(bgDir))
@@ -910,10 +922,10 @@ bool Menu::PutXML(wxSvgXmlNode* node) {
 				bgRect->SetId(wxT("backgroundColour"));
 			// fix path
 			if (GetBackground().length() > 0) {
-				wxStandardPaths paths;
-				wxString bgDir = paths.GetUserDataDir() + wxFILE_SEP_PATH + wxT("backgrounds") + wxFILE_SEP_PATH;
+				wxString bgDir = wxStandardPaths::Get().GetUserDataDir() + wxFILE_SEP_PATH + wxT("backgrounds")
+						+ wxFILE_SEP_PATH;
 				wxFileName fn(GetBackground());
-				if (fn.IsRelative()) {
+				if (fn.IsRelative() && !GetBackground().StartsWith(wxT("concat:"))) {
 					if (wxFileExists(m_dvd->GetPath() + fn.GetFullPath()))
 						SetBackground(m_dvd->GetPath() + fn.GetFullPath());
 					else if (wxFileExists(m_dvd->GetPath() + fn.GetFullName()))
@@ -936,7 +948,7 @@ bool Menu::PutXML(wxSvgXmlNode* node) {
 					else // elem->GetDtd() == wxSVG_VIDEO_ELEMENT
 						uriElem = (wxSVGVideoElement*) elem;
 					wxString href = uriElem->GetHref();
-					if (href.length()) {
+					if (href.length() && !href.StartsWith(wxT("concat:"))) {
 						wxString frameStr;
 						if (href.Find(wxT('#')) > 0) {
 							frameStr = wxT('#') + href.AfterLast(wxT('#'));
