@@ -3,7 +3,7 @@
 // Purpose:     The widget to edit a DVD Menu
 // Author:      Alex Thuering
 // Created:     11.10.2003
-// RCS-ID:      $Id: MenuEditor.cpp,v 1.69 2013/01/07 14:40:03 ntalex Exp $
+// RCS-ID:      $Id: MenuEditor.cpp,v 1.74 2014/03/31 10:57:47 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -212,8 +212,14 @@ enum {
 	MENUEDITOR_ARRANGEMENU_BACKWARD_ID,
 	MENUEDITOR_ARRANGEMENU_TOBACK_ID,
 	MENUEDITOR_ALIGNMENU_ID,
+	MENUEDITOR_ALIGNMENU_TOCENTERMH_ID,
+	MENUEDITOR_ALIGNMENU_TOCENTERMV_ID,
 	MENUEDITOR_ALIGNMENU_TOCENTERH_ID,
 	MENUEDITOR_ALIGNMENU_TOCENTERV_ID,
+	MENUEDITOR_ALIGNMENU_TOLEFT_ID,
+	MENUEDITOR_ALIGNMENU_TORIGHT_ID,
+	MENUEDITOR_ALIGNMENU_TOTOP_ID,
+	MENUEDITOR_ALIGNMENU_TOBOTTOM_ID,
 	MENUEDITOR_VIEWMENU_ID,
 	MENUEDITOR_VIEWMENU_SAFETV_ID,
 	MENUEDITOR_GRIDMENU_ID = 8600,
@@ -250,8 +256,20 @@ BEGIN_EVENT_TABLE(MenuEditor, wxSVGCtrl)
   EVT_UPDATE_UI(MENUEDITOR_ARRANGEMENU_FORWARD_ID, MenuEditor::OnUpdateUIObjectForward)
   EVT_UPDATE_UI(MENUEDITOR_ARRANGEMENU_BACKWARD_ID, MenuEditor::OnUpdateUIObjectBackward)
   EVT_UPDATE_UI(MENUEDITOR_ARRANGEMENU_TOBACK_ID, MenuEditor::OnUpdateUIObjectBackward)
+  EVT_MENU(MENUEDITOR_ALIGNMENU_TOCENTERMH_ID, MenuEditor::OnAlignToCenterMH)
+  EVT_MENU(MENUEDITOR_ALIGNMENU_TOCENTERMV_ID, MenuEditor::OnAlignToCenterMV)
   EVT_MENU(MENUEDITOR_ALIGNMENU_TOCENTERH_ID, MenuEditor::OnAlignToCenterH)
   EVT_MENU(MENUEDITOR_ALIGNMENU_TOCENTERV_ID, MenuEditor::OnAlignToCenterV)
+  EVT_MENU(MENUEDITOR_ALIGNMENU_TOLEFT_ID, MenuEditor::OnAlignToLeft)
+  EVT_MENU(MENUEDITOR_ALIGNMENU_TORIGHT_ID, MenuEditor::OnAlignToRight)
+  EVT_MENU(MENUEDITOR_ALIGNMENU_TOTOP_ID, MenuEditor::OnAlignToTop)
+  EVT_MENU(MENUEDITOR_ALIGNMENU_TOBOTTOM_ID, MenuEditor::OnAlignToBottom)
+  EVT_UPDATE_UI(MENUEDITOR_ALIGNMENU_TOCENTERH_ID, MenuEditor::OnUpdateUIAlign)
+  EVT_UPDATE_UI(MENUEDITOR_ALIGNMENU_TOCENTERV_ID, MenuEditor::OnUpdateUIAlign)
+  EVT_UPDATE_UI(MENUEDITOR_ALIGNMENU_TOLEFT_ID, MenuEditor::OnUpdateUIAlign)
+  EVT_UPDATE_UI(MENUEDITOR_ALIGNMENU_TORIGHT_ID, MenuEditor::OnUpdateUIAlign)
+  EVT_UPDATE_UI(MENUEDITOR_ALIGNMENU_TOTOP_ID, MenuEditor::OnUpdateUIAlign)
+  EVT_UPDATE_UI(MENUEDITOR_ALIGNMENU_TOBOTTOM_ID, MenuEditor::OnUpdateUIAlign)
   EVT_MENU(MENUEDITOR_VIEWMENU_SAFETV_ID, MenuEditor::OnSafeTV)
   EVT_MENU(MENUEDITOR_GRIDMENU_ITEM_ID, MenuEditor::OnGridMenu)
   EVT_MENU(MENUEDITOR_GRIDMENU_ITEM_ID+1, MenuEditor::OnGridMenu)
@@ -294,8 +312,14 @@ MenuEditor::MenuEditor(wxWindow *parent, wxWindowID id): wxSVGCtrl(parent, id, w
 
 	// sub menu "Align"
 	wxMenu* alignMenu = new wxMenu;
-	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOCENTERH_ID, _("Center &Horizontally"));
-	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOCENTERV_ID, _("Center &Vertically"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOLEFT_ID, _("To &Left"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TORIGHT_ID, _("To &Right"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOTOP_ID, _("To &Top"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOBOTTOM_ID, _("To &Bottom"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOCENTERH_ID, _("To Center &horizontally"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOCENTERV_ID, _("To Center &vertically"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOCENTERMH_ID, _("To &Center of Menu horizontally"));
+	alignMenu->Append(MENUEDITOR_ALIGNMENU_TOCENTERMV_ID, _("To Center of &Menu vertically"));
 
 	// sub menu "Add"
 	wxMenu* addMenu = new wxMenu;
@@ -365,7 +389,7 @@ MenuEditor::MenuEditor(wxWindow *parent, wxWindowID id): wxSVGCtrl(parent, id, w
 }
 
 void MenuEditor::SetMenu(DVD* dvd, Menu* menu, int tsi, int pgci) {
-	if (menu != NULL) {
+	if (m_menu != NULL && m_doc != NULL) {
 		// remove old selection
 		for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
 			wxSVGRectElement* selRect = (wxSVGRectElement*) m_doc->GetElementById(wxT("selection_") + *it);
@@ -465,7 +489,7 @@ bool MenuEditor::AddButton(wxString fname, int x, int y, int pgci, int tsi, bool
 	}
 
 	wxString param;
-	tsi = tsi >= -1 ? tsi : m_tsi >= -1 ? m_tsi : 0;
+	tsi = tsi >= -1 ? tsi : (m_tsi > -1 || (m_tsi == -1 && isMenu) ? m_tsi : 0);
 
 	MenuObject tmpObj(NULL, false, fname);
 	MenuObjectParam* initParam = tmpObj.GetInitParam();
@@ -479,7 +503,7 @@ bool MenuEditor::AddButton(wxString fname, int x, int y, int pgci, int tsi, bool
 				param = wxFileName(pgc->GetVideoFrameUri(chapter)).GetName();
 		} else {
 			if (isMenu) {
-				param = wxString::Format(tsi == -1 ? _("vmMenu %d") : _("Menu %d"), pgci+1);
+				param = wxString::Format(tsi == -1 ? _("VMGM menu %d") : _("Menu %d"), pgci+1);
 			} else
 				param = wxString::Format(_("button%d"), btNum);
 		}
@@ -611,6 +635,53 @@ void MenuEditor::DoSelect(wxString id, bool refresh, bool sendEvent, bool ctrlDo
 		SendChangedEvent();
 }
 
+wxRect MenuEditor::UpdateSelectionRect(int x, int y) {
+	x = (int) round(x / GetScaleX());
+	y = (int) round(y / GetScaleY());
+	wxRect refreshRect;
+	wxSVGRectElement* selRect = (wxSVGRectElement*) m_doc->GetRootElement()->GetElementById(wxT("menuObjSelection"));
+	if (selRect == NULL) {
+		selRect = new wxSVGRectElement;
+		selRect->SetId(wxT("menuObjSelection"));
+		selRect->SetStroke(wxSVGPaint(255, 0, 0));
+		selRect->SetFill(wxSVGPaint());
+		selRect->SetX(x);
+		selRect->SetY(y);
+		selRect->SetWidth(1);
+		selRect->SetHeight(1);
+		m_doc->GetRootElement()->AppendChild(selRect);
+	} else
+		refreshRect = ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY());
+	selRect->SetWidth(x - selRect->GetX().GetAnimVal().GetValue());
+	selRect->SetHeight(y - selRect->GetY().GetAnimVal().GetValue());
+	selRect->SetCanvasItem(NULL);
+	
+	return refreshRect.Union(ScaleRect(selRect->GetBBox(), GetScaleX(), GetScaleY()));
+}
+
+wxRect MenuEditor::PerformSelection() {
+	wxSVGRectElement* selRectElem = (wxSVGRectElement*) m_doc->GetRootElement()->GetElementById(wxT("menuObjSelection"));
+	if (selRectElem == NULL) {
+		return wxRect(0, 0, 0, 0);
+	}
+	wxSVGRect bbox = selRectElem->GetBBox();
+	wxRect selRect = wxRect((int) bbox.GetX(), (int) bbox.GetY(), (int) bbox.GetWidth(), (int) bbox.GetHeight());
+	wxRect refreshRect = ScaleRect(bbox, GetScaleX(), GetScaleY());;
+	selRectElem->GetParent()->RemoveChild(selRectElem);
+	
+
+	// select all objects
+	for (unsigned int i = 0; i < m_menu->GetObjectsCount(); i++) {
+		MenuObject* obj = m_menu->GetObject(i);
+		wxString id = obj->GetId();
+		if (obj->GetBBox().Intersects(selRect) && m_selectedIds.Index(id) == wxNOT_FOUND) {
+			m_selectedIds.push_back(id);
+			refreshRect.Union(CreateSelection(id));
+		}
+	}
+	return refreshRect;
+}
+
 wxRect MenuEditor::CreateSelection(wxString id) {
 	MenuObject* obj = m_menu->GetObject(id);
 	if (!obj)
@@ -650,6 +721,10 @@ void MenuEditor::OnMouseLeftButton(wxMouseEvent &event) {
 	}
 	if (objectIsMoving) {
 		objectIsMoving = false;
+		if (!event.LeftDown() && m_action == eaNONE) {
+			wxRect rect = PerformSelection();
+			RefreshRect(rect.Inflate(8));
+		}
 		SendChangedEvent();
 	}
 	int x = event.GetX();
@@ -691,8 +766,8 @@ void MenuEditor::OnMouseMove(wxMouseEvent &event) {
 		return;
 	}
 
-	// left mouse button is down => move or resize
-	if (m_action == eaMOVE) {
+	// left mouse button is down => move, resize or select
+	if (m_action == eaMOVE) { // move
 		// move Object
 		int x1 = x - m_oldx;
 		int y1 = y - m_oldy;
@@ -702,7 +777,11 @@ void MenuEditor::OnMouseMove(wxMouseEvent &event) {
 		}
 		m_oldx += x1;
 		m_oldy += y1;
-	} else if (m_action != eaNONE) { // m_action=TL,TR,BL,BR
+	} else if (m_action == eaNONE) { // select
+		wxRect rect = UpdateSelectionRect(x, y);
+		RefreshRect(rect.Inflate(8));
+		objectIsMoving = true;
+	} else { // m_action=TL,TR,BL,BR => resize
 		// resize object
 		if (ResizeObject(x, y, m_action)) {
 			DoSelect(GetSelected(), true); // refresh
@@ -1207,12 +1286,15 @@ void MenuEditor::OnUpdateUIObjectForward(wxUpdateUIEvent& event) {
 void MenuEditor::OnUpdateUIObjectBackward(wxUpdateUIEvent& event) {
 	event.Enable(m_selectedIds.size() == 1 && !m_menu->IsFirstObject(GetSelected()));
 }
+void MenuEditor::OnUpdateUIAlign(wxUpdateUIEvent& event) {
+	event.Enable(m_selectedIds.size() > 1);
+}
 
 int MenuEditor::SnapToGrid(int pos) {
 	return m_grid > 0 ? pos >> m_grid << m_grid : pos;
 }
 
-void MenuEditor::OnAlignToCenterH(wxCommandEvent& event) {
+void MenuEditor::OnAlignToCenterMH(wxCommandEvent& event) {
 	int x1 = 9999;
 	int x2 = -9999;
 	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
@@ -1231,7 +1313,7 @@ void MenuEditor::OnAlignToCenterH(wxCommandEvent& event) {
 	SendChangedEvent();
 }
 
-void MenuEditor::OnAlignToCenterV(wxCommandEvent& event) {
+void MenuEditor::OnAlignToCenterMV(wxCommandEvent& event) {
 	int y1 = 9999;
 	int y2 = -9999;
 	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
@@ -1250,6 +1332,104 @@ void MenuEditor::OnAlignToCenterV(wxCommandEvent& event) {
 	SendChangedEvent();
 }
 
+void MenuEditor::OnAlignToCenterH(wxCommandEvent& event) {
+	int x1 = 9999;
+	int x2 = -9999;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		if (obj->GetX() < x1)
+			x1 = obj->GetX();
+		if (obj->GetX() + obj->GetWidth() > x2)
+			x2 = obj->GetX() + obj->GetWidth();
+	}
+	int x = (x2 + x1)/2;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		obj->SetX(x - obj->GetWidth()/2);
+	}
+	RefreshSelected();
+	SendChangedEvent();
+}
+
+void MenuEditor::OnAlignToCenterV(wxCommandEvent& event) {
+	int y1 = 9999;
+	int y2 = -9999;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		if (obj->GetY() < y1)
+			y1 = obj->GetY();
+		if (obj->GetY() + obj->GetHeight() > y2)
+			y2 = obj->GetY() + obj->GetHeight();
+	}
+	int y = (y2 + y1)/2;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		obj->SetY(y - obj->GetHeight()/2);
+	}
+	RefreshSelected();
+	SendChangedEvent();
+}
+
+void MenuEditor::OnAlignToLeft(wxCommandEvent& event) {
+	int x1 = 9999;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		if (obj->GetX() < x1)
+			x1 = obj->GetX();
+	}
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		obj->SetX(x1);
+	}
+	RefreshSelected();
+	SendChangedEvent();
+}
+
+void MenuEditor::OnAlignToRight(wxCommandEvent& event) {
+	int x1 = 0;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		if (obj->GetX() + obj->GetWidth() > x1)
+			x1 = obj->GetX() + obj->GetWidth();
+	}
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		obj->SetX(x1 - obj->GetWidth());
+	}
+	RefreshSelected();
+	SendChangedEvent();
+}
+
+void MenuEditor::OnAlignToTop(wxCommandEvent& event) {
+	int y1 = 9999;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		if (obj->GetY() < y1)
+			y1 = obj->GetY();
+	}
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		obj->SetY(y1);
+	}
+	RefreshSelected();
+	SendChangedEvent();
+}
+
+void MenuEditor::OnAlignToBottom(wxCommandEvent& event) {
+	int y1 = 0;
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		if (obj->GetY() + obj->GetHeight() > y1)
+			y1 = obj->GetY() + obj->GetHeight();
+	}
+	for (wxArrayString::const_iterator it = m_selectedIds.begin(); it != m_selectedIds.end(); it++) {
+		MenuObject* obj = m_menu->GetObject(*it);
+		obj->SetY(y1 - obj->GetHeight());
+	}
+	RefreshSelected();
+	SendChangedEvent();
+}
+
 void MenuEditor::OnProperties(wxCommandEvent& event) {
 	if (!m_menu)
 		return;
