@@ -3,7 +3,7 @@
 // Purpose:     The widget to edit a DVD Menu
 // Author:      Alex Thuering
 // Created:	11.10.2003
-// RCS-ID:      $Id: MenuEditor.h,v 1.24 2012/07/22 09:33:20 ntalex Exp $
+// RCS-ID:      $Id: MenuEditor.h,v 1.26 2014/01/13 14:38:55 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -98,6 +98,9 @@ private:
     void DoSelect(wxString id = wxT(""), bool refresh = false, bool sendEvent = false, bool ctrlDown = false);
     wxRect CreateSelection(wxString id);
     void RefreshSelected();
+    
+    wxRect UpdateSelectionRect(int x, int y);
+    wxRect PerformSelection();
 	
 	void OnMouseLeftButton(wxMouseEvent &event);
     void OnMouseMove(wxMouseEvent &event);
@@ -119,8 +122,15 @@ private:
     void OnObjectToBack(wxCommandEvent& event);
     void OnUpdateUIObjectForward(wxUpdateUIEvent& event);
     void OnUpdateUIObjectBackward(wxUpdateUIEvent& event);
+    void OnAlignToCenterMH(wxCommandEvent& event);
+    void OnAlignToCenterMV(wxCommandEvent& event);
     void OnAlignToCenterH(wxCommandEvent& event);
     void OnAlignToCenterV(wxCommandEvent& event);
+    void OnAlignToLeft(wxCommandEvent& event);
+    void OnAlignToRight(wxCommandEvent& event);
+    void OnAlignToTop(wxCommandEvent& event);
+    void OnAlignToBottom(wxCommandEvent& event);
+    void OnUpdateUIAlign(wxUpdateUIEvent& event);
 	void OnProperties(wxCommandEvent& event);
 	void OnUpdateUIProperties(wxUpdateUIEvent& event);
 	void OnSafeTV(wxCommandEvent& event);
