@@ -3,13 +3,14 @@
 // Purpose:     The class to store a DVD Menu Object
 // Author:      Alex Thuering
 // Created:	04.11.2006
-// RCS-ID:      $Id: MenuObject.cpp,v 1.46 2013/04/02 06:44:00 ntalex Exp $
+// RCS-ID:      $Id: MenuObject.cpp,v 1.50 2014/02/19 21:09:51 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
 
 #include "DVD.h"
 #include "Menu.h"
+#include "Config.h"
 #include <wxVillaLib/utils.h>
 #include <wxSVG/svg.h>
 #include <wxSVGXML/svgxmlhelpr.h>
@@ -26,7 +27,8 @@ wxRegEx s_jumpTitlesetMenu(wxT("jump titleset ([[:digit:]]+) menu;"));
 
 ///////////////////////////// MenuObject /////////////////////////////////////
 
-MenuObject::MenuObject(Menu* menu, bool vmg, wxString fileName, int x, int y, wxString param): m_action(vmg) {
+MenuObject::MenuObject(Menu* menu, bool vmg, wxString fileName, int x, int y, wxString param):
+		m_action(vmg), m_textOffset(0), m_svg(NULL), m_use(NULL), m_symbol(NULL) {
 	m_menu = menu;
 	if (menu == NULL) {
 		m_deleteSVG = true;
@@ -40,8 +42,6 @@ MenuObject::MenuObject(Menu* menu, bool vmg, wxString fileName, int x, int y, wx
 		m_deleteSVG = false;
 		m_svg = menu->GetSVG();
 	}
-	m_use = NULL;
-	m_symbol = NULL;
 	
 	m_fileName = fileName;
 	m_previewHighlighted = false;
@@ -154,6 +154,8 @@ bool MenuObject::Init(wxString fileName, int x, int y, wxString param) {
 	if (m_initParameter.length() && param.length())
 		SetParam(m_initParameter, param);
 	
+	m_textOffset.SetValueAsString(XmlReadValue(root, wxT("text-offset")));
+
 	// load default size
 	wxSvgXmlNode* defaultSizeNode = XmlFindNode(root, wxT("default-size"));
 	if (defaultSizeNode && defaultSizeNode->GetFirstChild()) {
@@ -384,11 +386,22 @@ unsigned int MenuObject::CalcSize(MenuObjectSize& size, bool width) {
 		}
 	}
 	if (size.valuePercent > 0)
-		result += (result * size.valuePercent + 99) / 100;
+		result += lround(((double) result * size.valuePercent) / 100);
 	result += size.valueInc;
 	return wxMax(result, size.value);
 }
 
+bool MenuObject::IsAlignRight(MenuObjectSize& size) {
+	if (size.elements.size() == 0) {
+		return false;
+	}
+	wxSVGElement* elem = (wxSVGElement*) m_symbol->GetElementById(size.elements[0]);
+	if (!elem || elem->GetDtd() != wxSVG_TEXT_ELEMENT) {
+		return false;
+	}
+	return ((wxSVGTextElement*) elem)->GetTextAnchor() == wxCSS_VALUE_END;
+}
+
 #include <wxSVG/SVGCanvasItem.h>
 
 void MenuObject::FixSize(int& width, int& height) {
@@ -419,8 +432,15 @@ void MenuObject::UpdateSize() {
 	int width = GetWidth();
 	int height = GetHeight();
 	FixSize(width, height);
+	if (IsAlignRight(m_defaultSize ? m_defaultWidth : m_minWidth) && width != GetWidth()) {
+		SetX(GetX() + GetWidth() - width);
+	}
 	SetWidth(width);
 	SetHeight(height);
+	if (GetX() + GetWidth() <= 0)
+		SetX(0);
+	if (GetY() + GetHeight() <= 0)
+		SetY(0);
 }
 
 wxString MenuObject::GetParam(wxString name, wxString attribute) {
@@ -959,7 +979,8 @@ wxSvgXmlNode* MenuObject::GetXML(DVDFileType type, DVD* dvd, SubStreamMode mode,
 		wxString action = GetAction().AsString(dvd);
 		action.Replace(wxT("vmMenu"), wxT("vmgm menu"));
 		if (dvd->GetPlayAllRegister() != -1)
-			action = wxString::Format(wxT("g%d=%d;"), dvd->GetPlayAllRegister(), GetAction().IsPlayAll()) + action;
+			action = wxString::Format(wxT("g%d=%d;"), dvd->GetPlayAllRegister(),
+					GetAction().IsPlayAll() ? (s_config.GetDefPlayAllTitlesets() ? 2 : 1): 0) + action;
 		if (dvd->GetLastMenuRegister() != -1) {
 			int rootMenu = ((Menus&) dvd->GetPgcArray(m_menu->GetTsi(), true)).GetPgciByEntry(wxT("root"));
 			if (action.Contains(wxT("jump menu;")) || action.Contains(wxT("jump menu entry root;"))
