@@ -3,7 +3,7 @@
 // Purpose:     DVD menu button properties dialog
 // Author:      Alex Thuering
 // Created:	20.11.2003
-// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.67 2013/06/23 20:59:55 ntalex Exp $
+// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.76 2014/03/07 13:19:23 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -18,8 +18,11 @@
 #include <wx/tglbtn.h>
 #include <stdint.h>
 #include "rc/justifyLeft.png.h"
+#include "rc/justifyLeftSelected.png.h"
 #include "rc/justifyCenter.png.h"
+#include "rc/justifyCenterSelected.png.h"
 #include "rc/justifyRight.png.h"
+#include "rc/justifyRightSelected.png.h"
 #if !wxCHECK_VERSION(2,9,0)
 #define wxBitmapToggleButton wxToggleBitmapButton
 #endif
@@ -165,7 +168,7 @@ void MenuObjectPropDlg::CreatePropPanel(wxSizer* sizer) {
 		if (m_dvd->GetSubtitleStreamsCount() == 0)
 			GetLastControl()->Enable(false);
 		
-		AddCheckProp(s, _("Auto execute"), m_object->IsAutoExecute());
+		AddCheckProp(mainSizer, _("Auto execute command by select"), m_object->IsAutoExecute());
 
 		grid = new wxFlexGridSizer(3, 4, 16);
 		AddText(grid, _("Navigation"));
@@ -227,17 +230,18 @@ void MenuObjectPropDlg::CreateLook(wxBoxSizer* mainSizer, wxFlexGridSizer* grid)
 				wxBoxSizer* sizer3 = new wxBoxSizer(wxVERTICAL);
 				AddFontProp(sizer3, wxT(""), m_object->GetParamFont(param->name), _("Font..."));
 				wxBoxSizer* sizer4 = new wxBoxSizer(wxHORIZONTAL);
-				bool enableJustify = m_object->GetParam(param->name, wxT("x")) == wxT("0")
-						|| m_object->GetParam(param->name, wxT("x")) == wxT("50%")
-						|| m_object->GetParam(param->name, wxT("x")) == wxT("100%");
-				AddBitmapToggleButton(sizer4, m_object->GetParam(param->name, wxT("text-anchor")) == wxT("start"),
-						JUSTIFY_LEFT_BT_ID, wxBITMAP_FROM_MEMORY(justifyLeft), wxSize(22, 22));
+				bool enableJustify = CanJustifyText(param->name);
+				bool selected = m_object->GetParam(param->name, wxT("text-anchor")) == wxT("start");
+				AddBitmapToggleButton(sizer4, selected, JUSTIFY_LEFT_BT_ID, selected ? wxBITMAP_FROM_MEMORY(
+						justifyLeftSelected) : wxBITMAP_FROM_MEMORY(justifyLeft), wxSize(22, 22));
 				GetLastControl()->Enable(enableJustify);
-				AddBitmapToggleButton(sizer4, m_object->GetParam(param->name, wxT("text-anchor")) == wxT("middle"),
-						JUSTIFY_CENTER_BT_ID, wxBITMAP_FROM_MEMORY(justifyCenter), wxSize(22, 22));
+				selected = m_object->GetParam(param->name, wxT("text-anchor")) == wxT("middle");
+				AddBitmapToggleButton(sizer4, selected, JUSTIFY_CENTER_BT_ID, selected ? wxBITMAP_FROM_MEMORY(
+						justifyCenterSelected) : wxBITMAP_FROM_MEMORY(justifyCenter), wxSize(22, 22));
 				GetLastControl()->Enable(enableJustify);
-				AddBitmapToggleButton(sizer4, m_object->GetParam(param->name, wxT("text-anchor")) == wxT("end"),
-						JUSTIFY_RIGHT_BT_ID, wxBITMAP_FROM_MEMORY(justifyRight), wxSize(22, 22));
+				selected = m_object->GetParam(param->name, wxT("text-anchor")) == wxT("end");
+				AddBitmapToggleButton(sizer4, selected, JUSTIFY_RIGHT_BT_ID, selected ? wxBITMAP_FROM_MEMORY(
+						justifyRightSelected) : wxBITMAP_FROM_MEMORY(justifyRight), wxSize(22, 22));
 				GetLastControl()->Enable(enableJustify);
 				sizer3->Add(sizer4, 0, wxEXPAND);
 				sizer2->Add(sizer3, 0, wxEXPAND);
@@ -359,8 +363,9 @@ void MenuObjectPropDlg::CreateLocAndSize(wxBoxSizer* mainSizer) {
 	// object location
 	wxSizer* grpSizer = BeginGroup(hSizer, _("Location"));
 	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
-	AddSpinProp(grid, _("X:"), m_object->GetX(), 0, m_menu->GetResolution().GetWidth()-8);
-	AddSpinProp(grid, _("Y:"), m_object->GetY(), 0, m_menu->GetResolution().GetHeight()-8);
+	wxSize menuSize = m_menu->GetResolution();
+	AddSpinProp(grid, _("X:"), m_object->GetX(), m_object->IsButton() ? 0 : -menuSize.GetWidth(), menuSize.GetWidth()-8);
+	AddSpinProp(grid, _("Y:"), m_object->GetY(), m_object->IsButton() ? 0 : -menuSize.GetHeight(), menuSize.GetHeight()-8);
 	grpSizer->Add(grid, 0, wxALL, 4);
 	EndGroup();
 	hSizer->AddSpacer(8);
@@ -422,11 +427,11 @@ void MenuObjectPropDlg::FillTargets(wxChoice* ctrl) {
 	// add a jump target for every title and menu in every titleset if possible
 	for (int tsi = -1; tsi < (int)m_dvd->GetTitlesets().Count(); tsi++) {
 		if (tsi == -1) { // Video-Manager-Domain
-			// jumpt to vmMenu
+			// jumpt to vmgm menu
 			for (int pgci = 0; pgci < (int) m_dvd->GetVmgm().Count(); pgci++) {
 				if (tsi == m_tsi && pgci == m_pgci)
 					continue; // current menu
-				ctrl->Append(wxString::Format(_("vmMenu %d"), pgci + 1), TargetToPtr(tsi, pgci, true));
+				ctrl->Append(_("VMGM menu") + wxString::Format(wxT(" %d"), pgci + 1), TargetToPtr(tsi, pgci, true));
 				if (tsi == actionTsi && pgci == actionPgci && actionMenu)
 					sel = ctrl->GetCount() - 1; // current action target
 			}
@@ -443,13 +448,13 @@ void MenuObjectPropDlg::FillTargets(wxChoice* ctrl) {
 					if (pgci != rootMenu && pgc->GetEntries().size() == 0)
 						continue; // cannot jump to specific menu from other titleset, only to an entry
 					const wxString entries[6] = {
-							_("title vmMenu"), _("root menu"), _("subtitle menu"),
+							_("title menu"), _("root menu"), _("subtitle menu"),
 							_("audio menu"), _("angle menu"), _("chapter menu")};
 					int entryIdx = pgc->GetEntries().size() > 0 ? s_entries.Index(*pgc->GetEntries().begin()) : 1;
 					if (entryIdx >= 0)
 						label = label + wxT(" (") + entries[entryIdx] + wxT(")");
 				}
-				if (m_dvd->GetTitlesets().Count() > 1)
+				if (m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0)
 					label = _("titleset") + wxString::Format(wxT(" %d "), tsi + 1) + label;
 				ctrl->Append(label, TargetToPtr(tsi, pgci, true));
 				if (tsi == actionTsi && pgci == actionPgci && actionMenu)
@@ -458,7 +463,7 @@ void MenuObjectPropDlg::FillTargets(wxChoice* ctrl) {
 			// jump to not existing menu
 			if (tsi == actionTsi && actionPgci >= (int) ts->GetMenus().Count() && actionMenu) {
 				wxString label = _("menu") + wxString::Format(wxT(" %d*"), actionPgci + 1);
-				if (m_dvd->GetTitlesets().Count() > 1)
+				if (m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0)
 					label = _("titleset") + wxString::Format(wxT(" %d "), tsi + 1) + label;
 				ctrl->Append(label, TargetToPtr(tsi, actionPgci, true));
 				sel = ctrl->GetCount() - 1;
@@ -468,7 +473,7 @@ void MenuObjectPropDlg::FillTargets(wxChoice* ctrl) {
 				// jump to title
 				for (int pgci = 0; pgci < (int) ts->GetTitles().Count(); pgci++) {
 					wxString label = _("title") + wxString::Format(wxT(" %d"), pgci + 1);
-					if (m_dvd->GetTitlesets().Count() > 1)
+					if (m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0)
 						label = _("titleset") + wxString::Format(wxT(" %d "), tsi + 1) + label;
 					ctrl->Append(label, TargetToPtr(tsi, pgci, false));
 					if (tsi == actionTsi && pgci == actionPgci && !actionMenu)
@@ -477,7 +482,7 @@ void MenuObjectPropDlg::FillTargets(wxChoice* ctrl) {
 				// jump to not existing title
 				if (tsi == actionTsi && actionPgci >= (int) ts->GetTitles().Count() && !actionMenu) {
 					wxString label = _("title") + wxString::Format(wxT(" %d*"), actionPgci + 1);
-					if (m_dvd->GetTitlesets().Count() > 1)
+					if (m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0)
 						label = _("titleset") + wxString::Format(wxT(" %d "), tsi + 1) + label;
 					ctrl->Append(label, TargetToPtr(tsi, actionPgci, false));
 					sel = ctrl->GetCount() - 1;
@@ -485,6 +490,13 @@ void MenuObjectPropDlg::FillTargets(wxChoice* ctrl) {
 			}
 		}
 	}
+	// jump to not existing title in not existing titleset
+	if (actionTsi >= (int) m_dvd->GetTitlesets().size() && !actionMenu) {
+		wxString label = _("titleset") + wxString::Format(wxT(" %d "), actionTsi + 1)
+				+ _("title") + wxString::Format(wxT(" %d*"), actionPgci + 1);
+		ctrl->Append(label, TargetToPtr(actionTsi, actionPgci, false));
+		sel = ctrl->GetCount() - 1;
+	}
 	ctrl->SetSelection(sel);
 }
 
@@ -612,10 +624,29 @@ void MenuObjectPropDlg::OnVideoFrame(wxCommandEvent& evt) {
 	}
 }
 
+bool MenuObjectPropDlg::CanJustifyText(wxString paramName) {
+	wxString val = m_object->GetParam(paramName, wxT("x"));
+	wxString right = wxT("100%");
+	if (m_object->GetTextOffset().GetValueInSpecifiedUnits() != 0) {
+		if (m_object->GetTextOffset().GetUnitType() == wxSVG_LENGTHTYPE_PERCENTAGE) {
+			right = wxString::Format(wxT("%g%%"), 100 - m_object->GetTextOffset().GetValueInSpecifiedUnits());
+		}
+	}
+	return val == m_object->GetTextOffset().GetValueAsString() || val == wxT("50%") || val == right;
+}
+
 void MenuObjectPropDlg::OnJustifyText(wxCommandEvent& evt) {
 	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_LEFT_BT_ID))->SetValue(evt.GetId() == JUSTIFY_LEFT_BT_ID);
 	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_CENTER_BT_ID))->SetValue(evt.GetId() == JUSTIFY_CENTER_BT_ID);
 	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_RIGHT_BT_ID))->SetValue(evt.GetId() == JUSTIFY_RIGHT_BT_ID);
+#if wxCHECK_VERSION(2,9,0)
+	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_LEFT_BT_ID))->SetBitmap(evt.GetId() == JUSTIFY_LEFT_BT_ID
+			? wxBITMAP_FROM_MEMORY(justifyLeftSelected) : wxBITMAP_FROM_MEMORY(justifyLeft));
+	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_CENTER_BT_ID))->SetBitmap(evt.GetId() == JUSTIFY_CENTER_BT_ID
+			? wxBITMAP_FROM_MEMORY(justifyCenterSelected) : wxBITMAP_FROM_MEMORY(justifyCenter));
+	((wxBitmapToggleButton*) this->FindWindow(JUSTIFY_RIGHT_BT_ID))->SetBitmap(evt.GetId() == JUSTIFY_RIGHT_BT_ID
+			? wxBITMAP_FROM_MEMORY(justifyRightSelected) : wxBITMAP_FROM_MEMORY(justifyRight));
+#endif
 }
 
 void MenuObjectPropDlg::OnKeepAspectRatio(wxCommandEvent& evt) {
@@ -690,7 +721,7 @@ bool MenuObjectPropDlg::SetValues() {
 		action.SetTsi(GetSelectedTsi() != m_tsi ? GetSelectedTsi() : -2);
 		action.SetPgci(GetSelectedTsi() != m_tsi || GetSelectedPgci() != m_pgci || !IsSelectedMenu() ? GetSelectedPgci() : -1);
 		action.SetMenu(IsSelectedMenu());
-		if (GetSelectedTsi() != m_tsi && IsSelectedMenu() && GetSelectedPgci() > 0) {
+		if (GetSelectedTsi() != m_tsi && GetSelectedTsi() != -1 && IsSelectedMenu() && GetSelectedPgci() > 0) {
 			const StringSet& entries = m_dvd->GetPgcArray(GetSelectedTsi(), true)[GetSelectedPgci()]->GetEntries();
 			action.SetEntry(wxString(entries.size() > 0 ? *entries.begin() : wxT("")));
 		} else
@@ -739,17 +770,28 @@ bool MenuObjectPropDlg::SetValues() {
 			if (param->type == _T("text")) {
 				m_object->SetParam(param->name, GetString(n++));
 				m_object->SetParamFont(param->name, GetFont(n++).GetChosenFont());
-				if (GetBool(n++)) {
-					m_object->SetParam(param->name, wxT("start"), wxT("text-anchor"));
-					m_object->SetParam(param->name, wxT("0"), wxT("x"));
-				}
-				if (GetBool(n++)) {
-					m_object->SetParam(param->name, wxT("middle"), wxT("text-anchor"));
-					m_object->SetParam(param->name, wxT("50%"), wxT("x"));
-				}
-				if (GetBool(n++)) {
-					m_object->SetParam(param->name, wxT("end"), wxT("text-anchor"));
-					m_object->SetParam(param->name, wxT("100%"), wxT("x"));
+				if (CanJustifyText(param->name)) {
+					if (GetBool(n++)) {
+						m_object->SetParam(param->name, wxT("start"), wxT("text-anchor"));
+						m_object->SetParam(param->name, m_object->GetTextOffset().GetValueAsString(), wxT("x"));
+					}
+					if (GetBool(n++)) {
+						m_object->SetParam(param->name, wxT("middle"), wxT("text-anchor"));
+						m_object->SetParam(param->name, wxT("50%"), wxT("x"));
+					}
+					if (GetBool(n++)) {
+						m_object->SetParam(param->name, wxT("end"), wxT("text-anchor"));
+						wxString xVal = wxT("100%");
+						if (m_object->GetTextOffset().GetValueInSpecifiedUnits() != 0) {
+							if (m_object->GetTextOffset().GetUnitType() == wxSVG_LENGTHTYPE_PERCENTAGE) {
+								xVal = wxString::Format(wxT("%g%%"), 100
+										- m_object->GetTextOffset().GetValueInSpecifiedUnits());
+							}
+						}
+						m_object->SetParam(param->name, xVal, wxT("x"));
+					}
+				} else {
+					n += 3;
 				}
 			} else if (param->type == _T("string"))
 				m_object->SetParam(param->name, GetString(n++));
