@@ -3,7 +3,7 @@
 // Purpose:     DVD menu properties dialog
 // Author:      Alex Thuering
 // Created:     25.04.2004
-// RCS-ID:      $Id: MenuPropDlg.cpp,v 1.43 2013/03/04 04:55:20 ntalex Exp $
+// RCS-ID:      $Id: MenuPropDlg.cpp,v 1.47 2014/03/11 12:11:12 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -34,8 +34,8 @@ BEGIN_EVENT_TABLE(MenuPropDlg, wxPropDlg)
 END_EVENT_TABLE()
 
 MenuPropDlg::MenuPropDlg(wxWindow *parent, DVD* dvd, int tsi, int pgci):
-		wxPropDlg(parent), m_dvd(dvd), m_tsi(tsi), m_pgci(pgci),
-		m_aspect(NULL), m_wsFormat(NULL), m_audioFormat(NULL), m_pauseCtrl(NULL), m_postCommandsCtrl(NULL) {
+		wxPropDlg(parent), m_dvd(dvd), m_tsi(tsi), m_pgci(pgci), m_aspect(NULL), m_wsFormat(NULL), m_audioFormat(NULL),
+		m_pauseCtrl(NULL), m_postCommandsCtrl(NULL), m_subStartCtrlIdx(0), m_audioCtrlIdx(0), m_preCommandsCtrlIdx(0) {
 	PgcArray& pgcs = m_dvd->GetPgcArray(tsi, true);
 	m_video = &pgcs.GetVideo();
 	m_langCodes = &pgcs.GetAudioLangCodes();
@@ -52,7 +52,7 @@ MenuPropDlg::MenuPropDlg(wxWindow *parent, DVD* dvd, int tsi, int pgci):
 			title += _("Titleset") + wxString::Format(wxT(" %d "), tsi+1);
 		title += _("Menu") + wxString::Format(wxT(" %d"), pgci+1);
 	} else
-		title += _("vmMenu") + wxString::Format(wxT(" %d"), pgci+1);
+		title += _("VMGM menu") + wxString::Format(wxT(" %d"), pgci+1);
 	SetTitle(title);
 	// create
 	Create();
@@ -137,7 +137,8 @@ void MenuPropDlg::CreateButtonsGroup(wxSizer* sizer) {
 	wxFlexGridSizer* grid = new wxFlexGridSizer(2, 4, 16);
 	grid->AddGrowableCol(1);
 	// Start/End
-	wxSizer* timeSizer = AddTextProp(grid, _("Start/End:"), m_menu->GetStartTime(), false, 100, false);
+	wxSizer* timeSizer = AddTextProp(grid, _("Subpicture start/end:"), m_menu->GetStartTime(), false, 100, false);
+	m_subStartCtrlIdx = GetLastControlIndex();
 	AddTextProp(timeSizer, wxT(" - "), m_menu->GetEndTime(), false, 100);
 	grpSizer->Add(grid, 0, wxEXPAND|wxALL, 4);
 	// Remember last selected button
@@ -166,6 +167,7 @@ void MenuPropDlg::CreateVobGroup(wxSizer* sizer, bool loop) {
 	AddFileProp(grid, _("Audio:"), audioFile, wxFD_OPEN, wxT("..."),
 			_("Audio Files") + wxString::Format(wxT(" (%s)|%s|"), audio.c_str(), audio.c_str())
 			+ _("All Files") + wxString(wxT(" (*.*)|*.*")), AUDIO_CTRL_ID);
+	m_audioCtrlIdx = GetLastControlIndex();
 	// audio format
 	Stream* stream = audioFile.length() > 0 ? m_vob->GetStreams()[m_vob->GetStreams().size() - 1] : NULL;
 	int af = stream != NULL ? stream->GetAudioFormat() - 1 : afCOPY - 1;
@@ -213,6 +215,7 @@ void MenuPropDlg::CreateMenuGroup(wxSizer* sizer, bool loop) {
 	// Pre and post commans
 	wxArrayString commands = GetCommands();
 	AddComboProp(grid, _("Pre commands:"), m_pgc->GetPreCommands(), commands);
+	m_preCommandsCtrlIdx = GetLastControlIndex();
 	AddComboProp(grid, _("Post commands:"), m_pgc->GetPostCommands(), commands);
 	m_postCommandsCtrl = (wxComboBox*) GetLastControl();
 	m_postCommandsCtrl->Enable(!loop);
@@ -236,9 +239,14 @@ wxArrayString MenuPropDlg::GetCommands() {
 }
 
 bool MenuPropDlg::SetValues() {
+	// validate sub end
+	if (GetString(m_subStartCtrlIdx).size() > 0 && GetString(m_subStartCtrlIdx+1).size() > 0
+			&& String2Time(GetString(m_subStartCtrlIdx)) >= String2Time(GetString(m_subStartCtrlIdx))) {
+		wxLogError(_("Subpicture end must be greater than start or empty"));
+		return false;
+	}
 	// validate audio file
-	int AUDIO_CTRL_IDX = 13;
-	wxString audioFile = GetString(AUDIO_CTRL_IDX);
+	wxString audioFile = GetString(m_audioCtrlIdx);
 	if (audioFile.length() > 0) {
 		if (!wxFile::Exists(audioFile)) {
 			wxLogError(_("File %s doesn't exist."), audioFile.c_str());
@@ -254,9 +262,8 @@ bool MenuPropDlg::SetValues() {
 	}
 	
 	// validate commands
-	int n = AUDIO_CTRL_IDX + (m_tsi >= 0 ? 9 : 5);
-	wxString preCommands = GetString(n++);
-	wxString postCommands = GetString(n++);
+	wxString preCommands = GetString(m_preCommandsCtrlIdx);
+	wxString postCommands = GetString(m_preCommandsCtrlIdx + 1);
 	DVDAction action;
 	action.SetCustom(preCommands);
 	if (preCommands.length() && !action.IsValid(m_dvd, m_tsi, m_pgci, true, wxT(""), true, false)) {
@@ -267,7 +274,12 @@ bool MenuPropDlg::SetValues() {
 		return false;
 	}
 	
-	n = 0;
+	if (postCommands.length() && GetInt(m_audioCtrlIdx + 3) == -1) {
+		wxLogError(_("Post commands will not be executed if pause is set to -1"));
+		return false;
+	}
+
+	int n = 0;
 	
 	// set video format
 	VideoFormat videoFormat = (VideoFormat) (GetInt(n++) + 2);
@@ -334,10 +346,10 @@ bool MenuPropDlg::SetValues() {
 			entries.insert(wxT("subtitle"));
 		if (GetBool(n++))
 			entries.insert(wxT("ptt"));
-		if (GetBool(n++))
-			entries.insert(wxT("angle"));
 		if (GetBool(n++))
 			entries.insert(wxT("audio"));
+		if (GetBool(n++))
+			entries.insert(wxT("angle"));
 	} else if (GetBool(n++))
 		entries.insert(wxT("title"));
 	// remove same entries from other menus in the same titleset
