@@ -3,7 +3,7 @@
 // Purpose:     Progress of generation/burning dialog
 // Author:      Alex Thuering
 // Created:     14.08.2004
-// RCS-ID:      $Id: ProgressDlg.cpp,v 1.152 2013/08/18 10:22:24 ntalex Exp $
+// RCS-ID:      $Id: ProgressDlg.cpp,v 1.168 2014/03/31 08:36:22 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -20,14 +20,18 @@
 #include <wx/dir.h>
 #include <wx/filename.h>
 #include <wx/file.h>
+#include <wx/textfile.h>
 #include <wx/regex.h>
 #include <wx/utils.h>
 #include <wx/platinfo.h>
 #include <wxSVG/SVGDocument.h>
+#include <wxSVG/SVGImageElement.h>
+#include <wxSVG/SVGAnimateElement.h>
 #include <wxSVG/mediadec_ffmpeg.h>
+#include <wx/math.h>
 
 #ifdef __WXMAC__
-extern "C" {
+extern "C++" {
 	wxString GetDeviceName(const wxString& ioRegistryEntryPath);
 	wxString GetDeviceNode(const wxString& ioRegistryEntryPath);
 	bool IsMediaPresent(const wxString& ioRegistryEntryPath);
@@ -37,7 +41,9 @@ extern "C" {
 }
 #endif
 
-#define DATA_FILE(fname) wxFindDataFile(_T("data") + wxString(wxFILE_SEP_PATH) + fname)
+#define DATA_FILE(fname) wxFindDataFile(wxT("data") + wxString(wxFILE_SEP_PATH) + fname)
+#define TRANSITION_FILE(fname) wxFindDataFile(wxT("transitions") + wxString(wxFILE_SEP_PATH) + fname)
+#define TRANSITIONS_DIR wxFindDataDirectory(wxT("transitions"))
 #define TMP_ISO wxT("dvd-out.iso")
 #define WARNING_MPLEX_MSG wxT("Warning: using of mplex (mjpegs-tool) for generation of menus with audio is disabled. This can produce not compliant DVD.")
 
@@ -191,10 +197,10 @@ public:
 				|| line.Find(wxT("packet too large, ignoring buffer limits")) >= 0
 				|| line.Find(wxT("Last message repeated 1 times")) >= 0)
 			return;
-		if (m_pattern.Matches(line)) {
+		if (m_totalFrames > 0 && m_pattern.Matches(line)) {
 			long frame = 0;
 			m_pattern.GetMatch(line, 1).ToLong(&frame);
-			m_percent = (m_totalFrames > 0) ? (frame * 100) / m_totalFrames : 0;
+			m_percent = (frame * 100) / m_totalFrames;
 			m_processDlg->SetSubStep(m_initSubStep + (int) m_percent);
 		}
 		m_processDlg->AddDetailText(line + _T("\n"));
@@ -344,12 +350,13 @@ ProgressDlg::ProgressDlg(MainWin* parent, Cache* cache, bool autoStart): wxDialo
     m_subStepCount = 0;
     m_cache = cache;
     m_autoStart = autoStart;
+    m_detailsText->SetFont(wxFont(8, wxFONTFAMILY_TELETYPE, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL));
 }
 
 void ProgressDlg::set_properties() {
     // begin wxGlade: ProgressDlg::set_properties
     SetTitle(_("Generate DVD"));
-    SetSize(wxSize(600, 600));
+    SetSize(wxSize(700, 600));
     // end wxGlade
 
 	m_detailsBtLabel = m_detailsBt->GetLabel();
@@ -547,6 +554,9 @@ int ProgressDlg::GetTitleSubSteps(wxArrayPtrVoid& titleVobs, wxArrayInt& titleAs
 				vob->SetTmpFilename(_T(""));
 				if (vob->GetSlideshow() || (vob->GetDoNotTranscode() && vob->GetAudioFilenames().Count() == 0))
 					continue;
+				if (vob->GetKeepAspectRatio()) {
+					vob->UpdatePad(ts->GetTitles().GetVideo().GetAspect());
+				}
 				wxString cacheFile = cache->Find(vob, dvd);
 				if (cacheFile.length() > 0 && wxFileExists(cacheFile)) {
 					AddDetailMsg(wxString::Format(_("Found transcoded file in cache for '%s'"),
@@ -572,7 +582,7 @@ int ProgressDlg::GetSlideshowSubSteps(wxArrayPtrVoid& slideshowVobs, DVD* dvd, w
 			for (int vobi = 0; vobi < (int) pgc->GetVobs().Count(); vobi++) {
 				Vob* vob = pgc->GetVobs()[vobi];
 				if (vob->GetSlideshow()) {
-					slideshowSubSteps += 10 * vob->GetSlideshow()->GetCount();
+					slideshowSubSteps += 10 * vob->GetSlideshow()->size();
 					if (vob->GetAudioFilenames().size() > 0)
 						slideshowSubSteps += 200; // transcode
 					vob->SetTmpFilename(dvdTmpDir
@@ -585,8 +595,7 @@ int ProgressDlg::GetSlideshowSubSteps(wxArrayPtrVoid& slideshowVobs, DVD* dvd, w
 	return slideshowSubSteps;
 }
 
-int ProgressDlg::GetSubtitleSubSteps(wxArrayPtrVoid& subtitleVobs, wxArrayInt& subtitleTsi, DVD* dvd,
-		wxString dvdTmpDir) {
+int ProgressDlg::GetSubtitleSubSteps(wxArrayPtrVoid& subtitleVobs, wxArrayInt& subtitleTsi, DVD* dvd, Cache* cache) {
 	int subtitleSubSteps = 0;
 	for (int tsi = 0; tsi < (int) dvd->GetTitlesets().Count(); tsi++) {
 		Titleset* ts = dvd->GetTitlesets()[tsi];
@@ -596,8 +605,13 @@ int ProgressDlg::GetSubtitleSubSteps(wxArrayPtrVoid& subtitleVobs, wxArrayInt& s
 				Vob* vob = pgc->GetVobs()[vobi];
 				if (vob->GetSubtitles().Count()) {
 					subtitleSubSteps += vob->GetSubtitles().Count() * 50;
-					vob->SetTmpFilename(dvdTmpDir
-							+ wxString::Format(_T("title%d-%d-%d.vob"), tsi, pgci, vobi));
+					wxString cacheFile = cache->Find(vob, dvd);
+					if (cacheFile.length() > 0 && wxFileExists(cacheFile)) {
+						AddDetailMsg(wxString::Format(_("Found transcoded file in cache for '%s'"),
+								vob->GetFilename().c_str()));
+						vob->SetTmpFilename(cacheFile);
+						continue; // file in cache do not need to transcode
+					}
 					subtitleVobs.Add(vob);
 					subtitleTsi.Add(tsi);
 				}
@@ -607,6 +621,125 @@ int ProgressDlg::GetSubtitleSubSteps(wxArrayPtrVoid& subtitleVobs, wxArrayInt& s
 	return subtitleSubSteps;
 }
 
+void PrintInfoLine(ProgressDlg* progressDlg, const wxString& info, unsigned int inputSize, unsigned int outputSize,
+		double outputDuration, int bitrate) {
+	wxString text = info.substr(0, 12);
+	text.Append(wxT(' '), 12 - info.length()).Append(wxT("| "));
+	// input size
+	wxString str = inputSize > 0 ? wxString::Format(wxT("%0.1f"), ((float) inputSize) / 1024) + wxT(" MB") : wxT("");
+	str.Append(wxT(' '), 11 - str.length());
+	text.Append(str).Append(wxT("| "));
+	// output duration
+	str = outputDuration > 0 ? Time2String(outputDuration*1000) + wxT(" sec") : wxT("");
+	str.Append(wxT(' '), 16 - str.length());
+	text.Append(str).Append(wxT("| "));
+	// output bitrate
+	if (bitrate >= 1000)
+		str = wxString::Format(wxT("%0.1f"), ((float) bitrate) / 1000) + wxT(" MB/s");
+	else
+		str = bitrate > 0 ? wxString::Format(wxT("%d"), bitrate) + wxT(" KB/s") : wxT("");
+	str.Append(wxT(' '), 9 - str.length());
+	text.Append(str).Append(wxT("| "));
+	// output size
+	str = wxString::Format(wxT("%0.1f"), ((float) outputSize) / 1024) + wxT(" MB");
+	text.Append(str);
+	progressDlg->AddDetailMsg(text);
+}
+
+void ProgressDlg::PrintProjectInfo(DVD* dvd) {
+	AddDetailMsg(wxT("============================================================================="));
+	AddDetailMsg(wxT("            | Input size | Output duration | Bitrate  | Estimated output size"));
+	double totalDuration = 0;
+	for (int tsi = -1; tsi < (int) dvd->GetTitlesets().Count(); tsi++) {
+		PgcArray& pgcArray = dvd->GetPgcArray(tsi, true);
+		for (int pgci = 0; pgci < (int) pgcArray.Count(); pgci++) {
+			Pgc* pgc = pgcArray[pgci];
+			for (int vobi = 0; vobi < (int) pgc->GetVobs().Count(); vobi++) {
+				Vob* vob = pgc->GetVobs()[vobi];
+				double dur = vob->GetMenu() ? vob->GetMenu()->GetSVG()->GetDuration() : 0;
+				PrintInfoLine(this, wxString::Format(tsi == -1 ? wxT("VMGM menu %d") : wxT("Menu %d"), pgci + 1), 0,
+						vob->GetOutputFileSize(dvd, 0), dur, vob->GetBitrate(dvd, 0));
+				totalDuration += dur;
+				for (unsigned int fileIdx = 0; fileIdx < vob->GetAudioFilenames().size(); fileIdx++) {
+					PrintInfoLine(this, wxT("  ") + vob->GetAudioFilenames()[fileIdx].AfterLast(wxT('.')),
+							vob->GetFileSize(vob->GetAudioFilenames()[fileIdx]),
+							vob->GetOutputFileSize(dvd, fileIdx + 1), 0, vob->GetBitrate(dvd, fileIdx + 1));
+				}
+			}
+		}
+		if (tsi == -1)
+			continue;
+		Titles& titles = dvd->GetTitlesets()[tsi]->GetTitles();
+		for (int pgci = 0; pgci < (int) titles.Count(); pgci++) {
+			Pgc* pgc = titles[pgci];
+			AddDetailMsg(wxString::Format(wxT("Title %d"), pgci + 1));
+			for (int vobi = 0; vobi < (int) pgc->GetVobs().Count(); vobi++) {
+				Vob* vob = pgc->GetVobs()[vobi];
+				if (vob->GetSlideshow()) {
+					double dur = vob->GetSlideshow()->GetResultDuration();
+					PrintInfoLine(this, wxT("  slideshow"), 0, vob->GetOutputFileSize(dvd, 0), dur,
+							vob->GetBitrate(dvd, 0));
+					totalDuration += dur;
+				} else if (vob->GetFilename().length() > 0) {
+					double dur = vob->GetResultDuration();
+					PrintInfoLine(this, wxT("  ") + vob->GetFilename().AfterLast(wxT('.')),
+							vob->GetFileSize(vob->GetFilename()), vob->GetOutputFileSize(dvd, 0), dur,
+							vob->GetBitrate(dvd, 0));
+					totalDuration += dur;
+				}
+				for (unsigned int fileIdx = 0; fileIdx < vob->GetAudioFilenames().size(); fileIdx++) {
+					PrintInfoLine(this, wxT("  ") + vob->GetAudioFilenames()[fileIdx].AfterLast(wxT('.')),
+							vob->GetFileSize(vob->GetAudioFilenames()[fileIdx]),
+							vob->GetOutputFileSize(dvd, fileIdx + 1), 0, vob->GetBitrate(dvd, fileIdx + 1));
+				}
+			}
+		}
+	}
+	PrintInfoLine(this, wxT("Total"), 0, dvd->GetSize(), totalDuration, 0);
+	AddDetailMsg(wxT("============================================================================="));
+}
+
+void PrintInfoLine(ProgressDlg* progressDlg, const wxString& info, int transcodedSize) {
+	wxString text = info.substr(0, 12);
+	text.Append(wxT(' '), 12 - info.length()).Append(wxT("| "));
+	// transcoded size
+	wxString str = wxString::Format(wxT("%0.1f"), ((float) transcodedSize) / 1024) + wxT(" MB");
+	text.Append(str);
+	progressDlg->AddDetailMsg(text);
+}
+
+
+void ProgressDlg::PrintProjectTranscodedInfo(DVD* dvd) {
+	AddDetailMsg(wxT("========================="));
+	AddDetailMsg(wxT("            | Result size"));
+	for (int tsi = -1; tsi < (int) dvd->GetTitlesets().Count(); tsi++) {
+		PgcArray& pgcArray = dvd->GetPgcArray(tsi, true);
+		for (int pgci = 0; pgci < (int) pgcArray.Count(); pgci++) {
+			Pgc* pgc = pgcArray[pgci];
+			for (int vobi = 0; vobi < (int) pgc->GetVobs().Count(); vobi++) {
+				Vob* vob = pgc->GetVobs()[vobi];
+				PrintInfoLine(this, wxString::Format(tsi == -1 ? wxT("VMGM menu %d") : wxT("Menu %d"), pgci + 1),
+						vob->GetTranscodedSize(dvd));
+			}
+		}
+		if (tsi == -1)
+			continue;
+		Titles& titles = dvd->GetTitlesets()[tsi]->GetTitles();
+		for (int pgci = 0; pgci < (int) titles.Count(); pgci++) {
+			Pgc* pgc = titles[pgci];
+			for (int vobi = 0; vobi < (int) pgc->GetVobs().Count(); vobi++) {
+				Vob* vob = pgc->GetVobs()[vobi];
+				wxString titleStr = wxString::Format(wxT("Title %d"), pgci + 1);
+				if (vobi > 0)
+					titleStr += wxString::Format(wxT("-%d"), vobi + 1);
+				PrintInfoLine(this, titleStr, vob->GetTranscodedSize(dvd));
+			}
+		}
+	}
+	PrintInfoLine(this, wxT("Total"), dvd->GetSize(true));
+	AddDetailMsg(wxT("========================="));
+}
+
 void ProgressDlg::Run(BurnDlg* burnDlg, DVD* dvd) {
 	if (IsCanceled())
 		return;
@@ -622,12 +755,16 @@ void ProgressDlg::Run(BurnDlg* burnDlg, DVD* dvd) {
 	}
 #endif
 	
-	// clean temp dir
 	wxString tmpDir = burnDlg->GetTempDir();
 	if (tmpDir.Last() != wxFILE_SEP_PATH)
 		tmpDir += wxFILE_SEP_PATH;
-	wxString dvdOutDir = tmpDir + wxString(wxT("dvd-out")) + wxFILE_SEP_PATH;
 	wxString dvdTmpDir = tmpDir + wxString(wxT("dvd-tmp")) + wxFILE_SEP_PATH;
+	wxString dvdOutDir = tmpDir + wxString(wxT("dvd-out")) + wxFILE_SEP_PATH;
+	if (burnDlg->DoGenerate()) {
+		dvdOutDir = burnDlg->GetOutputDir();
+		if (dvdOutDir.Last() != wxFILE_SEP_PATH)
+			dvdOutDir += wxFILE_SEP_PATH;
+	}
 	
 	// create log file
 	m_logFile.Open(tmpDir + wxT("dvdstyler.log"), wxT("w"));
@@ -662,7 +799,7 @@ void ProgressDlg::Run(BurnDlg* burnDlg, DVD* dvd) {
 	// subtitle
 	wxArrayPtrVoid subtitleVobs;
 	wxArrayInt subtitleTsi;
-	int subtitleSubSteps = GetSubtitleSubSteps(subtitleVobs, subtitleTsi, dvd, dvdTmpDir);
+	int subtitleSubSteps = GetSubtitleSubSteps(subtitleVobs, subtitleTsi, dvd, m_cache);
 	// remove unused files from cache
 	m_cache->EndClean();
 
@@ -687,6 +824,9 @@ void ProgressDlg::Run(BurnDlg* burnDlg, DVD* dvd) {
 			stepCount++;
 	}
 	SetSteps(stepCount);
+
+	// print dvd info
+	PrintProjectInfo(dvd);
 	
 	// Start generation
 	if (!GenerateMenus(menuVobs, menuWSTypes, menuSubSteps, dvd)
@@ -751,7 +891,7 @@ bool ProgressDlg::GenerateMenus(wxArrayPtrVoid& menuVobs, wxArrayInt& menuWSType
 		
 		wxString audioFile;
 		AudioFormat audioFormat = dvd->GetAudioFormat();
-		if (vob->GetAudioFilenames().size() > 0 && vob->GetStreams().GetCount() > 0
+		if (vob->GetAudioFilenames().size() > 0 && vob->GetStreams().size() > 0
 				&& vob->GetStreams()[0]->GetType() == stAUDIO) {
 			audioFile = vob->GetAudioFilenames()[0];
 			Stream* stream = vob->GetStreams()[0];
@@ -812,7 +952,7 @@ bool ProgressDlg::GenerateSlideshow(wxArrayPtrVoid& slideshowVobs, int slideshow
 		AddDetailMsg(wxString::Format(_("Generating slideshow %u of %lu"), i + 1, slideshowVobs.Count()));
 		Vob* vob = (Vob*) slideshowVobs[i];
 		AudioFormat audioFormat = dvd->GetAudioFormat();
-		if (vob->GetStreams().GetCount() > 0 && vob->GetStreams()[0]->GetType() == stAUDIO) {
+		if (vob->GetStreams().size() > 0 && vob->GetStreams()[0]->GetType() == stAUDIO) {
 			Stream* stream = vob->GetStreams()[0];
 			audioFormat = stream->GetAudioFormat();
 			if (audioFormat == afCOPY) {
@@ -846,6 +986,11 @@ bool ProgressDlg::MultiplexSubtitles(wxArrayPtrVoid& subtitleVobs, wxArrayInt& s
 		AddDetailMsg(wxString::Format(_("Multiplexing subtitles %u of %lu"), i + 1, subtitleVobs.Count()));
 		Vob* vob = (Vob*) subtitleVobs[i];
 		AspectRatio aspectRatio = dvd->GetTitlesets()[subtitleTsi[i]]->GetTitles().GetVideo().GetAspect();
+		if (vob->GetTmpFilename().length() == 0) {
+			wxString cacheFile = m_cache->Add(vob, dvd);
+			AddDetailMsg(wxT("Add file to cache:") + cacheFile);
+			vob->SetTmpFilename(cacheFile);
+		}
 		
 		// Extract Video stream geometry
 		wxSize movieSize;
@@ -900,6 +1045,8 @@ bool ProgressDlg::MultiplexSubtitles(const wxString& vobFile, TextSub* textSub,
 	wxULongLong fileSize = wxFileName::GetSize(vobFile);
 	SpumuxExecute exec(this, fileSize != wxInvalidSize ? fileSize.ToDouble() : -1);
 	if (!exec.Execute(cmd, vobFile, resultFile)) {
+		if (wxFileExists(resultFile))
+			wxRemoveFile(resultFile);
 		Failed();
 		return false;
 	}
@@ -917,6 +1064,7 @@ bool ProgressDlg::GenerateDvdFilesystem(DVD* dvd, const wxString& dvdTmpDir, con
 		const wxString& tmpDir) {
 	if (IsCanceled())
 		return false;
+	PrintProjectTranscodedInfo(dvd);
 	wxString dvdauthFile = dvdTmpDir + _T("dvdauthor.xml");
 	dvd->SaveDVDAuthor(dvdauthFile);
 	AddSummaryMsg(_("Generating DVD"));
@@ -958,6 +1106,19 @@ or open the following directory with your DVD player: ");
 				msg += dvdOutDir;
 				wxMessageBox(msg, _("Burn"), wxOK|wxICON_ERROR, this);
 			}
+		} else if (cmd.StartsWith(wxT("/Applications/VLC.app/Contents/MacOS/VLC"))) {
+			if (!wxFileExists(wxT("/Applications/VLC.app/Contents/MacOS/VLC"))) {
+				wxString msg = _("VLC player is not found. \
+Please install VLC player (http://www.videolan.org) in Applications directory \
+or open the following directory with your favorite DVD player: ");
+				msg += dvdOutDir;
+				wxMessageBox(msg, _("Burn"), wxOK|wxICON_ERROR, this);
+			} else {
+				cmd += wxT(" \"dvd:///$DIR\"");
+				cmd.Replace(wxT("$DIR"), dvdOutDir.Mid(0, dvdOutDir.length() - 1));
+				if (wxExecute(cmd, wxEXEC_ASYNC) < 0)
+					Failed();
+			}
 		} else {
 			if (cmd.Find(wxT("$DIR")) < 0) {
 				if (cmd[0] != wxT('"'))
@@ -1026,7 +1187,9 @@ bool ProgressDlg::CreateIsoImage(BurnDlg* burnDlg, DVD* dvd, const wxString& dvd
 		AddSummaryMsg(_("Creating ISO image"));
 		SetSubSteps(100);
 		cmd = s_config.GetIsoCmd();
-		cmd.Replace(_T("$VOL_ID"), dvd->GetLabel());
+		wxString label = dvd->GetLabel();
+		label.Replace(wxT("\""), wxT("\\\""));
+		cmd.Replace(_T("$VOL_ID"), label);
 		cmd.Replace(_T("$DIR"), dvdOutDir.Mid(0, dvdOutDir.length() - 1));
 		cmd.Replace(_T("$FILE"), isoFile);
 		ProgressExecute exec(this, wxT(".*"));
@@ -1072,7 +1235,7 @@ bool ProgressDlg::FormatDvd(BurnDlg* burnDlg) {
 			while (!IsMediaPresent(device) || !IsMediaErasable(device)) {
 				if (IsMediaBlank(device))
 					return true;
-				if (wxMessageBox(wxString::Format(_("Please insert erasable DVD into the device %s."),
+				if (wxMessageBox(wxString::Format(_("Please insert a rewritable DVD into the device %s."),
 						GetDeviceName(device).c_str()), _("Burn"), wxOK|wxCANCEL, this) == wxCANCEL) {
 					AddSummaryMsg(_("Aborted"), wxEmptyString, *wxRED);
 					return false;
@@ -1112,7 +1275,7 @@ bool ProgressDlg::BurnDvd(BurnDlg* burnDlg, DVD* dvd, const wxString& dvdOutDir,
 	wxString cmd;
 #ifdef __WXMAC__
 	while (!IsMediaPresent(device)) {
-		if (wxMessageBox(wxString::Format(_("Please insert empty DVD into the device %s."),
+		if (wxMessageBox(wxString::Format(_("Please insert a blank or rewritable DVD into the device %s."),
 				GetDeviceName(device).c_str()), _("Burn"), wxOK|wxCANCEL, this) == wxCANCEL) {
 		   AddSummaryMsg(_("Aborted"), wxEmptyString, *wxRED);
 		   return false;
@@ -1130,7 +1293,7 @@ bool ProgressDlg::BurnDvd(BurnDlg* burnDlg, DVD* dvd, const wxString& dvdOutDir,
 	while (true) {
 		if (wxExecute(cmd, output, wxEXEC_SYNC | wxEXEC_NODISABLE) == 0)
 			break;
-		if (wxMessageBox(wxString::Format(_("Please insert empty DVD into the device %s."), device.c_str()),
+		if (wxMessageBox(wxString::Format(_("Please insert a blank or rewritable DVD into the device %s."), device.c_str()),
 				_("Burn"), wxOK|wxCANCEL, this) == wxCANCEL) {
 			AddSummaryMsg(_("Aborted"), wxEmptyString, *wxRED);
 			return false;
@@ -1188,7 +1351,9 @@ bool ProgressDlg::BurnDvd(BurnDlg* burnDlg, DVD* dvd, const wxString& dvdOutDir,
 		cmd = s_config.GetBurnCmd();
 		cmd.Replace(_T("$DIR"), dvdOutDir.Mid(0, dvdOutDir.length() - 1));
 	}
-	cmd.Replace(_T("$VOL_ID"), dvd->GetLabel());
+	wxString label = dvd->GetLabel();
+	label.Replace(wxT("\""), wxT("\\\""));
+	cmd.Replace(_T("$VOL_ID"), label);
 	cmd.Replace(_T("$DEV"), device);
 	wxString speedStr;
 	if (burnDlg->GetSpeed() > 0) {
@@ -1214,13 +1379,13 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 	// set output formats
 	double startTime = vob->GetStartTime();
 	double recordingTime = vob->GetRecordingTime();
-	bool needEncode = vob->GetAudioFilenames().GetCount() != vob->GetAudioStreamCount()
+	bool needEncode = vob->GetAudioFilenames().size() != vob->GetAudioStreamCount()
 			|| startTime != 0 || recordingTime != -1; // some files are not elementary streams
 	VideoFormat videoFormat = vfCOPY;
 	bool ntscFilm = false;
 	wxArrayInt audioFormats;
 	wxArrayInt subtitleFormats;
-	for (unsigned int stIdx = 0; stIdx < vob->GetStreams().GetCount(); stIdx++) {
+	for (unsigned int stIdx = 0; stIdx < vob->GetStreams().size(); stIdx++) {
 		Stream* stream = vob->GetStreams()[stIdx];
 		switch (stream->GetType()) {
 		case stVIDEO:
@@ -1287,21 +1452,16 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 		}
 		
 		// set video filters
-		wxString videoFilters = vob->GetAllVideoFilters();
-		if (videoFilters.length() > 0) {
-			wxLogMessage(wxT("Video filters: ") + videoFilters);
-		}
-		transcoder.SetVideoFilters(videoFilters);
+		transcoder.SetVideoFilters(vob->GetAllVideoFilters());
 		
-		// set audio volume
+		// set audio filters
 		int audioIdx = 0;
-		for (unsigned int stIdx = 0; stIdx < vob->GetStreams().GetCount(); stIdx++) {
+		for (unsigned int stIdx = 0; stIdx < vob->GetStreams().size(); stIdx++) {
 			Stream* stream = vob->GetStreams()[stIdx];
 			if (stream->GetType() == stAUDIO) {
-				if (stream->GetAudioVolume() != 256)
-					transcoder.SetAudioVolume(audioIdx, stream->GetAudioVolume());
-				if (stream->GetChannelNumber() > 0)
-					transcoder.SetChannelNumber(audioIdx, stream->GetChannelNumber());
+				wxString audioFilters = stream->GetAllAudioFilters();
+				if (audioFilters.length())
+					transcoder.SetAudioFilters(audioIdx, audioFilters);
 				audioIdx++;
 			}
 		}
@@ -1318,8 +1478,8 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 		if (!useMplex) {
 			double fps = GetFps(videoFormat, ntscFilm);
 			AVConvExecute exec(this, lround(vob->GetDuration() * fps));
-			if (!transcoder.SetOutputFile(vob->GetTmpFilename(), videoFormat, ntscFilm, audioFormats, subtitleFormats,
-					videoBitrate, s_config.GetVbr(), audioBitrate)
+			if (!transcoder.SetOutputFile(vob->GetTmpFilename(), videoFormat, ntscFilm, aspect, audioFormats,
+					subtitleFormats, videoBitrate, s_config.GetVbr(), audioBitrate)
 					|| !exec.Execute(transcoder.GetCmd())) {
 				if (wxFileExists(vob->GetTmpFilename()))
 					wxRemoveFile(vob->GetTmpFilename());
@@ -1330,26 +1490,28 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 			wxString videoFile = vob->GetTmpFilename() + wxT(".m2v");
 			if (wxFileExists(videoFile) && !wxRemoveFile(videoFile)) {
 				wxLogError(wxString::Format(_("Can't remove file '%s'"), videoFile.c_str()));
+				return false;
 			}
-			if (!transcoder.SetOutputFile(videoFile, videoFormat, ntscFilm, afNONE, sfNONE,
+			if (!transcoder.SetOutputFile(videoFile, videoFormat, ntscFilm, aspect, afNONE, sfNONE,
 					videoBitrate, s_config.GetVbr(), audioBitrate, 0, vob->GetVideoStreamIndex())) {
 				Failed(_("Error transcoding of ") + vob->GetFilename());
 				return false;
 			}
 			wxArrayString audioFiles;
-			for (unsigned int audioIdx = 0; audioIdx < audioFormats.GetCount(); audioIdx++) {
+			for (unsigned int audioIdx = 0; audioIdx < audioFormats.size(); audioIdx++) {
 				if (audioFormats[audioIdx] == afNONE)
 					continue;
 				wxString audioFile = vob->GetTmpFilename() + wxString::Format(wxT(".audio%u"), audioIdx);
 				audioFiles.Add(audioFile);
 				if (wxFileExists(audioFile) && !wxRemoveFile(audioFile)) {
 					wxLogError(wxString::Format(_("Can't remove file '%s'"), audioFile.c_str()));
+					return false;
 				}
 				if (startTime != 0)
 					transcoder.SetStartTime(startTime);
 				if (recordingTime > 0)
 					transcoder.SetRecordingTime(recordingTime);
-				int audioFileIdx = audioIdx + 1 - audioFormats.GetCount() + vob->GetAudioFilenames().size();
+				int audioFileIdx = audioIdx + 1 - audioFormats.size() + vob->GetAudioFilenames().size();
 				int audioStreamIdx = audioIdx;
 				if (audioFileIdx <= 0) {
 					audioFileIdx = 0;
@@ -1357,8 +1519,8 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 						audioStreamIdx++;
 				} else
 					audioStreamIdx = 0;
-				if (!transcoder.SetOutputFile(audioFile, vfNONE, false, (AudioFormat) audioFormats[audioIdx], sfNONE,
-						videoBitrate, s_config.GetVbr(), audioBitrate, audioFileIdx, audioStreamIdx)) {
+				if (!transcoder.SetOutputFile(audioFile, vfNONE, false, aspect, (AudioFormat) audioFormats[audioIdx],
+						sfNONE, videoBitrate, s_config.GetVbr(), audioBitrate, audioFileIdx, audioStreamIdx)) {
 					Failed(_("Error transcoding of ") + vob->GetFilename());
 					return false;
 				}
@@ -1368,7 +1530,7 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 			if (!exec.Execute(transcoder.GetCmd())) {
 				if (wxFileExists(videoFile))
 					wxRemoveFile(videoFile);
-				for (unsigned int audioIdx = 0; audioIdx < audioFiles.GetCount(); audioIdx++)
+				for (unsigned int audioIdx = 0; audioIdx < audioFiles.size(); audioIdx++)
 					if (wxFileExists(audioFiles[audioIdx]))
 						wxRemoveFile(audioFiles[audioIdx]);
 				Failed(_("Error transcoding of ") + vob->GetFilename());
@@ -1378,7 +1540,7 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 			if (!Multiplex(videoFile, audioFiles, vob->GetTmpFilename())) {
 				if (wxFileExists(videoFile))
 					wxRemoveFile(videoFile);
-				for (unsigned int audioIdx = 0; audioIdx < audioFiles.GetCount(); audioIdx++)
+				for (unsigned int audioIdx = 0; audioIdx < audioFiles.size(); audioIdx++)
 					if (wxFileExists(audioFiles[audioIdx]))
 						wxRemoveFile(audioFiles[audioIdx]);
 				return false;
@@ -1386,7 +1548,7 @@ bool ProgressDlg::Transcode(Vob* vob, AspectRatio aspect, int videoBitrate, int
 			// remove temp files
 			if (s_config.GetRemoveTempFiles()) {
 				DeleteFile(videoFile);
-				for (unsigned int audioIdx = 0; audioIdx < audioFiles.GetCount(); audioIdx++)
+				for (unsigned int audioIdx = 0; audioIdx < audioFiles.size(); audioIdx++)
 					DeleteFile(audioFiles[audioIdx]);
 			}
 		}
@@ -1456,7 +1618,7 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 			}
 		}
 		// encode video
-		bool hasAudio = audioFile.length() || bgAudioFormat != afNONE;
+		bool hasAudio = audioFile.length() || bgAudioFormat != afNONE || s_config.GetUseMplexForMenus();
 		wxFfmpegMediaEncoder ffmpeg(s_config.GetThreadCount());
 		if (!ffmpeg.BeginEncode(hasAudio ? m2vFile : mpegFile, menu->GetVideoFormat(), hasAudio ? afNONE : audioFormat,
 				menu->GetAspectRatio(), s_config.GetMenuVideoBitrate())) {
@@ -1485,11 +1647,24 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 		}
 		ffmpeg.EndEncode();
 		if (hasAudio) {
+			if (audioFile.length() == 0 && bgAudioFormat == afNONE) {
+				// encode audio
+				audioFileTmp = menuFile + wxString(wxT("_bg.")) + (audioFormat == afAC3 ? wxT("ac3") : wxT("mp2"));
+				double duration = (double) frameCount / GetFps(menu->GetVideoFormat(), false);
+				if (!ffmpeg.BeginEncode(audioFileTmp, vfNONE, audioFormat, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate())
+						|| !ffmpeg.EncodeAudio(duration, &m_cancel)) {
+					Failed(_("Error creation of menu"));
+					return false;
+				}
+				ffmpeg.EndEncode();
+			}
 			Vob menuVob;
 			menuVob.SetFilename(m2vFile);
 			menuVob.GetVideoStream()->SetDestinationFormat(vfCOPY);
 			if (audioFile.length()) {
 				menuVob.AddAudioFile(audioFile);
+			} else if (bgAudioFormat == afNONE) {
+				menuVob.AddAudioFile(audioFileTmp);
 			} else {
 				AddDetailMsg(_("Transcode audio from") + wxString(wxT(" ")) + menu->GetBackground());
 				// transcode audio
@@ -1499,22 +1674,21 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 					return false;
 				}
 				transcoder.SetOutputFormat(bgAudioOutputFormat);
-				if (!transcoder.SetOutputFile(audioFileTmp, vfNONE, false, bgAudioFormat, sfNONE, 0, false,
-						audioBitrate)) {
+				if (!transcoder.SetOutputFile(audioFileTmp, vfNONE, false, menu->GetAspectRatio(), bgAudioFormat,
+						sfNONE, 0, false, audioBitrate)) {
 					Failed(_("Error transcoding of ") + menu->GetBackground());
 					return false;
 				}
 				AVConvExecute exec(this, -1);
 				if (!exec.Execute(transcoder.GetCmd())) {
-					if (wxFileExists(audioFileTmp))
-						wxRemoveFile(audioFileTmp);
+					DeleteFile(audioFileTmp);
 					Failed(_("Error transcoding of ") + menu->GetBackground());
 					return false;
 				}
 				menuVob.AddAudioFile(audioFileTmp);
 			}
 			AddDetailMsg(_("Multiplexing audio and video"));
-			for (unsigned int i=0; i<menuVob.GetStreams().GetCount(); i++) {
+			for (unsigned int i=0; i<menuVob.GetStreams().size(); i++) {
 				Stream* stream = menuVob.GetStreams()[i];
 				if (stream->GetType() == stAUDIO && stream->GetAudioFormat() == afCOPY) {
 					// change destination format if it set to COPY and codec is not mp2/ac3 or sample rate != 48 kHz
@@ -1534,8 +1708,7 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 				return false;
 			if (s_config.GetRemoveTempFiles()) {
 				DeleteFile(m2vFile);
-				if (wxFileExists(audioFileTmp))
-					wxRemoveFile(audioFileTmp);
+				DeleteFile(audioFileTmp);
 			}
 		}
 	} else { // menu with still image
@@ -1544,8 +1717,11 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 			Failed(_("Error creation of menu"));
 			return false;
 		}
+		
+		bool hasAudio = audioFile.length() || s_config.GetUseMplexForMenus();
 		int frameCount = s_config.GetMenuFrameCount();
 		if (audioFile.length() > 0) {
+			// get audio duration
 			wxFfmpegMediaDecoder decoder;
 			if (decoder.Load(audioFile)) {
 				double duration = decoder.GetDuration();
@@ -1558,17 +1734,30 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 				}
 			}
 		}
+		
+		// encode video
 		wxFfmpegMediaEncoder ffmpeg(s_config.GetThreadCount());
-		if (!ffmpeg.BeginEncode(audioFile.length() ? m2vFile : mpegFile, menu->GetVideoFormat(),
-				audioFile.length() ? afNONE : audioFormat, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate())
+		if (!ffmpeg.BeginEncode(hasAudio ? m2vFile : mpegFile, menu->GetVideoFormat(),
+				hasAudio ? afNONE : audioFormat, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate())
 				|| !ffmpeg.EncodeImage(bgImage, frameCount, &m_cancel)) {
 			Failed(_("Error creation of menu"));
 			return false;
 		}
 		ffmpeg.EndEncode();
 		IncSubStep(25);
-
-		if (audioFile.length()) {
+		
+		if (hasAudio) {
+			if (audioFile.length() == 0) {
+				// encode audio
+				audioFileTmp = menuFile + wxString(wxT("_bg.")) + (audioFormat == afAC3 ? wxT("ac3") : wxT("mp2"));
+				double duration = (double) frameCount / GetFps(menu->GetVideoFormat(), false);
+				if (!ffmpeg.BeginEncode(audioFileTmp, vfNONE, audioFormat, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate())
+						|| !ffmpeg.EncodeAudio(duration, &m_cancel)) {
+					Failed(_("Error creation of menu"));
+					return false;
+				}
+				ffmpeg.EndEncode();
+			}
 			IncSubStep(75);
 			// mplex (and optionally transcode audio)
 			if (IsCanceled())
@@ -1576,11 +1765,11 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 			AddDetailMsg(_("Multiplexing audio and video"));
 			Vob menuVob;
 			menuVob.SetFilename(m2vFile);
-			menuVob.AddAudioFile(audioFile);
-			for (unsigned int i=0; i<menuVob.GetStreams().GetCount(); i++) {
+			menuVob.AddAudioFile(audioFile.length() ? audioFile : audioFileTmp);
+			for (unsigned int i=0; i<menuVob.GetStreams().size(); i++) {
 				Stream* stream = menuVob.GetStreams()[i];
 				if (stream->GetType() == stAUDIO)
-					stream->SetDestinationFormat(audioFormat);
+					stream->SetDestinationFormat(audioFile.length() ? audioFormat : afCOPY);
 			}
 			menuVob.SetTmpFilename(mpegFile);
 			if (!s_config.GetUseMplexForMenus())
@@ -1588,8 +1777,10 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 			if (!Transcode(&menuVob, menu->GetAspectRatio(), s_config.GetMenuVideoBitrate(), audioBitrate,
 					s_config.GetUseMplexForMenus()))
 				return false;
-			if (s_config.GetRemoveTempFiles())
+			if (s_config.GetRemoveTempFiles()) {
 				DeleteFile(m2vFile);
+				DeleteFile(audioFileTmp);
+			}
 		}
 	}
 
@@ -1643,6 +1834,44 @@ bool ProgressDlg::GenerateMenu(Menu* menu, WidescreenType widescreenType, const
 	return true;
 }
 
+void SetAnimationDur(wxSVGElement* parent, double dur) {
+	wxSVGElement* elem = (wxSVGElement*) parent->GetChildren();
+	while (elem) {
+		if (elem->GetType() == wxSVGXML_ELEMENT_NODE) {
+			if (elem->GetDtd() == wxSVG_ANIMATE_ELEMENT) {
+				wxSVGAnimateElement* animateElem = (wxSVGAnimateElement*) elem;
+				animateElem->SetDur(dur);
+			} else if (elem->GetChildren()) {
+				SetAnimationDur(elem, dur);
+			}
+		}
+		elem = (wxSVGElement*) elem->GetNext();
+	}
+}
+
+bool ProgressDlg::LoadTransition(wxSVGDocument& svg, const wxString& fileName, Slideshow* slideshow, Slide* slide1,
+		Slide* slide2) {
+	if (!svg.Load(TRANSITION_FILE(fileName))) {
+		Failed(_("Error loading transition definition"));
+		return false;
+	}
+	svg.GetRootElement()->SetWidth(slideshow->GetResolution().GetWidth());
+	svg.GetRootElement()->SetHeight(slideshow->GetResolution().GetHeight());
+	
+	wxSVGImageElement* img1 = (wxSVGImageElement*) svg.GetElementById(wxT("image1"));
+	wxSVGImageElement* img2 = (wxSVGImageElement*) svg.GetElementById(wxT("image2"));
+	if (!img1 || !img2) {
+		Failed(wxT("Transition: image element with id 'image1' and/or 'image2' is not defined"));
+		return false;
+	}
+	
+	img1->SetHref(slide1->GetFilename());
+	img2->SetHref(slide2->GetFilename());
+	
+	SetAnimationDur(svg.GetRootElement(), s_config.GetDefTransitionDuration());
+	return true;
+}
+
 bool ProgressDlg::GenerateSlideshow(Slideshow* slideshow, const wxString& vobFile, AudioFormat audioFormat,
 		wxString audioFile, int audioBitrate) {
 	if (IsCanceled())
@@ -1658,8 +1887,22 @@ bool ProgressDlg::GenerateSlideshow(Slideshow* slideshow, const wxString& vobFil
 		Failed(_("Error creation of slideshow"));
 		return false;
 	}
-
-	for (unsigned i = 0; i < slideshow->GetCount(); i++) {
+	
+	int width = GetFrameSize(slideshow->GetVideoFormat()).GetWidth();
+	int height = GetFrameSize(slideshow->GetVideoFormat()).GetHeight();
+	
+	wxArrayString transitions;
+	wxString fname = wxFindFirstFile(TRANSITIONS_DIR + _T("*.xml"));
+	while (!fname.IsEmpty()) {
+		transitions.Add(wxFileName(fname).GetFullName());
+		fname = wxFindNextFile();
+	}
+	
+	int tLast = -1;
+	srand(time(NULL));
+	for (unsigned i = 0; i < slideshow->size(); i++) {
+		if (IsCanceled())
+			return false;
 		AddDetailMsg(wxString::Format(_("Converting slide %u image to video"), i + 1));
 		wxYield();
 		wxImage img = slideshow->GetImage(i);
@@ -1667,6 +1910,32 @@ bool ProgressDlg::GenerateSlideshow(Slideshow* slideshow, const wxString& vobFil
 			Failed(_("Error creation of slideshow"));
 			return false;
 		}
+		// Transition
+		wxString transition = slideshow->GetSlide(i)->GetTransition();
+		if (transition.length() == 0)
+			transition = slideshow->GetTransition();
+		if (transition.length() && transition != wxT("none") && i != slideshow->size() - 1) {
+			if (transition == wxT("random")) {
+				int t;
+				do {
+					t = rand() % transitions.size();
+				} while (t == tLast);
+				tLast = t;
+				transition = transitions[t];
+			}
+			wxSVGDocument svg;
+			if (!LoadTransition(svg, transition, slideshow, slideshow->GetSlide(i), slideshow->GetSlide(i + 1)))
+				return false;
+			int frameCount = slideshow->GetFPS();
+			for (int f = 0; f < frameCount; f++) {
+				wxImage img = svg.Render(width, height, NULL, false);
+				if (!ffmpeg.EncodeImage(img, 1)) {
+					Failed(_("Error creation of slideshow"));
+					return false;
+				}
+				svg.SetCurrentTime(((double) f) / slideshow->GetFPS());
+			}
+		}
 		IncSubStep(10);
 	}
 	ffmpeg.EndEncode();
@@ -1675,22 +1944,65 @@ bool ProgressDlg::GenerateSlideshow(Slideshow* slideshow, const wxString& vobFil
 		// mplex (and optionally transcode audio)
 		if (IsCanceled())
 			return false;
+		
+		wxFfmpegMediaDecoder ffmpeg;
+		if (!ffmpeg.Load(audioFile))
+			return false;
+		double audioDuration = ffmpeg.GetDuration();
+		AddDetailMsg(_("Audio file duration: ") + Time2String(audioDuration * 1000));
+		
+		int resultDuration = slideshow->GetResultDuration();
+		wxString concatFile;
+		if (audioDuration > 0 && audioDuration < resultDuration) {
+			// concate
+			AddDetailMsg(_("Concat audio files"));
+			int n = resultDuration / audioDuration + 1;
+//			concatFile = vobFile + wxT("_audio.txt");
+//			wxTextFile file(concatFile);
+//			file.Create();
+//			file.AddLine(wxT("ffconcat version 1.0"));
+//			for (int i = 0; i < n; i++)
+//				file.AddLine(wxT("file ") + audioFile);
+//			file.Write();
+			//ffmpeg -i 1.mp2 -i 1.mp2 -filter_complex "[0:0] [1:0] concat=n=2:v=0:a=1 [a]" -map "[a]"
+			concatFile = vobFile + wxString(wxT("_audio.")) + (audioFormat  == afMP2 ? wxT("mp2") : wxT("ac3"));
+			wxString avCmd = s_config.GetAVConvCmd();
+			wxString filter;
+			for (int i = 0; i < n; i++) {
+				avCmd += wxT(" -i \"") + audioFile + wxT("\"");
+				filter += wxString::Format(wxT("[%d:0] "), i);
+			}
+			filter += wxString::Format(wxT("concat=n=%d:v=0:a=1 [a]"), n);
+			avCmd += wxT(" -filter_complex \"") + filter + wxT("\" -map \"[a]\" \"") + concatFile + wxT("\"");
+			AVConvExecute exec(this, 0);
+			if (!exec.Execute(avCmd)) {
+				if (wxFileExists(concatFile))
+					wxRemoveFile(concatFile);
+				Failed(_("Error transcoding of ") + audioFile);
+				return false;
+			}
+		}
+		
 		AddDetailMsg(_("Multiplexing audio and video"));
+		
 		Vob slideShowVob;
 		slideShowVob.SetFilename(m2vFile);
-		slideShowVob.AddAudioFile(audioFile);
-		for (unsigned int i=0; i<slideShowVob.GetStreams().GetCount(); i++) {
+		slideShowVob.AddAudioFile(concatFile.length() ? concatFile : audioFile);
+		for (unsigned int i=0; i<slideShowVob.GetStreams().size(); i++) {
 			Stream* stream = slideShowVob.GetStreams()[i];
 			if (stream->GetType() == stAUDIO)
 				stream->SetAudioFormat(audioFormat);
 		}
 		slideShowVob.SetTmpFilename(vobFile);
-		slideShowVob.SetRecordingTime(slideshow->GetDuration() * slideshow->GetCount());
+		slideShowVob.SetRecordingTime(resultDuration);
 		if (!Transcode(&slideShowVob, slideshow->GetAspectRatio(), s_config.GetSlideshowVideoBitrate(),
 				audioBitrate, s_config.GetUseMplexForMenus()))
 			return false;
-		if (s_config.GetRemoveTempFiles())
+		if (s_config.GetRemoveTempFiles()) {
 			DeleteFile(m2vFile);
+			if (concatFile.length())
+				DeleteFile(concatFile);
+		}
 	}
 
 	wxYield();
@@ -1698,21 +2010,18 @@ bool ProgressDlg::GenerateSlideshow(Slideshow* slideshow, const wxString& vobFil
 }
 
 bool ProgressDlg::DeleteFile(wxString fname) {
-	if (!wxRemoveFile(fname)) {
+	if (wxFileExists(fname) && !wxRemoveFile(fname)) {
 		AddDetailMsg(wxString::Format(_("Can't remove file '%s'"), fname.c_str()), *wxRED);
 		return false;
 	}
 	return true;
 }
 
-bool ProgressDlg::DeleteDir(wxString dir, bool subdirs) {
+bool ProgressDlg::DeleteDir(wxString dir) {
 	if (dir.Last() != wxFILE_SEP_PATH)
 		dir += wxFILE_SEP_PATH;
 	wxDir d(dir);
 	wxString fname;
-	while (subdirs && d.GetFirst(&fname, wxEmptyString, wxDIR_DIRS))
-		if (!DeleteDir(dir + fname, true))
-			return false;
 	while (d.GetFirst(&fname, wxEmptyString, wxDIR_FILES | wxDIR_HIDDEN))
 		if (!DeleteFile(dir + fname))
 			return false;
@@ -1725,10 +2034,22 @@ bool ProgressDlg::DeleteDir(wxString dir, bool subdirs) {
 bool ProgressDlg::DeleteTempFiles(const wxString& tmpDir, const wxString& dvdTmpDir, const wxString& dvdOutDir,
 		bool deleteOutDir) {
 	AddDetailMsg(_("Cleaning temporary directory"));
-	if (wxDirExists(dvdTmpDir) && !DeleteDir(dvdTmpDir, false))
-		return false;
-	if (deleteOutDir && wxDirExists(dvdOutDir) && !DeleteDir(dvdOutDir, true))
+	if (wxDirExists(dvdTmpDir) && !DeleteDir(dvdTmpDir)) {
+		wxLogError(_("Cannot remove directory '%s'"), dvdTmpDir.c_str());
 		return false;
+	}
+	if (deleteOutDir && wxDirExists(dvdOutDir)) {
+		if (!DeleteDir(dvdOutDir + wxT("VIDEO_TS"))) {
+			return false;
+		}
+		if (!DeleteDir(dvdOutDir + wxT("AUDIO_TS"))) {
+			return false;
+		}
+		if (!wxRmdir(dvdOutDir)) {
+			wxLogError(_("Cannot remove directory '%s'"), dvdOutDir.c_str());
+			return false;
+		}
+	}
 	if (wxFileExists(tmpDir + TMP_ISO) && !DeleteFile(tmpDir + TMP_ISO))
 		return false;
 	return true;
