@@ -3,7 +3,7 @@
 // Purpose:     Settings dialog
 // Author:      Alex Thuering
 // Created:     27.03.2004
-// RCS-ID:      $Id: SettingsDlg.cpp,v 1.68 2013/06/23 21:02:31 ntalex Exp $
+// RCS-ID:      $Id: SettingsDlg.cpp,v 1.71 2013/10/25 21:19:15 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -17,6 +17,7 @@
 #include <wx/filename.h>
 
 #define BUTTONS_DIR wxFindDataDirectory(_T("buttons"))
+#define TRANSITIONS_DIR wxFindDataDirectory(wxT("transitions"))
 
 enum {
 	FILE_BROWSER_CHOICE_ID = 7900,
@@ -122,6 +123,7 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	// default title post command
 	labels = DVD::GetDefPostCommandLabels();
 	AddChoiceProp(interfaceGrid, _("Default title post command:"), labels[s_config.GetDefPostCommand(def)], labels, 0);
+	wxControl* postCommandChoice = GetLastControl();
 	
 	// default button
 	int sel = 0;
@@ -145,9 +147,24 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 	}
 	wxSizer* dbtSizer = AddChoiceProp(interfaceGrid, _("Default button:"), labels[sel], labels, 0, false);
 	wxControl* defButtonChoice = GetLastControl();
+	if (postCommandChoice->GetBestSize().GetWidth() < defButtonChoice->GetBestSize().GetWidth())
+		postCommandChoice->SetMinSize(defButtonChoice->GetBestSize());
 	if (dbtSizer)
 		dbtSizer->AddSpacer(4);
 	AddCheckProp(dbtSizer, _("Accept invalid actions"), s_config.GetAcceptInvalidActions(def));
+	
+	// Slideshow
+	AddSpinProp(interfaceGrid, _("Default slide duration:"), s_config.GetDefSlideDuration(def), 0, 999, 60, _("sec"));
+	AddSpinDoubleProp(interfaceGrid, _("Default transition duration:"), s_config.GetDefTransitionDuration(def),
+			0, 99, 60, _("sec"));
+	Slideshow::GetTransitions(m_transitions, labels);
+	sel = 0;
+	for (unsigned int i = 0; i <= m_transitions.GetCount() - 1; i++)
+		if (m_transitions[i] == s_config.GetDefTransition(def))
+			sel = i;
+	AddChoiceProp(interfaceGrid, _("Default slide transition:"), labels[sel], labels, 0, false);
+	if (GetLastControl()->GetBestSize().GetWidth() < defButtonChoice->GetBestSize().GetWidth())
+		GetLastControl()->SetMinSize(defButtonChoice->GetBestSize());
 
 	// File Browser start directory
 	wxString fbDir = s_config.GetFileBrowserDir();
@@ -156,8 +173,6 @@ void SettingsDlg::CreatePropPanel(wxSizer* sizer) {
 		fbChoices[fbDir.IsEmpty() ? 0 : 1], wxArrayString(2, fbChoices), 0, false, FILE_BROWSER_CHOICE_ID);
 	if (GetLastControl()->GetBestSize().GetWidth() < defButtonChoice->GetBestSize().GetWidth())
 		GetLastControl()->SetMinSize(defButtonChoice->GetBestSize());
-	else
-		defButtonChoice->SetMinSize(GetLastControl()->GetBestSize());
 	if (fbSizer)
 		fbSizer->AddSpacer(4);
 	AddDirectoryProp(fbSizer, wxT(""), fbDir);
@@ -255,6 +270,10 @@ bool SettingsDlg::SetValues() {
 	s_config.SetDefPostCommand(GetInt(i++));
 	s_config.SetDefButton(m_buttons[GetInt(i++)]);
 	s_config.SetAcceptInvalidActions(GetBool(i++));
+	s_config.SetDefSlideDuration(GetInt(i++));
+	s_config.SetDefTransitionDuration(GetDouble(i++));
+	s_config.SetDefTransition(m_transitions[GetInt(i++)]);
+	
 	i++;
 	s_config.SetFileBrowserDir(GetString(i++));
 #ifndef GNOME2
@@ -291,7 +310,8 @@ void SettingsDlg::OnChangeFileBrowserDir(wxCommandEvent& evt) {
 
 void SettingsDlg::OnResetDontShowFlags(wxCommandEvent& evt) {
 	s_config.SetShowWelcomeDlg(true);
-	s_config.SetShowTitleDeletePrompt(true);
+	s_config.SetTitleDeletePrompt(true);
+	s_config.SetOverwriteOutputDirPrompt(true);
 	wxMessageBox(_("All \"don't show again\" flags are reseted."), _("Settings"),
 			wxOK | wxCENTRE | wxICON_INFORMATION);
 }
