@@ -3,7 +3,7 @@
 // Purpose:     Titleset Manager
 // Author:      Alex Thuering
 // Created:	27.01.2003
-// RCS-ID:      $Id: TitlesetManager.cpp,v 1.76 2013/06/23 21:02:31 ntalex Exp $
+// RCS-ID:      $Id: TitlesetManager.cpp,v 1.92 2014/03/31 08:37:09 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -71,14 +71,14 @@ public:
 
 	bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& filenames, wxDragResult def) {
 		bool res = false;
-		for (int i = 0; i<(int)filenames.Count(); i++)
-			res = AddFile(filenames[i], i == 0, def) || res;
+		for (unsigned int i = 0; i < filenames.size(); i++)
+			res = AddFile(filenames[i], i == 0, i == filenames.size() - 1, def) || res;
 		return res;
 	}
 	
-	bool AddFile(wxString filename, bool first, wxDragResult def) {
+	bool AddFile(wxString filename, bool first, bool last, wxDragResult def) {
 		if (wxImage::FindHandler(filename.AfterLast('.').Lower(), BITMAP_TYPE_ANY)) {
-			m_pOwner->AddImage(filename, def == wxDragMove && first);
+			m_pOwner->AddImage(filename, def == wxDragMove && first, last);
 			return true;
 		} else if (wxThumbnails::IsVideo(filename)) {
 			return m_pOwner->AddVideo(filename, def == wxDragMove);
@@ -139,12 +139,15 @@ TitlesetManager::TitlesetManager(wxWindow* parent, int id): wxThumbnails(parent,
 	m_dvd = NULL;
 	m_selectedMenu = -1;
 	m_reEncodingByDefault = false;
+	m_progressDlg = NULL;
 
 	wxMenu* addMenu = new wxMenu;
 	addMenu->Append(MainWin::MENU_DVD_ADD_FILE_ID, _("&File..."));
 	addMenu->Append(MainWin::MENU_DVD_ADD_FILE_AS_CHAPTER_ID, _("File as &chapter..."));
+	addMenu->Append(MainWin::MENU_DVD_ADD_TITLES_FROM_DVD_ID, _("Titles from &DVD..."));
 	addMenu->Append(MainWin::MENU_DVD_ADD_MENU_ID, _("&Menu"));
-	addMenu->Append(MainWin::MENU_DVD_ADD_VMMENU_ID, _("&vmMenu"));
+	addMenu->Append(MainWin::MENU_DVD_ADD_CHAPTER_MENU_ID, _("&Chapter menu"));
+	addMenu->Append(MainWin::MENU_DVD_ADD_VMMENU_ID, _("&VMGM Menu"));
 	addMenu->Append(MainWin::MENU_DVD_ADD_TITLESET_ID, _("&Titleset"));
 
 	m_mainMenu = new wxMenu;
@@ -162,8 +165,10 @@ TitlesetManager::TitlesetManager(wxWindow* parent, int id): wxThumbnails(parent,
 	wxMenu* addMenu2 = new wxMenu;
 	addMenu2->Append(MainWin::MENU_DVD_ADD_FILE_ID, _("&File..."));
 	addMenu2->Append(MainWin::MENU_DVD_ADD_FILE_AS_CHAPTER_ID, _("File as &chapter..."));
+	addMenu2->Append(MainWin::MENU_DVD_ADD_TITLES_FROM_DVD_ID, _("Titles from &DVD..."));
 	addMenu2->Append(MainWin::MENU_DVD_ADD_MENU_ID, _("&Menu"));
-	addMenu2->Append(MainWin::MENU_DVD_ADD_VMMENU_ID, _("&vmMenu"));
+	addMenu2->Append(MainWin::MENU_DVD_ADD_CHAPTER_MENU_ID, _("&Chapter menu"));
+	addMenu2->Append(MainWin::MENU_DVD_ADD_VMMENU_ID, _("&VMGM Menu"));
 	addMenu2->Append(MainWin::MENU_DVD_ADD_TITLESET_ID, _("&Titleset"));
 
 	m_titleMenu = new wxMenu;
@@ -196,13 +201,17 @@ void TitlesetManager::SetDVD(DVD* dvd) {
 wxBitmap TitlesetManager::GetThumbImage(wxThumb& thumb) {
 	if (!m_dvd)
 		return wxBitmap();
+	if (m_progressDlg)
+		m_progressDlg->Pulse();
 	int id = thumb.GetId();
 	Vob* vob = m_dvd->GetVob(DVD::GetTsi(id), DVD::IsMenu(id), DVD::GetPgci(id), DVD::GetVobi(id));
 	wxBitmap img = thumb.GetBitmap();
 	if (!img.Ok()) {
 		int titleHeight = m_tTextHeight + 2;
+		if (m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0)
+			titleHeight *= 2;
 		if (vob->GetMenu()) {
-			img = wxBitmap(vob->GetMenu()->GetImage(m_tWidth-8, m_tHeight-titleHeight));
+			img = wxBitmap(vob->GetMenu()->GetImage(m_tWidth-8, m_tHeight-titleHeight, m_progressDlg));
 			thumb.SetBitmap(img);
 		} else if (vob->GetSlideshow()) {
 			img = wxBitmap(vob->GetSlideshow()->GetThumbImage(m_tWidth-8, m_tHeight-titleHeight));
@@ -229,45 +238,47 @@ void TitlesetManager::DrawThumbnail(wxBitmap& bmp, wxThumb& thumb, int index) {
 	dc.SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
 	int x = m_tBorder/2;
 	int y = m_tBorder/2;
+	int y1 = y;
 	int tw = bmp.GetWidth() - m_tBorder + 2;
 	int th = bmp.GetHeight() - m_tBorder + 2;
-	int titleHeight = m_tTextHeight + 2;
+	int th1 = th;
+	int titleHeight1 = m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0 ? m_tTextHeight + 2 : 0;
+	int titleHeight2 = m_tTextHeight + 2;
+	int titleHeight = titleHeight1 + titleHeight2;
 	// background
 	dc.SetPen(wxPen(*wxBLACK, 0, wxTRANSPARENT));
 	dc.SetBrush(wxBrush(GetBackgroundColour(), wxSOLID));
 	dc.DrawRectangle(0, 0, bmp.GetWidth(), bmp.GetHeight());
-	if (pgc->GetVobs().Count() > 1) {
-		dc.SetBrush(wxBrush(wxColour(64, 64, 64), wxSOLID));
-		if (vobi == 0) {
+	if (m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0) {
+		// rounded rectangle
+		dc.SetBrush(wxBrush(wxColour(128, 128, 128), wxSOLID));
+		dc.DrawRoundedRectangle(x, y, tw, th, 12);
+		if (IsBeginOfTitleset(tsi, pgci, vobi, isMenu) && IsEndOfTitleset(tsi, pgci, vobi, isMenu)) {
+			// nothing to do
+		} else if (IsBeginOfTitleset(tsi, pgci, vobi, isMenu)) {
 			dc.DrawRectangle(bmp.GetWidth()/2, y, bmp.GetWidth()/2, th);
-		} else if (vobi == (int) pgc->GetVobs().Count() - 1) {
+		} else if (IsEndOfTitleset(tsi, pgci, vobi, isMenu)) {
 			dc.DrawRectangle(0, y, bmp.GetWidth()/2, th);
 		} else {
 			dc.DrawRectangle(0, y, bmp.GetWidth(), th);
 		}
+		y1 += titleHeight1;
+		th1 -= titleHeight1;
+	}
+	if (pgc->GetVobs().Count() > 1) {
+		dc.SetBrush(wxBrush(wxColour(64, 64, 64), wxSOLID));
+		if (vobi == 0) {
+			dc.DrawRectangle(bmp.GetWidth()/2, y1, bmp.GetWidth()/2, th1);
+		} else if (vobi == (int) pgc->GetVobs().Count() - 1) {
+			dc.DrawRectangle(0, y1, bmp.GetWidth()/2, th1);
+		} else {
+			dc.DrawRectangle(0, y1, bmp.GetWidth(), th1);
+		}
 	}
 	// rounded rectangle
 	wxColour rectColour = isMenu ? wxColour(64, 64, 64) : wxColour(0, 0, 0);
 	dc.SetBrush(wxBrush(rectColour, wxSOLID));
-	dc.DrawRoundedRectangle(x, y, tw, th, 12);
-	// draw begin & end of titleset
-	if (IsBeginOfTitleset(tsi, pgci, vobi, isMenu)) {
-		int h = bmp.GetHeight();
-		dc.SetPen(wxPen(*wxRED, 0, wxSOLID));
-		dc.DrawLine(1, 1, 10, 1);
-		dc.DrawLine(1, 1, 1, 10);
-		dc.DrawLine(1, h-2, 10, h-2);
-		dc.DrawLine(1, h-2, 1, h-11);
-	}
-	if (IsEndOfTitleset(tsi, pgci, vobi, isMenu)) {
-		int h = bmp.GetHeight();
-		int w = bmp.GetWidth();
-		dc.SetPen(wxPen(*wxRED, 0, wxSOLID));
-		dc.DrawLine(w-1, 1, w-10, 1);
-		dc.DrawLine(w-1, 1, w-1, 10);
-		dc.DrawLine(w-1, h-2, w-10, h-2);
-		dc.DrawLine(w-1, h-2, w-1, h-11);
-	}
+	dc.DrawRoundedRectangle(x, y1, tw, th1, 12);
 	// image
 	wxBitmap img = GetThumbImage(thumb);
 	if (index == m_pointed) {
@@ -297,24 +308,32 @@ void TitlesetManager::DrawThumbnail(wxBitmap& bmp, wxThumb& thumb, int index) {
 		dc.SetBrush(wxBrush(*wxBLACK, wxTRANSPARENT));
 		dc.DrawRectangle(imgRect.x-1, imgRect.y-1, imgRect.width+1, imgRect.height+1);
 	}
+	// draw titleset caption
+	if (titleHeight1 > 0 && IsBeginOfTitleset(tsi, pgci, vobi, isMenu)) {
+		dc.SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
+		dc.SetTextForeground(*wxWHITE);
+		wxString text = wxT("VMGM");
+		if (tsi >= 0) {
+			text = _("Titleset") + wxString::Format(_T(" %d"), tsi + 1);
+		}
+		int sw, sh;
+		dc.GetTextExtent(text, &sw, &sh);
+		int tx = x + (m_tWidth-sw)/2;
+		int ty = y + (titleHeight1-sh)/2;
+		dc.DrawText(text, tx, ty);
+	}
 	// draw title caption
 	dc.SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
 	dc.SetTextForeground(*wxWHITE);
-	wxString caption;
-	if (isMenu && tsi<0)
-		caption = _("vmMenu");
-	else if (isMenu)
-		caption = _("Menu");
-	else
-		caption = _("Title");
-	caption += wxString::Format(_T(" %d"), pgci+1);
+	wxString title = isMenu ? _("Menu") : _("Title");
+	title += wxString::Format(_T(" %d"), pgci+1);
 	if (vobi>0)
-		caption += wxString::Format(_T("-%d"), vobi+1);
+		title += wxString::Format(_T("-%d"), vobi+1);
 	int sw, sh;
-	dc.GetTextExtent(caption, &sw, &sh);
+	dc.GetTextExtent(title, &sw, &sh);
 	int tx = x + (m_tWidth-sw)/2;
-	int ty = y + (titleHeight-sh)/2;
-	dc.DrawText(caption, tx, ty);
+	int ty = y + titleHeight1 + (titleHeight2-sh)/2;
+	dc.DrawText(title, tx, ty);
 	// draw caption
 	for (int i=0; i<thumb.GetCaptionLinesCount(m_tWidth-m_tCaptionBorder); i++) {
 		wxString caption = thumb.GetCaption(i);
@@ -334,7 +353,7 @@ void TitlesetManager::Paint(wxPaintDC& dc) {
 		dc.SetBrush(wxBrush(GetBackgroundColour(), wxTRANSPARENT));
 		dc.SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
 		int col = m_items.GetCount() % m_cols;
-		dc.DrawText(_("Drag here your video files from file browser"),
+		dc.DrawText(_("Drag your video files from the File Browser to here."),
 				col * (m_tWidth + m_tBorder) + 2 * m_tBorder, m_tBorder + m_tHeight / 2);
 	}
 }
@@ -347,7 +366,10 @@ int TitlesetManager::GetRowHeight(unsigned int begRow, unsigned int count) {
 	return (m_tHeight + m_tBorder)*count + capHeight*m_tTextHeight;
 }
 
-void TitlesetManager::UpdateItems() {
+void TitlesetManager::UpdateItems(wxProgressDialog* progressDlg) {
+	m_progressDlg = progressDlg;
+	if (m_progressDlg)
+		m_progressDlg->Pulse();
 	wxThumbnailFactory::ClearQueue(this);
 
 	int selectedMenuId = -1; // to update m_selectedMenu
@@ -399,10 +421,12 @@ void TitlesetManager::UpdateItems() {
 	}
 	if (selectedMenuId>=0) // update m_selectedMenu
 		m_selectedMenu = GetIndex(selectedMenuId);
+	SetThumbSize(96, 76 + (m_dvd->GetTitlesets().size() > 1 || m_dvd->GetVmgm().size() > 0 ? m_tTextHeight : 0));
 	UpdateProp();
 	Refresh();
 	wxSplitterWindow* p = (wxSplitterWindow*) GetParent(); 
 	p->SetSashPosition(p->GetSashPosition() + (m_rows > 1 ? 0 : 1000));
+	m_progressDlg = NULL;;
 }
 
 int TitlesetManager::GetIndex(int tsi, int pgci, int vobi, bool menu) {
@@ -418,18 +442,16 @@ int TitlesetManager::GetIndex(int id) {
 }
 
 bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi, bool allowMenuDuplication) {
-	wxProgressDialog pdlg(wxT("DVDStyler"), wxString::Format(_("Adding file %s. Please wait..."), fname.c_str()),
-			99, this, wxPD_APP_MODAL | wxPD_AUTO_HIDE | wxPD_SMOOTH);
+	wxProgressDialog pdlg(wxT("DVDStyler"), wxString::Format(_("Adding file %s.\nPlease wait..."),
+			wxFileNameFromPath(fname).c_str()), 99, this->GetParent(), wxPD_APP_MODAL | wxPD_AUTO_HIDE | wxPD_SMOOTH);
 	pdlg.Show();
 	pdlg.SetFocus();
 	pdlg.Pulse();
 	Vob* vob = new Vob(_T(""));
 	if (!vob->SetFilename(fname)) {
-		pdlg.Close();
 		delete vob;
 		return false;
 	}
-	pdlg.Close();
 	
 	Stream* videoStream = vob->GetVideoStream();
 	if (videoStream == NULL) {
@@ -441,13 +463,52 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 		delete vob;
 		return AddAudio(fname);
 	}
+
+	// set chapters
+	int chapterCount = 0;
+	if (s_config.GetDefChapterLength() > 0) {
+		if (vob->GetDuration() > 0) {
+			int duration = (int) vob->GetDuration() / 60;
+			chapterCount = duration / s_config.GetDefChapterLength();
+			if (chapterCount > 0 && duration - s_config.GetDefChapterLength()*chapterCount < s_config.GetDefChapterLength()/5)
+				chapterCount--;
+			if (chapterCount>100)
+				chapterCount = 100;
+		} else {
+			chapterCount = 10;
+		}
+	}
+	long t = 0;
+	for (int i = 0; i <= chapterCount; i++) {
+		vob->GetCells().push_back(new Cell(t * 60000));
+		t += s_config.GetDefChapterLength();
+	}
 		
 	int videoBitrateOld = m_dvd->GetVideoBitrate();
 	
-	if (m_dvd->GetTitlesets().Count() == 0)
+	if (m_dvd->GetTitlesets().size() == 0) {
 		m_dvd->GetTitlesets().Add(new Titleset);
-	if (tsi < 0)
+	}
+
+	// check if chapter menu need to be updated
+	bool updateChapterMenu = false;
+	if (m_dvd->GetTitleMenuTemplate() && m_dvd->GetVmgm().size() > 0 && tsi < 0) {
+		Titleset* titleset = m_dvd->GetTitlesets().back();
+		if (titleset->GetMenus().GetPgciByEntry(wxT("ptt")) >= 0) {
+			if (titleset->GetTitles().size() == 0) {
+				updateChapterMenu = true;
+			} else if (titleset->GetTitles().size() == 1) {
+				updateChapterMenu = true;
+				if (chapterCount == 0)
+					chapterCount++;
+				chapterCount += titleset->GetTitles()[0]->GetChapterCount();
+			}
+		}
+	}
+
+	if (tsi < 0) {
 		tsi = m_dvd->GetTitlesets().GetCount() - 1;
+	}
 	PgcArray& pgcs = m_dvd->GetTitlesets()[tsi]->GetTitles();
 	
 	if (pgcs.Count() == 0) {
@@ -455,14 +516,14 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 		pgcs.GetVideo().SetAspect(videoStream->GetSourceAspectRatio() > 1.4 ? ar16_9 : ar4_3);
 		// check DVD video format
 		if (m_dvd->GetTitlesets().Count() == 1) {
-			int fps = lroundf(videoStream->GetSourceFps());
+			int fps = lround(videoStream->GetSourceFps());
 			if (isNTSC(m_dvd->GetVideoFormat()) && fps == 25) {
 				if (wxMessageBox(_("This file contains video in PAL format. Do you want to change DVD format to PAL too?"),
-						_("Burn"), wxYES_NO|wxICON_QUESTION, this) == wxYES)
+						wxT("DVDStyler"), wxYES_NO|wxICON_QUESTION, this) == wxYES)
 					m_dvd->SetVideoFormat(vfPAL, true);
 			} else if (!isNTSC(m_dvd->GetVideoFormat()) && (fps == 24 || fps == 30)) {
 				if (wxMessageBox(_("This file contains video in NTSC format. Do you want to change DVD format to NTSC too?"),
-						_("Burn"), wxYES_NO|wxICON_QUESTION, this) == wxYES)
+						wxT("DVDStyler"), wxYES_NO|wxICON_QUESTION, this) == wxYES)
 					m_dvd->SetVideoFormat(vfNTSC, true);
 			}
 		}
@@ -473,12 +534,12 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 	if (pgcs.GetVideo().GetFormat() <= vfCOPY)
 		pgcs.GetVideo().SetFormat(m_dvd->GetVideoFormat());
 	// check if reencoding is needed
-	for (unsigned int i=0; i<vob->GetStreams().GetCount(); i++) {
+	for (unsigned int i=0; i<vob->GetStreams().size(); i++) {
 		Stream* stream = vob->GetStreams()[i];
 		if (stream->GetType() == stVIDEO) {
 			// set destination format (default COPY) if codec is not mpeg2
 			if (m_reEncodingByDefault
-					|| vob->GetStreams().GetCount() == 1 // only video is available
+					|| vob->GetStreams().size() == 1 // only video is available
 					|| !stream->GetSourceCodecName().StartsWith(wxT("mpeg2video"))
 					|| stream->GetSourceVideoFormat() != pgcs.GetVideo().GetFormat()
 					|| fabs(stream->GetSourceAspectRatio()
@@ -498,29 +559,9 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 			stream->SetDestinationFormat(stream->GetSourceCodecName() == wxT("dvdsub") ? sfCOPY : sfNONE);
 		}
 	}
-	// set chapters
-	int n = 0;
-	if (s_config.GetDefChapterLength() > 0) {
-		if (vob->GetDuration() > 0) {
-			int duration = (int) vob->GetDuration() / 60;
-			n = duration / s_config.GetDefChapterLength();
-			if (n > 0 && duration - s_config.GetDefChapterLength()*n < s_config.GetDefChapterLength()/5)
-				n--;
-			if (n>100)
-				n = 100;
-		} else {
-			n = 10;
-		}
-	}
-	
-	Pgc* pgc = pgcs.Count()>0 ? pgcs.Last() : NULL;
-	long t = 0;
-	for (int i = 0; i <= n; i++) {
-		vob->GetCells().push_back(new Cell(t * 60000));
-		t += s_config.GetDefChapterLength();
-	}
 	
 	// add vob
+	Pgc* pgc = pgcs.Count()>0 ? pgcs.Last() : NULL;
 	if (createTitle || pgc == NULL) {
 		pgc = new Pgc;
 		pgc->SetPostCommands(m_dvd->GetDefPostCommandStr());
@@ -528,18 +569,35 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 		pgcs.Add(pgc);
 		if (allowMenuDuplication && !m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1) && pgcs.GetCount() > 4) {
 			// find menu to duplicate
-			PgcArray& menus = m_dvd->GetPgcArray(tsi, true);
-			for (unsigned int menuIdx = 0; menuIdx < menus.GetCount(); menuIdx++) {
-				Menu* menu = menus[menuIdx]->GetMenu();
-				if (menu && menu->GetButtonByJumpAction(-2, pgcs.GetCount() - 2)
-						&&  menu->GetButtonByJumpAction(-2, pgcs.GetCount() - 3)) {
-					DuplicateMenu(tsi, menuIdx);
-					break;
+			bool found = false;
+			Menus& vmgmMenus = m_dvd->GetVmgm();
+			if (vmgmMenus.size() > 0) {
+				for (unsigned int menuIdx = 0; menuIdx < vmgmMenus.size(); menuIdx++) {
+					Menu* menu = vmgmMenus[menuIdx]->GetMenu();
+					if (menu && menu->GetButtonByJumpAction(tsi, pgcs.GetCount() - 2)
+							&& menu->GetButtonByJumpAction(tsi, pgcs.GetCount() - 3)) {
+						DuplicateMenu(-1, menuIdx, tsi);
+						found = true;
+						break;
+					}
+				}
+			}
+			if (!found) {
+				PgcArray& menus = m_dvd->GetPgcArray(tsi, true);
+				for (unsigned int menuIdx = 0; menuIdx < menus.size(); menuIdx++) {
+					Menu* menu = menus[menuIdx]->GetMenu();
+					if (menu && menu->GetButtonByJumpAction(-2, pgcs.GetCount() - 2)
+							&& menu->GetButtonByJumpAction(-2, pgcs.GetCount() - 3)) {
+						DuplicateMenu(tsi, menuIdx, -2);
+						break;
+					}
 				}
 			}
 		}
-	} else
+	} else {
 		pgc->GetVobs().Add(vob);
+		m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1);
+	}
 	
 	// set aspect ratio if it isn't set
 	if (pgcs.GetVideo().GetAspect() == arAUTO) {
@@ -550,7 +608,12 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi,
 			pgcs.GetVideo().SetAspect(m_dvd->GetAspectRatio());
 	}
 	
-	UpdateItems();
+	// create chapter menu
+	if (updateChapterMenu) {
+		CreateChapterMenu(m_dvd->GetTitlesets().size() - 1, chapterCount);
+	}
+
+	UpdateItems(&pdlg);
 	SendDvdChangedEvent();
 	
 	// check if video fit on DVD without re-encoding
@@ -607,8 +670,8 @@ bool TitlesetManager::AddAudio(const wxString& fname) {
 		return false;
 	vob->SetDoNotTranscode(false);
 	// check if reencoding is needed
-	Stream* stream = vob->GetStreams()[vob->GetStreams().GetCount()-1];
-	if (vob->GetStreams().GetCount() == 2 && stream->GetSourceAudioFormat() != m_dvd->GetAudioFormat())
+	Stream* stream = vob->GetStreams()[vob->GetStreams().size()-1];
+	if (vob->GetStreams().size() == 2 && stream->GetSourceAudioFormat() != m_dvd->GetAudioFormat())
 		stream->SetDestinationFormat(m_dvd->GetAudioFormat());
 	else if (stream->GetSourceAudioFormat() != afMP2 && stream->GetSourceAudioFormat() != afAC3)
 		stream->SetDestinationFormat(m_dvd->GetAudioFormat());
@@ -635,7 +698,7 @@ bool TitlesetManager::AddSubtitles(const wxString& fname) {
 	return true;
 }
 
-void TitlesetManager::AddImage(const wxString& fname, bool createTitle) {
+void TitlesetManager::AddImage(const wxString& fname, bool createTitle, bool update) {
 	if (m_dvd->GetTitlesets().Count() == 0)
 		m_dvd->GetTitlesets().Add(new Titleset);
 
@@ -657,9 +720,11 @@ void TitlesetManager::AddImage(const wxString& fname, bool createTitle) {
 		pgc->GetVobs().Add(vob);
 	}
 	slideshow->AddSlide(new Slide(fname));
-
-	UpdateItems();
-	SendDvdChangedEvent();
+	
+	if (update) {
+		UpdateItems();
+		SendDvdChangedEvent();
+	}
 }
 
 void TitlesetManager::SelectMenu(int tsi, int pgci) {
@@ -679,22 +744,13 @@ void TitlesetManager::SelectFirstMenu() {
 }
 
 bool TitlesetManager::IsBeginOfTitleset(int tsi, int pgci, int vobi, bool isMenu) {
-	if (tsi<0 || (m_dvd->GetTitlesets().Count()<=1 && m_dvd->GetVmgm().Count()==0))
-		return false;
-	return pgci == 0 && vobi == 0
-		&& (isMenu || m_dvd->GetTitlesets()[tsi]->GetMenus().Count() == 0);
+	return pgci == 0 && vobi == 0 && (isMenu || tsi < 0 || m_dvd->GetTitlesets()[tsi]->GetMenus().size() == 0);
 }
 
 bool TitlesetManager::IsEndOfTitleset(int tsi, int pgci, int vobi, bool isMenu) {
-	if (tsi<0 || m_dvd->GetTitlesets().Count() < 2
-			|| tsi == (int)m_dvd->GetTitlesets().Count()-1)
-		return false;
-	Titleset* ts = m_dvd->GetTitlesets()[tsi];
-	return (isMenu && ts->GetTitles().Count() == 0
-				&& pgci == (int)ts->GetMenus().Count()-1
-				&& vobi == (int)ts->GetMenus()[pgci]->GetVobs().Count()-1)
-		|| (!isMenu && pgci == (int)ts->GetTitles().Count()-1
-				&& vobi == (int)ts->GetTitles()[pgci]->GetVobs().Count()-1);
+	PgcArray& pgcs = m_dvd->GetPgcArray(tsi, isMenu);
+	return (!isMenu || tsi < 0 || m_dvd->GetTitlesets()[tsi]->GetTitles().size() == 0)
+			&& pgci == (int)pgcs.size() - 1 && vobi == (int)pgcs[pgci]->GetVobs().Count()-1;
 }
 
 void TitlesetManager::SendMenuSelectedEvent() {
@@ -755,6 +811,11 @@ void TitlesetManager::AddMenu() {
 	int tsi = m_dvd->GetTitlesets().Count()-1;
 	if (GetSelected()>=0)
 		tsi = DVD::GetTsi(GetSelectedId());
+	PgcArray& menus = m_dvd->GetPgcArray(tsi, true);
+	if (menus.GetCount() >= 99) {
+		wxLogError(_("Maximal 99 menus are allowed for one titleset."));
+		return;
+	}
 	int pgci = m_dvd->AddMenu(tsi);
 	UpdateItems();
 	SelectMenu(tsi, pgci);
@@ -771,10 +832,11 @@ void TitlesetManager::AddVmMenu() {
 
 void TitlesetManager::AddTitleset() {
 	m_dvd->AddTitleset();
+	SetSelected(-1);
 	AddMenu();
 }
 
-bool TitlesetManager::DuplicateMenu(int tsi, int pgci) {
+bool TitlesetManager::DuplicateMenu(int tsi, int pgci, int targetTsi) {
 	Vob* vob = m_dvd->GetVob(tsi, true, pgci, 0);
 	if (!vob || !vob->GetMenu())
 		return false;
@@ -785,27 +847,102 @@ bool TitlesetManager::DuplicateMenu(int tsi, int pgci) {
 	menu->PutXML(menuXml);
 	delete menuXml;
 	// fix jump actions
-	int actionPgci = m_dvd->GetPgcArray(tsi, false).GetCount() - 1;
+	int actionPgci = m_dvd->GetPgcArray(targetTsi, false).size() - 1;
 	for (unsigned int obji = 0; obji < menu->GetObjectsCount(); obji++) {
 		MenuObject* obj = menu->GetObject(obji);
-		if (obj->IsButton() && !obj->GetAction().IsCustom() && obj->GetAction().GetTsi() == -2) {
-			if (!obj->GetAction().IsMenu() && !obj->GetAction().IsPlayAll()) {
+		if (obj->IsButton() && !obj->GetAction().IsCustom()) {
+			if (obj->GetAction().GetTsi() == targetTsi && !obj->GetAction().IsMenu() && !obj->GetAction().IsPlayAll()) {
 				obj->GetAction().SetPgci(actionPgci);
-				menu->UpdateButtonImageFor(-2, actionPgci, m_dvd);
+				menu->UpdateButtonImageFor(targetTsi, actionPgci, m_dvd);
 				actionPgci++;
-			} else if (obj->GetAction().IsMenu()) {
-				if (obj->GetAction().GetPgci() == pgci2)
+			} else if (obj->GetAction().GetTsi() == -2 && obj->GetAction().IsMenu()) {
+				if (obj->GetAction().GetPgci() == pgci2) { // next button
 					obj->GetAction().SetPgci(pgci2 + 1);
-				else if (obj->GetAction().GetPgci() == 100)
+				} else if (obj->GetAction().GetPgci() == 100) { // previous button
 					obj->GetAction().SetPgci(pgci2 - 1);
-				else if (pgci2 > 2 && obj->GetAction().GetPgci() == pgci2 - 2)
+				} else if (pgci2 > 2 && obj->GetAction().GetPgci() == pgci2 - 2) { // previous button
 					obj->GetAction().SetPgci(pgci2 - 1);
+				}
 			}
 		}
 	}
 	return true;
 }
 
+bool TitlesetManager::CreateChapterMenu(int targetTsi, int chapterCount) {
+	if (!m_dvd->GetTitleMenuTemplate() || targetTsi < 0)
+		return false;
+
+	int chapter = 0;
+
+	// check if chapter menu already exists
+	Titleset* titleset = m_dvd->GetTitlesets()[targetTsi];
+	int pttMenu = titleset->GetMenus().GetPgciByEntry(wxT("ptt"));
+	if (pttMenu >= 0) {
+		for (unsigned int menuIdx = pttMenu; menuIdx < titleset->GetMenus().size(); menuIdx++) {
+			Menu* menu = titleset->GetMenus()[menuIdx]->GetMenu();
+			for (unsigned int obji = 0; obji < menu->GetObjectsCount(); obji++) {
+				MenuObject* obj = menu->GetObject(obji);
+				DVDAction& action = obj->GetAction();
+				if (obj->IsButton() && !action.IsCustom() && !action.IsMenu() && action.GetTsi() == -2
+						&& action.GetPgci() == 0 && action.GetChapter() > chapter) {
+					chapter = action.GetChapter();
+				}
+			}
+		}
+	}
+	if (chapter > 0)
+		chapter++;
+
+	// create menus
+	while (chapter < chapterCount) {
+		// add new menu
+		int pgci2 = m_dvd->AddMenu(targetTsi);
+		Pgc* pgc = m_dvd->GetPgc(targetTsi, true, pgci2);
+		pgc->GetEntries().clear();
+		if (chapter == 0) {
+			pgc->GetEntries().insert(wxT("ptt"));
+		}
+		Menu* menu = m_dvd->GetMenu(targetTsi, pgci2);
+		menu->PutXML(m_dvd->GetTitleMenuTemplate());
+		menu->SetAspectRatio(m_dvd->GetAspectRatio());
+		menu->SetVideoFormat(m_dvd->GetVideoFormat());
+
+		// fix jump actions
+		for (unsigned int obji = 0; obji < menu->GetObjectsCount(); obji++) {
+			MenuObject* obj = menu->GetObject(obji);
+			DVDAction& action = obj->GetAction();
+			if (obj->IsButton() && !action.IsCustom()) {
+				if (!action.IsMenu() && !action.IsPlayAll()) {
+					action.SetTsi(-2);
+					action.SetPgci(0);
+					action.SetChapter(chapter);
+					chapter++;
+				} else if (action.IsMenu() && action.GetTsi() == -2) {
+					if (action.GetPgci() == 0) {
+						action.SetTsi(-1); // home button -> vmgm menu 1
+					} else if (action.GetPgci() == 2) {
+						action.SetPgci(pgci2 + 1); // next button -> menu + 1
+					} else if (pgci2 > 0 && action.GetPgci() == 100) { // previous button -> menu - 1
+						obj->GetAction().SetPgci(pgci2 - 1);
+					}
+				}
+			}
+			MenuObjectParam* initParam = obj->GetInitParam();
+			if (initParam && (initParam->type == wxT("text") || initParam->type == wxT("string"))
+					&& obj->GetParam(initParam->name) == wxT("Back")) {
+				obj->SetParam(initParam->name, _("Back"));
+				obj->UpdateSize();
+			}
+		}
+		menu->UpdateButtonImageFor(-2, 0, m_dvd);
+		if (chapter == 0) {
+			break;
+		}
+	}
+	return true;
+}
+
 void TitlesetManager::FixVobChapters(Pgc* pgc, int vobi, int vobi2) {
 	wxString chapters = pgc->GetVobs()[vobi]->GetChapters();
 	wxString chapters2 = pgc->GetVobs()[vobi2]->GetChapters();
@@ -923,6 +1060,7 @@ void TitlesetManager::MoveSelectedTo(int idx) {
 			m_dvd->GetTitlesets().RemoveAt(tsi);
 		}
 	}
+	m_dvd->UpdateMenusLocations();
 	UpdateItems();
 	SendDvdChangedEvent();
 }
@@ -945,8 +1083,10 @@ void TitlesetManager::OnMoveTitleLeft(wxCommandEvent& WXUNUSED(event)) {
 	Pgc* pgc = pgcs[pgci];
 	pgcs[pgci] = pgcs[pgci-1];
 	pgcs[pgci-1] = pgc;
-	if (isMenu)
+	if (isMenu) {
 		SelectMenu(tsi, pgci-1);
+	}
+	m_dvd->UpdateMenusLocations();
 	UpdateItems();
 	SendDvdChangedEvent();
 	m_dvd->UpdateButtonImageFor(tsi, pgci - 1);
@@ -968,6 +1108,7 @@ void TitlesetManager::OnMoveTitleRight(wxCommandEvent& WXUNUSED(event)) {
 	pgcs[pgci+1] = pgc;
 	if (isMenu)
 		SelectMenu(tsi, pgci+1);
+	m_dvd->UpdateMenusLocations();
 	UpdateItems();
 	SendDvdChangedEvent();
 	m_dvd->UpdateButtonImageFor(tsi, pgci);
@@ -994,14 +1135,14 @@ void TitlesetManager::OnMoveTitleRightUpdateUI(wxUpdateUIEvent& event) {
 }
 
 void TitlesetManager::OnDelete(wxCommandEvent& WXUNUSED(event)) {
-	if (GetSelected()<0)
+	if (GetSelected() < 0)
 		return;
 	int id = GetSelectedId();
 	int tsi = DVD::GetTsi(id);
 	int pgci = DVD::GetPgci(id);
 	bool isMenu = DVD::IsMenu(id);
 	int vobi = DVD::GetVobi(id);
-	if (s_config.GetShowTitleDeletePrompt()) {
+	if (s_config.GetTitleDeletePrompt()) {
 		wxString caption = isMenu ? _("Menu") : _T("Title");
 		caption += wxString::Format(wxT(" %d"), pgci+1);
 		if (vobi>0)
@@ -1010,7 +1151,7 @@ void TitlesetManager::OnDelete(wxCommandEvent& WXUNUSED(event)) {
 				_("Titleset Manager"), wxYES_NO|wxICON_QUESTION);
 		if (msgDlg.ShowModal() != wxYES)
 			return;
-		s_config.SetShowTitleDeletePrompt(!msgDlg.DontShowAgain());
+		s_config.SetTitleDeletePrompt(msgDlg.IsShowAgain());
 	}
 	if (isMenu) {
 		Titleset* ts= NULL;
@@ -1074,6 +1215,8 @@ void TitlesetManager::OnDelete(wxCommandEvent& WXUNUSED(event)) {
 			for (unsigned int pgci2 = pgci; pgci2 <= ts->GetTitles().GetCount(); pgci2++) {
 				m_dvd->UpdateButtonImageFor(tsi, pgci2);
 			}
+		} else {
+			m_dvd->UpdateButtonImageFor(tsi, pgci);
 		}
 		// remove titleset if need
 		if (ts->GetTitles().Count() == 0
