@@ -3,7 +3,7 @@
 // Purpose:     The video properties dialog
 // Author:      Alex Thuering
 // Created:     09.09.2010
-// RCS-ID:      $Id: VideoPropDlg.cpp,v 1.20 2013/06/30 15:06:45 ntalex Exp $
+// RCS-ID:      $Id: VideoPropDlg.cpp,v 1.21 2014/02/08 11:00:53 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -218,7 +218,7 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	boxSizer1->Add(m_startFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	m_startBt = new wxBitmapButton(this, START_BT_ID, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_CUT")),wxART_MENU), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("START_BT_ID"));
 	m_startBt->SetDefault();
-	m_startBt->SetToolTip(_("Reset"));
+	m_startBt->SetToolTip(_("Cut beginning"));
 	boxSizer1->Add(m_startBt, 0, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
 	StaticText9 = new wxStaticText(this, wxID_ANY, _("End:"), wxDefaultPosition, wxDefaultSize, 0, _T("wxID_ANY"));
 	boxSizer1->Add(StaticText9, 0, wxLEFT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
@@ -234,7 +234,7 @@ VideoPropDlg::VideoPropDlg(wxWindow* parent,Vob* vob, AspectRatio aspectRatio) {
 	boxSizer1->Add(m_endFrameSpin, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
 	m_endBt = new wxBitmapButton(this, ID_RESET_TIME_BT, wxArtProvider::GetBitmap(wxART_MAKE_ART_ID_FROM_STR(_T("wxART_CUT")),wxART_MENU), wxDefaultPosition, wxDefaultSize, wxBU_AUTODRAW, wxDefaultValidator, _T("ID_RESET_TIME_BT"));
 	m_endBt->SetDefault();
-	m_endBt->SetToolTip(_("Reset"));
+	m_endBt->SetToolTip(_("Cut ending"));
 	boxSizer1->Add(m_endBt, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
 	mediaSizer->Add(boxSizer1, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
 	hSizer->Add(mediaSizer, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
