@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 2.7.12-4996.  */
 
 /* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +30,15 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_DVDVM_DVDVMY_H_INCLUDED
+# define YY_DVDVM_DVDVMY_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int dvdvmdebug;
+#endif
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -187,12 +196,10 @@
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
+/* Line 2053 of yacc.c  */
 #line 92 "dvdvmy.y"
 
     unsigned int int_val;
@@ -200,9 +207,8 @@ typedef union YYSTYPE
     struct vm_statement *statement;
 
 
-
-/* Line 2068 of yacc.c  */
-#line 206 "dvdvmy.h"
+/* Line 2053 of yacc.c  */
+#line 212 "dvdvmy.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -211,4 +217,18 @@ typedef union YYSTYPE
 
 extern YYSTYPE dvdvmlval;
 
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int dvdvmparse (void *YYPARSE_PARAM);
+#else
+int dvdvmparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int dvdvmparse (void);
+#else
+int dvdvmparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
 
+#endif /* !YY_DVDVM_DVDVMY_H_INCLUDED  */
