@@ -3,7 +3,7 @@
 // Purpose:     Media Transcoder Interface
 // Author:      Alex Thuering
 // Created:     26.04.2008
-// RCS-ID:      $Id: mediatrc.h,v 1.11 2013/03/17 18:51:00 ntalex Exp $
+// RCS-ID:      $Id: mediatrc.h,v 1.12 2014/03/31 08:36:31 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -29,13 +29,13 @@ public:
 	/** Adds input file. */
 	virtual bool AddInputFile(const wxString& fileName, const wxString& format = wxT(""), long tsOffset = 0) = 0;
 	/** Sets output file and video/audio/subtitle formats. */
-	virtual bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, AudioFormat audioFormat,
-		SubtitleFormat subtitleFormat, int videoBitrate = 6000, bool vbr = false, int audioBitrate = 224,
-		int mapFileIdx = -1, int mapStreamIdx = -1) = 0;
+	virtual bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm,
+		AspectRatio aspectRatio, AudioFormat audioFormat, SubtitleFormat subtitleFormat, int videoBitrate = 6000,
+		bool vbr = false, int audioBitrate = 224, int mapFileIdx = -1, int mapStreamIdx = -1) = 0;
 	/** Sets output file and video/audio/subtitle formats. */
-	virtual bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, wxArrayInt audioFormats,
-		wxArrayInt subtitleFormats, int videoBitrate = 6000, bool vbr = false, int audioBitrate = 224,
-		int mapFileIdx = -1, int mapStreamIdx = -1) = 0;
+	virtual bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm,
+			AspectRatio aspectRatio, wxArrayInt audioFormats, wxArrayInt subtitleFormats, int videoBitrate = 6000,
+			bool vbr = false, int audioBitrate = 224, int mapFileIdx = -1, int mapStreamIdx = -1) = 0;
 	/** Sets pad values */
 	void SetPad(const vector<int>& pad);
 	/** Sets crop values */
