@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Transcoder
 // Author:      Alex Thuering
 // Created:     26.04.2008
-// RCS-ID:      $Id: mediatrc_ffmpeg.cpp,v 1.58 2013/03/17 18:51:00 ntalex Exp $
+// RCS-ID:      $Id: mediatrc_ffmpeg.cpp,v 1.63 2014/03/31 08:36:22 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -42,9 +42,13 @@ void wxFfmpegMediaTranscoder::AddSubtitleOption(const wxString& name, int stream
 }
 
 bool wxFfmpegMediaTranscoder::AddInputFile(const wxString& fileName, const wxString& format, long tsOffset) {
-	if (format.length())
-		AddOption(wxT("f"), format);
-	m_cmd += wxString::Format(wxT(" -i \"%s\""), fileName.c_str());
+	if (fileName == wxT("/dev/zero")) {
+		m_cmd += wxT(" -ac 2 -ar 48000 -f s16le -i /dev/zero");
+	} else {
+		if (format.length())
+			AddOption(wxT("f"), format);
+		m_cmd += wxString::Format(wxT(" -i \"%s\""), fileName.c_str());
+	}
 	if (tsOffset > 0)
 		AddOption(wxT("itsoffset"), Time2String(tsOffset));
 	
@@ -53,20 +57,20 @@ bool wxFfmpegMediaTranscoder::AddInputFile(const wxString& fileName, const wxStr
 }
 
 bool wxFfmpegMediaTranscoder::SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm,
-		AudioFormat audioFormat, SubtitleFormat subtitleFormat, int videoBitrate, bool vbr, int audioBitrate,
-		int mapFileIdx, int mapStreamIdx) {
+		AspectRatio aspectRatio, AudioFormat audioFormat, SubtitleFormat subtitleFormat, int videoBitrate,
+		bool vbr, int audioBitrate, int mapFileIdx, int mapStreamIdx) {
 	wxArrayInt audioFormats;
 	if (audioFormat != afNONE)
 		audioFormats.Add(audioFormat);
 	wxArrayInt subtitleFormats;
 	subtitleFormats.Add(subtitleFormat);
-	return SetOutputFile(fileName, videoFormat, ntscFilm, audioFormats, subtitleFormats, videoBitrate, vbr,
-			audioBitrate, mapFileIdx, mapStreamIdx);
+	return SetOutputFile(fileName, videoFormat, ntscFilm, aspectRatio, audioFormats, subtitleFormats, videoBitrate,
+			vbr, audioBitrate, mapFileIdx, mapStreamIdx);
 }
 
 bool wxFfmpegMediaTranscoder::SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm,
-		wxArrayInt audioFormats, wxArrayInt subtitleFormats, int videoBitrate, bool vbr, int audioBitrate,
-		int mapFileIdx, int mapStreamIdx) {
+		AspectRatio aspectRatio, wxArrayInt audioFormats, wxArrayInt subtitleFormats, int videoBitrate, bool vbr,
+		int audioBitrate, int mapFileIdx, int mapStreamIdx) {
 	if (m_outputFormat.length() > 0)
 		AddOption(wxT("f"), m_outputFormat);
 	else if (audioFormats.GetCount() == 0)
@@ -81,6 +85,9 @@ bool wxFfmpegMediaTranscoder::SetOutputFile(const wxString& fileName, VideoForma
 		AddVideoOption(wxT("c"), 0, wxT("copy"));
 	} else if (videoFormat != vfNONE) {
 		AddVideoOption(wxT("c"), 0, wxT("mpeg2video"));
+		if (aspectRatio != arAUTO) {
+			AddOption(wxT("aspect"), aspectRatio == ar16_9 ? wxT("16:9") : wxT("4:3"));
+		}
 		
 		wxSize frameSize = GetFrameSize(videoFormat);
 		AddOption(wxT("s"), wxString::Format(wxT("%dx%d"), frameSize.x, frameSize.y));
@@ -113,17 +120,12 @@ bool wxFfmpegMediaTranscoder::SetOutputFile(const wxString& fileName, VideoForma
 		if (audioFormats[i] != afNONE) {
 			AddAudioOption(wxT("c"), outputStreamIdx, audioFormats[i] == afCOPY ? wxT("copy") : audioFormats[i] == afMP2
 						? wxT("mp2") : audioFormats[i] == afAC3 ? wxT("ac3") : wxT("pcm_s16be"));
-			if (audioFormats[i] >= afAC3 && m_channelNumber.find(i) != m_channelNumber.end())
-				AddAudioOption(wxT("af"), outputStreamIdx, wxString::Format(wxT("aformat=channel_layouts\\=%d"), m_channelNumber[i]));
+			if (m_audioFilters.find(i) != m_audioFilters.end() && m_audioFilters[i].length() > 0) {
+				AddAudioOption(wxT("filter"), outputStreamIdx, wxT('"') + m_audioFilters[i] + wxT('"'));
+			}
 			outputStreamIdx++;
 		}
 	}
-	for(map<int,int>::const_iterator i = m_audioVolume.begin(); i != m_audioVolume.end(); ++i) {
-		if (i->second != 256) {
-			AddOption(wxT("vol"), wxString::Format(wxT("%d"), i->second));
-			break;
-		}
-	}
 	outputStreamIdx = 0;
 	for (unsigned int i = 0; i < subtitleFormats.size(); i++) {
 		if (subtitleFormats[i] != sfNONE) {
@@ -153,6 +155,8 @@ bool wxFfmpegMediaTranscoder::SetOutputFile(const wxString& fileName, VideoForma
 		for (unsigned int i = 0; i < subtitleFormats.size(); i++) {
 			if (subtitleFormats[i] == sfNONE)
 				AddOption(wxT("map"), wxString::Format(wxT("-0:s:%d"), i));
+			else if (subtitleFormats[i] == sfCOPY)
+				AddOption(wxT("map"), wxString::Format(wxT("0:s:%d"), i));
 		}
 	}
 	
