@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Transcoder
 // Author:      Alex Thuering
 // Created:     26.04.2008
-// RCS-ID:      $Id: mediatrc_ffmpeg.h,v 1.33 2013/03/17 18:51:00 ntalex Exp $
+// RCS-ID:      $Id: mediatrc_ffmpeg.h,v 1.35 2014/03/31 08:36:22 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -26,13 +26,13 @@ public:
 	bool AddInputFile(const wxString& fileName, const wxString& format = wxT(""), long tsOffset = 0);
 	
 	/** Sets output file and video/audio/subtitle formats. */
-	bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, AudioFormat audioFormat,
-			SubtitleFormat subtitleFormat, int videoBitrate = 6000, bool vbr = false, int audioBitrate = 224,
-			int mapFileIdx = -1, int mapStreamIdx = -1);
+	bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, AspectRatio aspectRatio,
+			AudioFormat audioFormat, SubtitleFormat subtitleFormat, int videoBitrate = 6000, bool vbr = false,
+			int audioBitrate = 224, int mapFileIdx = -1, int mapStreamIdx = -1);
 	/** Sets output file and video/audio/subtitle formats. */
-	bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, wxArrayInt audioFormats,
-			wxArrayInt subtitleFormats, int videoBitrate = 6000, bool vbr = false, int audioBitrate = 224,
-			int mapFileIdx = -1, int mapStreamIdx = -1);
+	bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, bool ntscFilm, AspectRatio aspectRatio, 
+			wxArrayInt audioFormats, wxArrayInt subtitleFormats, int videoBitrate = 6000, bool vbr = false,
+			int audioBitrate = 224, int mapFileIdx = -1, int mapStreamIdx = -1);
 	/** Sets output format (optional). Call it before SetOutputFile() */
 	void SetOutputFormat(wxString outputFormat) { m_outputFormat = outputFormat; }
 	/** Sets interlaced encoding flag */
@@ -45,10 +45,8 @@ public:
 	void SetRecordingTime(double recordingTime);
 	/** Sets video filters */
 	void SetVideoFilters(const wxString& videoFilters) { m_videoFilters = videoFilters; }
-	/** Sets audio volume (256=normal) */
-	void SetAudioVolume(int streamIndex, int audioVolume) { m_audioVolume[streamIndex] = audioVolume; }
-	/** Sets audio volume (256=normal) */
-	void SetChannelNumber(int streamIndex, int channelNumber) { m_channelNumber[streamIndex] = channelNumber; }
+	/** Sets audio filters */
+	void SetAudioFilters(int streamIndex, const wxString& audioFilters) { m_audioFilters[streamIndex] = audioFilters; }
 	
 	/** Starts transcoding. */
 	bool Run(bool& canceled);
@@ -62,8 +60,7 @@ private:
 	wxString m_cmd;
 	wxString m_outputFormat;
 	wxString m_videoFilters;
-    map<int, int> m_audioVolume; // stream index -> audio volume
-    map<int, int> m_channelNumber; // stream index -> channel number
+    map<int, wxString> m_audioFilters; // stream index -> audio filters
     void AddOption(const wxString& name, const wxString& value);
     void AddAudioOption(const wxString& name, int streamIdx, const wxString& value);
     void AddVideoOption(const wxString& name, int streamIdx, const wxString& value);
