@@ -3,7 +3,7 @@
 // Purpose:     Properties dialog (base class for all properties dialogs)
 // Author:      Alex Thuering
 // Created:     18.11.2003
-// RCS-ID:      $Id: PropDlg.cpp,v 1.43 2013/06/04 19:23:35 ntalex Exp $
+// RCS-ID:      $Id: PropDlg.cpp,v 1.44 2013/12/29 19:32:02 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -740,14 +740,14 @@ void wxPropDlg::OnSelectColour(wxCommandEvent& event) {
 	}
 }
 
-void wxPropDlg::AddFileProp(wxSizer* sizer, const wxString& label, const wxString& value, int dlgStyle,
+wxSizer* wxPropDlg::AddFileProp(wxSizer* sizer, const wxString& label, const wxString& value, int dlgStyle,
 		wxString buttonLabel, wxString wildcard, int id) {
 	if (!sizer) // only update value
 	{
 		wxTextCtrl* ctrl = (wxTextCtrl*) m_controls[m_updateIndex];
 		ctrl->SetValue(value);
 		m_updateIndex++;
-		return;
+		return NULL;
 	}
 	// add text control
 	if (label.length())
@@ -766,6 +766,7 @@ void wxPropDlg::AddFileProp(wxSizer* sizer, const wxString& label, const wxStrin
 	m_types.Add(propTEXT);
 	m_controls.Add(ctrl);
 	m_groupIds.Add(m_currGroupId);
+	return sizer2;
 }
 
 void wxPropDlg::OnSelectFile(wxCommandEvent& event) {
@@ -782,12 +783,12 @@ void wxPropDlg::OnSelectFile(wxCommandEvent& event) {
 		ctrl->SetValue(dialog.GetPath());
 }
 
-void wxPropDlg::AddDirectoryProp(wxSizer* sizer, const wxString& label, const wxString& value, wxString buttonLabel) {
+wxSizer* wxPropDlg::AddDirectoryProp(wxSizer* sizer, const wxString& label, const wxString& value, wxString buttonLabel) {
 	if (!sizer) { // only update value
 		wxTextCtrl* ctrl = (wxTextCtrl*) m_controls[m_updateIndex];
 		ctrl->SetValue(value);
 		m_updateIndex++;
-		return;
+		return NULL;
 	}
 	// add text control
 	if (label.length())
@@ -805,6 +806,7 @@ void wxPropDlg::AddDirectoryProp(wxSizer* sizer, const wxString& label, const wx
 	m_types.Add(propTEXT);
 	m_controls.Add(ctrl);
 	m_groupIds.Add(m_currGroupId);
+	return sizer2;
 }
 
 void wxPropDlg::OnSelectDir(wxCommandEvent& event) {
